# Copyright (C) 2009, 2010, 2013, 2014 Nicira Networks, Inc.
#
# Copying and distribution of this file, with or without modification,
# are permitted in any medium without royalty provided the copyright
# notice and this notice are preserved.  This file is offered as-is,
# without warranty of any kind.
#
# If tests have to be skipped while building, specify the '--without check'
# option. For example:
# rpmbuild -bb --without check rhel/openvswitch-fedora.spec

# This defines the base package name's version.

%define pkgname openvswitch2.17


%if 0%{?commit:1}
%global shortcommit %(c=%{commit}; echo ${c:0:7})
%endif

# Enable PIE, bz#955181
%global _hardened_build 1

# RHEL-7 doesn't define _rundir macro yet
# Fedora 15 onwards uses /run as _rundir
%if 0%{!?_rundir:1}
%define _rundir /run
%endif

# FIXME Test "STP - flush the fdb and mdb when topology changed" fails on s390x
# FIXME 2 tests fails on ppc64le. They will be hopefully fixed before official 2.11
%ifarch %{ix86} x86_64 aarch64
%bcond_without check
%else
%bcond_with check
%endif
# option to run kernel datapath tests, requires building as root!
%bcond_with check_datapath_kernel
# option to build with libcap-ng, needed for running OVS as regular user
%bcond_without libcapng
# option to build with ipsec support
%bcond_without ipsec

# Build python2 (that provides python) and python3 subpackages on Fedora
# Build only python3 (that provides python) subpackage on RHEL8
# Build only python subpackage on RHEL7
%if 0%{?rhel} > 7 || 0%{?fedora}
# On RHEL8 Sphinx is included in buildroot
%global external_sphinx 1
%else
# Don't use external sphinx (RHV doesn't have optional repositories enabled)
%global external_sphinx 0
%endif

Name: %{pkgname}
Summary: Open vSwitch
Group: System Environment/Daemons daemon/database/utilities
URL: http://www.openvswitch.org/
Version: 2.17.0
Release: 172%{?dist}

# Nearly all of openvswitch is ASL 2.0.  The bugtool is LGPLv2+, and the
# lib/sflow*.[ch] files are SISSL
# datapath/ is GPLv2 (although not built into any of the binary packages)
License: ASL 2.0 and LGPLv2+ and SISSL

%define dpdkver 21.11
%define dpdkdir dpdk
%define dpdksver %(echo %{dpdkver} | cut -d. -f-2)
# NOTE: DPDK does not currently build for s390x
# DPDK on aarch64 is not stable enough to be enabled in FDP
%if 0%{?rhel} > 7 || 0%{?fedora}
%define dpdkarches x86_64 ppc64le
%else
%define dpdkarches
%endif

%if 0%{?commit:1}
Source: https://github.com/openvswitch/ovs/archive/%{commit}.tar.gz#/openvswitch-%{commit}.tar.gz
%else
Source: https://github.com/openvswitch/ovs/archive/v%{version}.tar.gz#/openvswitch-%{version}.tar.gz
%endif
Source2: openvswitch.sysusers
Source3: openvswitch-hugetlbfs.sysusers
Source10: https://fast.dpdk.org/rel/dpdk-%{dpdkver}.tar.xz

%define docutilsver 0.12
%define pygmentsver 1.4
%define sphinxver   1.2.3
%define pyelftoolsver 0.27
Source100: https://pypi.io/packages/source/d/docutils/docutils-%{docutilsver}.tar.gz
Source101: https://pypi.io/packages/source/P/Pygments/Pygments-%{pygmentsver}.tar.gz
Source102: https://pypi.io/packages/source/S/Sphinx/Sphinx-%{sphinxver}.tar.gz
Source103: https://pypi.io/packages/source/p/pyelftools/pyelftools-%{pyelftoolsver}.tar.gz

Patch0:    openvswitch-%{version}.patch

# The DPDK is designed to optimize througput of network traffic using, among
# other techniques, carefully crafted assembly instructions.  As such it
# needs extensive work to port it to other architectures.
ExclusiveArch: x86_64 aarch64 ppc64le s390x

# Do not enable this otherwise YUM will break on any upgrade.
# Provides: openvswitch
Conflicts: openvswitch < 2.17
Conflicts: openvswitch-dpdk < 2.17
Conflicts: openvswitch2.10
Conflicts: openvswitch2.11
Conflicts: openvswitch2.12
Conflicts: openvswitch2.13
Conflicts: openvswitch2.14
Conflicts: openvswitch2.15
Conflicts: openvswitch2.16

# FIXME Sphinx is used to generate some manpages, unfortunately, on RHEL, it's
# in the -optional repository and so we can't require it directly since RHV
# doesn't have the -optional repository enabled and so TPS fails
%if %{external_sphinx}
BuildRequires: python3-sphinx
%else
# Sphinx dependencies
BuildRequires: python-devel
BuildRequires: python-setuptools
#BuildRequires: python2-docutils
BuildRequires: python-jinja2
BuildRequires: python-nose
#BuildRequires: python2-pygments
# docutils dependencies
BuildRequires: python-imaging
# pygments dependencies
BuildRequires: python-nose
%endif

BuildRequires: gcc gcc-c++ make
BuildRequires: autoconf automake libtool
BuildRequires: systemd-units systemd-rpm-macros openssl openssl-devel
BuildRequires: python3-devel python3-setuptools
BuildRequires: desktop-file-utils
BuildRequires: groff-base graphviz
BuildRequires: unbound-devel
BuildRequires: systemtap-sdt-devel
# make check dependencies
BuildRequires: procps-ng
%if %{with check_datapath_kernel}
BuildRequires: nmap-ncat
# would be useful but not available in RHEL or EPEL
#BuildRequires: pyftpdlib
%endif

%if %{with libcapng}
BuildRequires: libcap-ng libcap-ng-devel
%endif

%ifarch %{dpdkarches}
BuildRequires: meson
%if 0%{?rhel} > 8 || 0%{?fedora}
BuildRequires: python3-pyelftools
%endif
# DPDK driver dependencies
BuildRequires: zlib-devel numactl-devel libarchive-devel
%ifarch x86_64
BuildRequires: rdma-core-devel >= 15 libmnl-devel
%endif

# Required by packaging policy for the bundled DPDK
Provides: bundled(dpdk) = %{dpdkver}
%endif

Requires: openssl iproute module-init-tools
#Upstream kernel commit 4f647e0a3c37b8d5086214128614a136064110c3
#Requires: kernel >= 3.15.0-0
Requires: openvswitch-selinux-extra-policy

%{?sysusers_requires_compat}
Requires(post): /bin/sed
Requires(post): systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units
Obsoletes: openvswitch-controller <= 0:2.1.0-1

%if 0%{?rhel}
# sortedcontainers are not packaged on RHEL yet, but ovs includes it
%global __requires_exclude ^python%{python3_version}dist\\(sortedcontainers\\)$
%endif

%description
Open vSwitch provides standard network bridging functions and
support for the OpenFlow protocol for remote per-flow control of
traffic.

%package -n python3-%{pkgname}
Summary: Open vSwitch python3 bindings
License: ASL 2.0
Requires: %{pkgname} = %{?epoch:%{epoch}:}%{version}-%{release}
Provides: python-%{pkgname} = %{?epoch:%{epoch}:}%{version}-%{release}

%description -n python3-%{pkgname}
Python bindings for the Open vSwitch database

%package test
Summary: Open vSwitch testing utilities
License: ASL 2.0
BuildArch: noarch
Requires: python3-%{pkgname} = %{?epoch:%{epoch}:}%{version}-%{release}
Requires: tcpdump

%description test
Utilities that are useful to diagnose performance and connectivity
issues in Open vSwitch setup.

%package devel
Summary: Open vSwitch OpenFlow development package (library, headers)
License: ASL 2.0
Requires: %{pkgname} = %{?epoch:%{epoch}:}%{version}-%{release}

%description devel
This provides shared library, libopenswitch.so and the openvswitch header
files needed to build an external application.

%if 0%{?rhel} == 8 || 0%{?fedora} > 28
%package -n network-scripts-%{name}
Summary: Open vSwitch legacy network service support
License: ASL 2.0
Requires: network-scripts
Supplements: (%{name} and network-scripts)

%description -n network-scripts-%{name}
This provides the ifup and ifdown scripts for use with the legacy network
service.
%endif

%if %{with ipsec}
%package ipsec
Summary: Open vSwitch IPsec tunneling support
License: ASL 2.0
Requires: python3-%{pkgname} = %{?epoch:%{epoch}:}%{version}-%{release}
Requires: libreswan

%description ipsec
This package provides IPsec tunneling support for OVS tunnels.
%endif

%prep
%if 0%{?commit:1}
%setup -q -n ovs-%{commit} -a 10
%else
%setup -q -n ovs-%{version} -a 10
%endif
%if ! %{external_sphinx}
%if 0%{?commit:1}
%setup -n ovs-%{commit} -q -D -T -a 100 -a 101 -a 102
%else
%setup -n ovs-%{version} -q -D -T -a 100 -a 101 -a 102
%endif
%endif
%if 0%{?rhel} && 0%{?rhel} < 9
%if 0%{?commit:1}
%setup -n ovs-%{commit} -q -D -T -a 103
%else
%setup -n ovs-%{version} -q -D -T -a 103
%endif
%endif

mv dpdk-*/ %{dpdkdir}/

# FIXME should we propose a way to do that upstream?
sed -ri "/^subdir\('(usertools|app)'\)/d" %{dpdkdir}/meson.build

%patch0 -p1

%build
%if 0%{?rhel} && 0%{?rhel} < 9
export PYTHONPATH="${PWD}/pyelftools-%{pyelftoolsver}"
%endif
# Build Sphinx on RHEL
%if ! %{external_sphinx}
export PYTHONPATH="${PYTHONPATH:+$PYTHONPATH:}%{_builddir}/pytmp/lib/python"
for x in docutils-%{docutilsver} Pygments-%{pygmentsver} Sphinx-%{sphinxver}; do
    pushd "$x"
    python2 setup.py install --home %{_builddir}/pytmp
    popd
done

export PATH="$PATH:%{_builddir}/pytmp/bin"
%endif

./boot.sh

%ifarch %{dpdkarches}    # build dpdk
# Lets build DPDK first
cd %{dpdkdir}

ENABLED_DRIVERS=(
    bus/pci
    bus/vdev
    mempool/ring
    net/failsafe
    net/i40e
    net/ring
    net/vhost
    net/virtio
    net/tap
)

%ifarch x86_64
ENABLED_DRIVERS+=(
    bus/auxiliary
    bus/vmbus
    common/iavf
    common/mlx5
    net/bnxt
    net/enic
    net/iavf
    net/ice
    net/mlx5
    net/netvsc
    net/nfp
    net/qede
    net/vdev_netvsc
)
%endif

%ifarch aarch64 x86_64
ENABLED_DRIVERS+=(
    net/e1000
    net/ixgbe
)
%endif

for driver in "${ENABLED_DRIVERS[@]}"; do
    enable_drivers="${enable_drivers:+$enable_drivers,}"$driver
done

# As of 21.11-rc3, following libraries can be disabled:
# optional_libs = [
#         'bitratestats',
#         'gpudev',
#         'gro',
#         'gso',
#         'kni',
#         'jobstats',
#         'latencystats',
#         'metrics',
#         'pdump',
#         'power',
#         'vhost',
# ]
# If doing any updates, this must be aligned with:
# https://access.redhat.com/articles/3538141
DISABLED_LIBS=(
    gpudev
    kni
    jobstats
    power
)

for lib in "${DISABLED_LIBS[@]}"; do
    disable_libs="${disable_libs:+$disable_libs,}"$lib
done

%set_build_flags
%__meson --prefix=%{_builddir}/dpdk-build \
         --buildtype=plain \
         -Ddisable_libs="$disable_libs" \
         -Denable_drivers="$enable_drivers" \
         -Dplatform=generic \
         -Dmax_ethports=1024 \
         -Dmax_numa_nodes=8 \
         -Dtests=false \
         %{_vpath_builddir}
%meson_build
%__meson install -C %{_vpath_builddir} --no-rebuild

# FIXME currently with LTO enabled OVS tries to link with both static and shared libraries
rm -v %{_builddir}/dpdk-build/%{_lib}/*.so*

# Generate a list of supported drivers, its hard to tell otherwise.
cat << EOF > README.DPDK-PMDS
DPDK drivers included in this package:

EOF

for f in %{_builddir}/dpdk-build/%{_lib}/librte_net_*.a; do
    basename ${f} | cut -c12- | cut -d. -f1 | tr [:lower:] [:upper:]
done >> README.DPDK-PMDS

cat << EOF >> README.DPDK-PMDS

For further information about the drivers, see
http://dpdk.org/doc/guides-%{dpdksver}/nics/index.html
EOF

cd -
%endif    # build dpdk

# And now for OVS...
mkdir build-shared build-static
pushd build-shared
ln -s ../configure
%configure \
%if %{with libcapng}
        --enable-libcapng \
%else
        --disable-libcapng \
%endif
        --disable-static \
        --enable-shared \
        --enable-ssl \
        --with-pkidir=%{_sharedstatedir}/openvswitch/pki \
        --enable-usdt-probes
make %{?_smp_mflags}
popd
pushd build-static
ln -s ../configure
%ifarch %{dpdkarches}
PKG_CONFIG_PATH=%{_builddir}/dpdk-build/%{_lib}/pkgconfig \
%endif
%configure \
%if %{with libcapng}
        --enable-libcapng \
%else
        --disable-libcapng \
%endif
        --enable-ssl \
%ifarch %{dpdkarches}
        --with-dpdk=static \
%endif
        --with-pkidir=%{_sharedstatedir}/openvswitch/pki \
        --enable-usdt-probes
make %{?_smp_mflags}
popd

/usr/bin/python3 build-aux/dpdkstrip.py \
        --dpdk \
        < rhel/usr_lib_systemd_system_ovs-vswitchd.service.in \
        > rhel/usr_lib_systemd_system_ovs-vswitchd.service

%install
rm -rf $RPM_BUILD_ROOT
make -C build-shared install sbin_PROGRAMS=ovsdb/ovsdb-server DESTDIR=$RPM_BUILD_ROOT
make -C build-static install bin_PROGRAMS= sbin_PROGRAMS=vswitchd/ovs-vswitchd DESTDIR=$RPM_BUILD_ROOT

install -d -m 0755 $RPM_BUILD_ROOT%{_rundir}/openvswitch
install -d -m 0750 $RPM_BUILD_ROOT%{_localstatedir}/log/openvswitch
install -d -m 0755 $RPM_BUILD_ROOT%{_sysconfdir}/openvswitch

install -p -D -m 0644 %{SOURCE2} $RPM_BUILD_ROOT%{_sysusersdir}/openvswitch.conf
%ifarch %{dpdkarches}
install -p -D -m 0644 %{SOURCE3} $RPM_BUILD_ROOT%{_sysusersdir}/openvswitch-hugetlbfs.conf
%endif

install -p -D -m 0644 rhel/usr_lib_udev_rules.d_91-vfio.rules \
        $RPM_BUILD_ROOT%{_udevrulesdir}/91-vfio.rules

install -p -D -m 0644 \
        rhel/usr_share_openvswitch_scripts_systemd_sysconfig.template \
        $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/openvswitch

for service in openvswitch ovsdb-server ovs-vswitchd \
               ovs-delete-transient-ports; do
        install -p -D -m 0644 \
                        rhel/usr_lib_systemd_system_${service}.service \
                        $RPM_BUILD_ROOT%{_unitdir}/${service}.service
done

%if %{with ipsec}
install -p -D -m 0644 rhel/usr_lib_systemd_system_openvswitch-ipsec.service \
                      $RPM_BUILD_ROOT%{_unitdir}/openvswitch-ipsec.service
%endif

install -m 0755 rhel/etc_init.d_openvswitch \
        $RPM_BUILD_ROOT%{_datadir}/openvswitch/scripts/openvswitch.init

install -p -D -m 0644 rhel/etc_openvswitch_default.conf \
        $RPM_BUILD_ROOT/%{_sysconfdir}/openvswitch/default.conf

install -p -D -m 0644 rhel/etc_logrotate.d_openvswitch \
        $RPM_BUILD_ROOT/%{_sysconfdir}/logrotate.d/openvswitch

install -m 0644 vswitchd/vswitch.ovsschema \
        $RPM_BUILD_ROOT/%{_datadir}/openvswitch/vswitch.ovsschema

%if 0%{?rhel} < 9
install -d -m 0755 $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/network-scripts/
install -p -m 0755 rhel/etc_sysconfig_network-scripts_ifdown-ovs \
        $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/network-scripts/ifdown-ovs
install -p -m 0755 rhel/etc_sysconfig_network-scripts_ifup-ovs \
        $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/network-scripts/ifup-ovs
%endif

install -d -m 0755 $RPM_BUILD_ROOT%{python3_sitelib}
cp -a $RPM_BUILD_ROOT/%{_datadir}/openvswitch/python/ovstest \
        $RPM_BUILD_ROOT%{python3_sitelib}

# Build the JSON C extension for the Python lib (#1417738)
pushd python
(
export CPPFLAGS="-I ../include -I ../build-shared/include"
export LDFLAGS="%{__global_ldflags} -L $RPM_BUILD_ROOT%{_libdir}"
%py3_build
%py3_install
[ -f "$RPM_BUILD_ROOT/%{python3_sitearch}/ovs/_json$(python3-config --extension-suffix)" ]
)
popd

rm -rf $RPM_BUILD_ROOT/%{_datadir}/openvswitch/python/

install -d -m 0755 $RPM_BUILD_ROOT/%{_sharedstatedir}/openvswitch

install -d -m 0755 $RPM_BUILD_ROOT%{_prefix}/lib/firewalld/services/

install -p -D -m 0755 \
        rhel/usr_share_openvswitch_scripts_ovs-systemd-reload \
        $RPM_BUILD_ROOT%{_datadir}/openvswitch/scripts/ovs-systemd-reload

touch $RPM_BUILD_ROOT%{_sysconfdir}/openvswitch/conf.db
# The db needs special permission as IPsec Pre-shared keys are stored in it.
chmod 0640 $RPM_BUILD_ROOT%{_sysconfdir}/openvswitch/conf.db

touch $RPM_BUILD_ROOT%{_sysconfdir}/openvswitch/system-id.conf

# remove unpackaged files
rm -f $RPM_BUILD_ROOT/%{_bindir}/ovs-benchmark \
        $RPM_BUILD_ROOT/%{_bindir}/ovs-docker \
        $RPM_BUILD_ROOT/%{_bindir}/ovs-parse-backtrace \
        $RPM_BUILD_ROOT/%{_bindir}/ovs-testcontroller \
        $RPM_BUILD_ROOT/%{_sbindir}/ovs-vlan-bug-workaround \
        $RPM_BUILD_ROOT/%{_mandir}/man1/ovs-benchmark.1* \
        $RPM_BUILD_ROOT/%{_mandir}/man8/ovs-testcontroller.* \
        $RPM_BUILD_ROOT/%{_mandir}/man8/ovs-vlan-bug-workaround.8*

%if ! %{with ipsec}
rm -f $RPM_BUILD_ROOT/%{_datadir}/openvswitch/scripts/ovs-monitor-ipsec
%endif

# remove ovn unpackages files
rm -f $RPM_BUILD_ROOT%{_bindir}/ovn*
rm -f $RPM_BUILD_ROOT%{_mandir}/man1/ovn*
rm -f $RPM_BUILD_ROOT%{_mandir}/man5/ovn*
rm -f $RPM_BUILD_ROOT%{_mandir}/man7/ovn*
rm -f $RPM_BUILD_ROOT%{_mandir}/man8/ovn*
rm -f $RPM_BUILD_ROOT%{_datadir}/openvswitch/ovn*
rm -f $RPM_BUILD_ROOT%{_datadir}/openvswitch/scripts/ovn*
rm -f $RPM_BUILD_ROOT%{_includedir}/ovn/*

%check
%if %{with check}
    pushd build-static
    touch resolv.conf
    export OVS_RESOLV_CONF=$(pwd)/resolv.conf
    if make check TESTSUITEFLAGS='%{_smp_mflags}' ||
       make check TESTSUITEFLAGS='--recheck'; then :;
    else
        cat tests/testsuite.log
        exit 1
    fi
    popd
%endif
%if %{with check_datapath_kernel}
    pushd build-static
    if make check-kernel RECHECK=yes; then :;
    else
        cat tests/system-kmod-testsuite.log
        exit 1
    fi
    popd
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%preun
%if 0%{?systemd_preun:1}
    %systemd_preun openvswitch.service
%else
    if [ $1 -eq 0 ] ; then
    # Package removal, not upgrade
        /bin/systemctl --no-reload disable openvswitch.service >/dev/null 2>&1 || :
        /bin/systemctl stop openvswitch.service >/dev/null 2>&1 || :
    fi
%endif

%pre
%sysusers_create_compat %{SOURCE2}
%ifarch %{dpdkarches}
%sysusers_create_compat %{SOURCE3}
%endif

%post
if [ $1 -eq 1 ]; then
    sed -i 's:^#OVS_USER_ID=:OVS_USER_ID=:' /etc/sysconfig/openvswitch

%ifarch %{dpdkarches}
    sed -i \
        's@OVS_USER_ID="openvswitch:openvswitch"@OVS_USER_ID="openvswitch:hugetlbfs"@'\
        /etc/sysconfig/openvswitch
%endif
fi
chown -R openvswitch:openvswitch /etc/openvswitch

%if 0%{?systemd_post:1}
    %systemd_post openvswitch.service
%else
    # Package install, not upgrade
    if [ $1 -eq 1 ]; then
        /bin/systemctl daemon-reload >dev/null || :
    fi
%endif

%postun
%if 0%{?systemd_postun:1}
    %systemd_postun openvswitch.service
%else
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
%endif

%triggerun -- openvswitch < 2.5.0-22.git20160727%{?dist}
# old rpm versions restart the service in postun, but
# due to systemd some preparation is needed.
if systemctl is-active openvswitch >/dev/null 2>&1 ; then
    /usr/share/openvswitch/scripts/ovs-ctl stop >/dev/null 2>&1 || :
    systemctl daemon-reload >/dev/null 2>&1 || :
    systemctl stop openvswitch ovsdb-server ovs-vswitchd >/dev/null 2>&1 || :
    systemctl start openvswitch >/dev/null 2>&1 || :
fi
exit 0

%files -n python3-%{pkgname}
%{python3_sitearch}/ovs
%{python3_sitearch}/ovs-*.egg-info
%doc LICENSE

%files test
%{_bindir}/ovs-pcap
%{_bindir}/ovs-tcpdump
%{_bindir}/ovs-tcpundump
%{_mandir}/man1/ovs-pcap.1*
%{_mandir}/man8/ovs-tcpdump.8*
%{_mandir}/man1/ovs-tcpundump.1*
%{_bindir}/ovs-test
%{_bindir}/ovs-vlan-test
%{_bindir}/ovs-l3ping
%{_mandir}/man8/ovs-test.8*
%{_mandir}/man8/ovs-vlan-test.8*
%{_mandir}/man8/ovs-l3ping.8*
%{python3_sitelib}/ovstest

%files devel
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/openvswitch/*
%{_includedir}/openflow/*
%exclude %{_libdir}/*.a
%exclude %{_libdir}/*.la

%if 0%{?rhel} == 8 || 0%{?fedora} > 28
%files -n network-scripts-%{name}
%{_sysconfdir}/sysconfig/network-scripts/ifup-ovs
%{_sysconfdir}/sysconfig/network-scripts/ifdown-ovs
%endif

%files
%defattr(-,openvswitch,openvswitch)
%dir %{_sysconfdir}/openvswitch
%{_sysconfdir}/openvswitch/default.conf
%config %ghost %verify(not owner group md5 size mtime) %{_sysconfdir}/openvswitch/conf.db
%ghost %attr(0600,-,-) %verify(not owner group md5 size mtime) %{_sysconfdir}/openvswitch/.conf.db.~lock~
%config %ghost %{_sysconfdir}/openvswitch/system-id.conf
%defattr(-,root,root)
%config(noreplace) %verify(not md5 size mtime) %{_sysconfdir}/sysconfig/openvswitch
%{_sysconfdir}/bash_completion.d/ovs-appctl-bashcomp.bash
%{_sysconfdir}/bash_completion.d/ovs-vsctl-bashcomp.bash
%config(noreplace) %{_sysconfdir}/logrotate.d/openvswitch
%{_unitdir}/openvswitch.service
%{_unitdir}/ovsdb-server.service
%{_unitdir}/ovs-vswitchd.service
%{_unitdir}/ovs-delete-transient-ports.service
%{_datadir}/openvswitch/scripts/openvswitch.init
%{_datadir}/openvswitch/scripts/ovs-check-dead-ifs
%{_datadir}/openvswitch/scripts/ovs-lib
%{_datadir}/openvswitch/scripts/ovs-save
%{_datadir}/openvswitch/scripts/ovs-vtep
%{_datadir}/openvswitch/scripts/ovs-ctl
%{_datadir}/openvswitch/scripts/ovs-kmod-ctl
%{_datadir}/openvswitch/scripts/ovs-systemd-reload
%config %{_datadir}/openvswitch/local-config.ovsschema
%config %{_datadir}/openvswitch/vswitch.ovsschema
%config %{_datadir}/openvswitch/vtep.ovsschema
%{_bindir}/ovs-appctl
%{_bindir}/ovs-dpctl
%{_bindir}/ovs-ofctl
%{_bindir}/ovs-vsctl
%{_bindir}/ovsdb-client
%{_bindir}/ovsdb-tool
%{_bindir}/ovs-pki
%{_bindir}/vtep-ctl
%{_libdir}/*.so.*
%{_sbindir}/ovs-vswitchd
%{_sbindir}/ovsdb-server
%{_mandir}/man1/ovsdb-client.1*
%{_mandir}/man1/ovsdb-server.1*
%{_mandir}/man1/ovsdb-tool.1*
%{_mandir}/man5/ovsdb.5*
%{_mandir}/man5/ovsdb.local-config.5*
%{_mandir}/man5/ovsdb-server.5.*
%{_mandir}/man5/ovs-vswitchd.conf.db.5*
%{_mandir}/man5/vtep.5*
%{_mandir}/man7/ovsdb-server.7*
%{_mandir}/man7/ovsdb.7*
%{_mandir}/man7/ovs-actions.7*
%{_mandir}/man7/ovs-fields.7*
%{_mandir}/man8/vtep-ctl.8*
%{_mandir}/man8/ovs-appctl.8*
%{_mandir}/man8/ovs-ctl.8*
%{_mandir}/man8/ovs-dpctl.8*
%{_mandir}/man8/ovs-kmod-ctl.8.*
%{_mandir}/man8/ovs-ofctl.8*
%{_mandir}/man8/ovs-pki.8*
%{_mandir}/man8/ovs-vsctl.8*
%{_mandir}/man8/ovs-vswitchd.8*
%{_mandir}/man8/ovs-parse-backtrace.8*
%{_udevrulesdir}/91-vfio.rules
%doc LICENSE NOTICE README.rst NEWS rhel/README.RHEL.rst
%ifarch %{dpdkarches}
%doc %{dpdkdir}/README.DPDK-PMDS
%attr(750,openvswitch,hugetlbfs) %verify(not owner group) /var/log/openvswitch
%else
%attr(750,openvswitch,openvswitch) %verify(not owner group) /var/log/openvswitch
%endif
/var/lib/openvswitch
%ghost %attr(755,root,root) %verify(not owner group) %{_rundir}/openvswitch
%{_datadir}/openvswitch/bugtool-plugins/
%{_datadir}/openvswitch/scripts/ovs-bugtool-*
%{_bindir}/ovs-dpctl-top
%{_sbindir}/ovs-bugtool
%{_mandir}/man8/ovs-dpctl-top.8*
%{_mandir}/man8/ovs-bugtool.8*
%if (0%{?rhel} && 0%{?rhel} <= 7) || (0%{?fedora} && 0%{?fedora} < 29)
%{_sysconfdir}/sysconfig/network-scripts/ifup-ovs
%{_sysconfdir}/sysconfig/network-scripts/ifdown-ovs
%endif
%{_sysusersdir}/openvswitch.conf
%ifarch %{dpdkarches}
%{_sysusersdir}/openvswitch-hugetlbfs.conf
%endif

%if %{with ipsec}
%files ipsec
%{_datadir}/openvswitch/scripts/ovs-monitor-ipsec
%{_unitdir}/openvswitch-ipsec.service
%endif

%changelog
* Wed Oct 30 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-172
- Merging upstream branch-2.17 [RH git: 392b856fa5]
    Commit list:
    ffd3e3b8ff meta-flow: Fix nw_frag mask while parsing from string.
    c5bd6ef65c github: Remove ASLR entropy workaround.
    da548a502d bond: Always revalidate unbalanced bonds when active member changes. (FDP-845)


* Wed Oct 30 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-171
- Merging dpdk subtree [RH git: 22842e4be1]
    Commit list:
    551d7da597 Merge tag 'v21.11.8' into 21.11
    d20fd65f25 version: 21.11.8
    ced6fe6d45 kni: use strscpy
    617f9462c1 net/softnic: fix maybe-uninitialized warning
    680818068d version: 21.11.8-rc1
    06a1fb9ff4 app/testpmd: fix interactive mode on Windows
    37408e6b7a app/testpmd: fix early exit from signal
    8211aee58f app/testpmd: cleanup cleanly from signal
    678229914e doc: fix mbuf flags
    764432d99c net/ena: fix checksum handling
    6059b6a729 dma/idxd: fix setup with Ubuntu 24.04
    24e7731981 dma/idxd: add verbose option to config script
    699d2b93fa dma/idxd: fix default for workqueue options
    07a19a205d dma/idxd: add generic option for queue config
    82c2a85726 net: fix outer UDP checksum in Intel prepare helper
    9290e6ebc7 ethdev: fix device init without socket-local memory
    77d08c98e7 test/crypto: remove unused stats in setup
    a46619d81e config: fix warning for cross build with meson >= 1.3.0
    9234d31785 doc: add baseline mode in l3fwd-power guide
    bee1b4cf67 doc: remove reference to mbuf pkt field
    b1b0e806ec net/ice/base: fix temporary failures reading NVM
    2a885993dc net/hns3: fix uninitialized variable in FEC query
    7da32cce88 bus/vdev: fix device reinitialization
    cb6ae8135d malloc: fix multi-process wait condition handling
    502c8f0344 app/pdump: handle SIGTERM and SIGHUP
    d2c2fc4709 app/dumpcap: handle SIGTERM and SIGHUP
    b898d9edce bus/pci: fix FD in secondary process
    4231013b08 bus/pci: fix UIO resource mapping in secondary process
    e3c5d1f39c app/testpmd: fix build on signed comparison
    a76b81f212 ethdev: fix GENEVE option item conversion
    8ef004bdde net/ark: fix index arithmetic
    df1ab1523a net/hns3: check Rx DMA address alignmnent
    791fb23625 common/mlx5: remove unneeded field when modify RQ table
    f40768049f net/mlx5: fix uplink port probing in bonding mode
    b0ab250b5c net/mlx5: fix end condition of reading xstats
    4032e7572a net/mlx5: fix MTU configuration
    24fc9686af net/mlx5: fix Arm build with GCC 9.1
    525eee1f7e net/ice: fix return value for raw pattern parsing
    62d214cef7 net/ice: fix memory leaks in raw pattern parsing
    f7da9791b7 test/crypto: fix asymmetric capability test
    00d901b2fc doc: fix typo in l2fwd-crypto guide
    02bda04ec3 test/crypto: fix allocation comment
    44b500589c net/nfp: fix disabling 32-bit build
    e4e2cbbdbd net/ena: fix return value check
    b4b2b2dbc8 net/ena: fix bad checksum handling
    f7072b7cac net/vmxnet3: fix init logs
    5cdda1dc0b net/txgbe: fix Rx interrupt
    e2b706371f net/ngbe: fix memory leaks
    45e7c92c6f net/txgbe: fix memory leaks
    adffa231be net/ngbe: fix MTU range
    d5ca03a046 net/txgbe: fix MTU range
    71944f455d net/ngbe: fix hotplug remove
    a6e71f39cc net/txgbe: fix hotplug remove
    c7640d6f91 net/ngbe: keep PHY power down while device probing
    d7774d77a5 net/txgbe: fix VF promiscuous and allmulticast
    06c7322fce net/txgbe: reconfigure more MAC Rx registers
    5d3adce6c8 net/txgbe: restrict configuration of VLAN strip offload
    ee5d65c322 net/txgbe: fix Tx hang on queue disable
    b1e9d2e692 net/txgbe: fix flow filters in VT mode
    6d3c1dfd5f net/txgbe: fix tunnel packet parsing
    5d16a5c0b0 app/testpmd: fix parsing for connection tracking item
    3fc3956874 app/testpmd: handle IEEE1588 init failure
    7cf71d7715 net/ice/base: fix masking when reading context
    f93aad91e0 net/ice/base: fix board type definition
    8452229f93 net/ice/base: fix potential TLV length overflow
    041079fd49 net/ice/base: fix check for existing switch rule
    ad10a87ffd net/ice/base: fix return type of bitmap hamming weight
    dd51a93ab6 net/ice/base: fix GCS descriptor field offsets
    bd46ca68c1 net/ice/base: fix size when allocating children arrays
    ffa6d84d02 net/ice/base: fix sign extension
    1b20f194b2 net/ice/base: fix pointer to variable outside scope
    e6b69e13c8 buildtools: fix build with clang 17 and ASan
    1e00bb1fb1 fbarray: fix finding for unaligned length
    728048cc94 bus/dpaa: remove redundant file descriptor check
    9fe819e421 common/dpaax: fix node array overrun
    5ab7860c51 common/dpaax: fix IOVA table cleanup
    e46935eae4 bus/dpaa: fix memory leak in bus scan
    373efadc5f bus/dpaa: fix bus scan for DMA devices
    23be36e929 app/testpmd: fix help string of BPF load command
    2de908abe1 eal/linux: lower log level on allocation attempt failure
    33db9b4509 fbarray: fix lookbehind ignore mask handling
    85308d31b1 fbarray: fix lookahead ignore mask handling
    313de37f27 fbarray: fix incorrect lookbehind behavior
    16039f57ff fbarray: fix incorrect lookahead behavior
    a16a1a7267 crypto/dpaa2_sec: fix event queue user context
    4d95152c91 common/dpaax/caamflib: fix PDCP AES-AES watchdog error
    b3f493cc72 common/dpaax/caamflib: fix PDCP-SDAP watchdog error
    3e1ff62d6d crypto/openssl: optimize 3DES-CTR context init
    6a46407ad7 cryptodev: validate crypto callbacks from next node
    a27e346a93 cryptodev: fix build without crypto callbacks
    87bdd9a583 crypto/cnxk: fix minimal input normalization
    f7e28211b7 baseband/la12xx: forbid secondary process
    38c54ad34e telemetry: fix connection parameter parsing
    7598b5b537 bpf: fix load hangs with six IPv6 addresses
    89a1505c5a bpf: fix MOV instruction evaluation
    e296365eb4 vdpa/sfc: remove dead code
    2c3f6129d9 dmadev: fix structure alignment
    967cb3d5bd app/bbdev: fix interrupt tests
    90859e988c telemetry: lower log level on socket error
    2a597e9f8b net/mlx5: fix hash Rx queue release in flow sample
    ac5f04c92a net/mlx5: fix indexed pool with invalid index
    1940acf81d common/mlx5: fix unsigned/signed mismatch
    f12baa45c9 hash: fix RCU reclamation size
    6fa9a2e32d net/cnxk: fix promiscuous state after MAC change
    9c45669c03 net/cnxk: fix outbound security with higher packet burst
    d8a3470e22 net/cnxk: fix RSS config
    2070487977 net/ixgbe/base: fix PHY ID for X550
    ea2d868cc5 net/ixgbe/base: fix 5G link speed reported on VF
    2b53ce832b net/ixgbe/base: revert advertising for X550 2.5G/5G
    f7f0ac1a36 net/e1000/base: fix link power down
    f6e83fa8b3 net/ixgbe: do not create delayed interrupt handler twice
    1d72c06705 net/ixgbe: do not update link status in secondary process
    7a97a44a0a net/fm10k: fix cleanup during init failure
    1f57a72efc eal: fix logs for '--lcores'
    4722e89fcd event/sw: fix warning from useless snprintf
    8863a119d0 net/virtio: fix MAC table update
    1a7bda79d1 vhost: cleanup resubmit info before inflight setup
    2f6234f1d9 vhost: fix build with GCC 13
    8a77d04eb3 hash: check name when creating a hash
    bb01e07f1d hash: fix return code description in Doxygen
    8e20d5d780 app/testpmd: fix lcore ID restriction
    d6ec78819d net/i40e: fix outer UDP checksum offload for X710
    ce87e585c5 app/testpmd: fix outer IP checksum offload
    c5411472c3 net/ice: fix check for outer UDP checksum offload
    c2baa4b8da net/axgbe: fix linkup in PHY status
    63539e77be net/axgbe: delay AN timeout during KR training
    d168063444 net/axgbe: fix Tx flow on 30H HW
    1f85d756aa net/axgbe: check only minimum speed for cables
    3fe8271448 net/axgbe: fix connection for SFP+ active cables
    35429aa99d net/axgbe: fix SFP codes check for DAC cables
    a14247758a net/axgbe: disable interrupts during device removal
    ef8e4aa855 net/axgbe: update DMA coherency values
    8d53ecbbf6 net/axgbe: fix fluctuations for 1G Bel Fuse SFP
    4615048c8a net/axgbe: reset link when link never comes back
    8eeb4d4534 net/axgbe: fix MDIO access for non-zero ports and CL45 PHYs
    a599aacf12 net/tap: fix file descriptor check in isolated flow
    6825397cf6 net/af_xdp: count mbuf allocation failures
    6d6630439d net/af_xdp: fix port ID in Rx mbuf
    9b8ca61893 doc: fix testpmd ring size command
    858c31a501 net/af_packet: align Rx/Tx structs to cache line
    8fb5749bc6 net/hns3: disable SCTP verification tag for RSS hash input
    2cd371c2b2 net/hns3: fix variable overflow
    46ac5a94ba net/hns3: fix double free for Rx/Tx queue
    7d93896c26 net/hns3: fix Rx timestamp flag
    4b362a6ca1 net/hns3: fix offload flag of IEEE 1588
    024e9662e7 latencystats: fix literal float suffix
    caed4d5e2d eal/windows: install sched.h file
    bd0e650520 net/virtio-user: add memcpy check
    d00c004916 pcapng: add memcpy check
    87e7322144 eal/unix: support ZSTD compression for firmware
    a7fb1c9784 bus/pci: fix build with musl 1.2.4 / Alpine 3.19
    b40fd60a9d test/crypto: fix vector global buffer overflow
    49b2102bf9 version: 21.11.7
    e9b8b369de version: 21.11.7-rc1
    adfa4b4d0c net/hns3: refactor handle mailbox function
    a38893de7d net/hns3: refactor send mailbox function
    465327ef11 net/nfp: fix Rx and Tx queue state
    8f8564ff2c net/axgbe: fix Rx and Tx queue state
    b42960b1d7 net/af_xdp: fix leak on XSK configuration failure
    d13f7b11d4 crypto/ipsec_mb: fix incorrectly setting cipher keys
    6be826afff net/nfp: fix resource leak for PF initialization
    aa99de9993 examples/ipsec-secgw: fix typo in error message
    c6ab7f7241 test/cfgfile: fix typo in error messages
    6e0fe10015 test/power: fix typo in error message
    fe97b1e3ed doc: fix typo in packet framework guide
    13e54713ae doc: fix typo in profiling guide
    2ee1c55567 net/vmxnet3: ignore Rx queue interrupt setup on FreeBSD
    46f9124cae doc: fix default IP fragments maximum in programmer guide
    0bcf927db2 net/bnxt: fix number of Tx queues being created
    307a7cc705 net/mlx5: fix warning about copy length
    61aa88de54 net/mlx5: fix drop action release timing
    165b252b21 net/mlx5: fix age position in hairpin split
    eadfb0fbb8 net/mlx5: prevent ioctl failure log flooding
    123f0bcf24 doc: update link to Windows DevX in mlx5 guide
    95826daab3 net/hns3: support new device
    300a10e4d3 app/testpmd: fix --stats-period option check
    4db5876a5e net/ena/base: restructure interrupt handling
    cb98b1b26d net/ena/base: limit exponential backoff
    b063b49cf4 doc: add link speeds configuration in features table
    4a74870ae4 doc: add traffic manager in features table
    5c731f2f53 net/hns3: enable PFC for all user priorities
    8f34999c24 examples/l3fwd: fix Rx over not ready port
    6241c4f334 examples/packet_ordering: fix Rx with reorder mode disabled
    da59128c3f test: do not count skipped tests as executed
    30c9214352 test/mbuf: fix external mbuf case with assert enabled
    617bccf412 config: fix CPU instruction set for cross-build
    bf8fb07ca7 test: fix probing in secondary process
    2481136319 net/mlx5: fix counters map in bonding mode
    03c7f0a177 net/mlx5: fix VLAN handling in meter split
    c52e6e0ecd net/mlx5: fix error packets drop in regular Rx
    411422bb04 net/mlx5: fix use after free when releasing Tx queues
    2556c23922 common/cnxk: fix possible out-of-bounds access
    22c015d09d common/cnxk: fix mbox struct attributes
    ed1fd02bd4 common/cnxk: fix RSS RETA configuration
    92f6f10e9d net/cnxk: fix MTU limit
    603e63f7a6 common/cnxk: fix Tx MTU configuration
    61ced40b0d net/bnx2x: fix warnings about memcpy lengths
    d8f8df9c46 net/ice: remove incorrect 16B descriptor read block
    dcf42c72bc net/iavf: remove incorrect 16B descriptor read block
    007b1f1ad7 net/i40e: remove incorrect 16B descriptor read block
    4a95397cc0 net/ixgbe: increase VF reset timeout
    22e7e531ce net/iavf: remove error logs for VLAN offloading
    153ce28fcf net/ixgbevf: fix RSS init for x550 NICs
    1de0e75b7b net/bnxt: fix null pointer dereference
    6131c863c8 net/tap: fix traffic control handle calculation
    f87697c6ad net/tap: do not overwrite flow API errors
    4e761a47ab doc: fix typos in cryptodev overview
    c5d16ff345 app/crypto-perf: add missing op resubmission
    51cdf41427 app/crypto-perf: fix out-of-place mbuf size
    c735ad16ff eventdev: fix Doxygen processing of vector struct
    5730dc49ba eventdev: improve Doxygen comments on configure struct
    34342122cd test/event: fix crash in Tx adapter freeing
    c87e76f66b event/dlb2: remove superfluous memcpy
    c2671c9adf doc: fix configuration in baseband 5GNR driver guide
    a5224aa517 telemetry: fix empty JSON dictionaries
    1af693e007 telemetry: fix connected clients count
    40625500ac net/mlx5: fix stats query crash in secondary process
    83738589f7 common/mlx5: fix duplicate read of general capabilities
    5c8bbc6b7d net/mlx5: fix GENEVE TLV option management
    9fe858d7b9 net/mlx5: fix jump action validation
    79c2b508d9 common/cnxk: fix mbox region copy
    5a59e070c0 net/cnxk: fix flow RSS configuration
    638141e6c5 net/bnxt: fix deadlock in ULP timer callback
    659e7c7b2d net/bnxt: modify locking for representor Tx
    f7380ba809 net/bnxt: fix backward firmware compatibility
    c208fb7ed9 net/bnxt: fix speed change from 200G to 25G on Thor
    e3391de3f7 net/bnxt: fix 50G and 100G forced speed
    f6e8248127 net/bnxt: fix array overflow
    7d331e7bd1 net/netvsc: fix VLAN metadata parsing
    d100a5e796 net: add macros for VLAN metadata parsing
    18fb9b63a8 net/memif: fix extra mbuf refcnt update in zero copy Tx
    82aea5d9b4 common/sfc_efx/base: use C11 static assert
    3b7cc646a9 net/ionic: fix device close
    bee2ac7906 net/ionic: fix RSS query
    04fb58b84f app/testpmd: fix crash in multi-process forwarding
    15d533ce94 drivers/net: fix buffer overflow for packet types list
    be2dc69e86 net/vmxnet3: fix initialization on FreeBSD
    2597a7df7c app/testpmd: hide --bitrate-stats in help if disabled
    e690cae685 doc: add --latencystats option in testpmd guide
    d2d6bdae86 net/hns3: remove QinQ insert support for VF
    51fd05c6ad net/hns3: fix reset level comparison
    a327482169 net/hns3: fix disable command with firmware
    72126b1d1c net/hns3: fix VF multiple count on one reset
    9b6c3117a1 net/hns3: refactor PF mailbox message struct
    8b31b47194 net/hns3: refactor VF mailbox message struct
    13696b1aa8 net/af_xdp: fix memzone leak on config failure
    b886b2c079 ethdev: fix NVGRE encap flow action description
    b1d48396f2 doc: fix commands in eventdev test tool guide
    15d001811d test/event: skip test if no driver is present
    d84482b4ce event/cnxk: fix dequeue timeout configuration
    33266c1331 app/crypto-perf: fix encrypt operation verification
    4fe2036cef app/crypto-perf: fix data comparison
    fa23c86e34 app/crypto-perf: fix next segment mbuf
    aed510b37c common/cnxk: fix memory leak in CPT init
    7683a75096 cryptodev: remove unused extern variable
    b3ec4db23d vhost: fix memory leak in Virtio Tx split path
    15afe0935f vhost: fix deadlock during vDPA SW live migration
    519dd4c280 net/virtio: remove duplicate queue xstats
    7293e69ddf vhost: fix virtqueue access check in vhost-user setup
    d27dfc1a75 build: fix linker warnings about undefined symbols
    8fd1646a47 net/nfp: fix calloc parameters
    59160624f8 net/bnx2x: fix calloc parameters
    bb4eb1f8fc common/mlx5: fix calloc parameters
    f6975c91bc examples/qos_sched: fix memory leak in args parsing
    f30f9a3c5e test: verify strdup return
    868c62ad59 app/crypto-perf: verify strdup return
    268ceff07f app/pdump: verify strdup return
    59b5633558 app/dumpcap: verify strdup return
    b8422c5011 net/failsafe: fix memory leak in args parsing
    bb7030a551 event/cnxk: verify strdup return
    93cc8c419f dma/idxd: verify strdup return
    fa4c241ce7 bus/vdev: verify strdup return
    5a753bd6dd bus/fslmc: verify strdup return
    f128469220 bus/dpaa: verify strdup return
    7fc3309c5d eal: verify strdup return
    83776248bc eal/x86: add AMD vendor check for TSC calibration
    100a4dc25e ci: update versions of actions in GHA
    7f994fccfe kernel/freebsd: fix module build on FreeBSD 14
    c354880dcf net/ice: fix tunnel TSO capabilities
    78c0d6dd0b net/ice: fix link update
    4f2f83c0a6 net/ixgbe: fix memoy leak after device init failure
    835b8ab53c net/iavf: fix memory leak on security context error
    3c1d8f321d net/i40e: remove redundant judgment in flow parsing
    570eff65fd regexdev: fix logtype register
    014409d9f3 hash: remove some dead code


* Tue Oct 22 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-170
- Merging upstream branch-2.17 [RH git: 2a7416e996]
    Commit list:
    efcae5fcae dpdk: Use DPDK 21.11.8 release for OVS 2.17.


* Fri Sep 20 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-169
- Merging upstream branch-2.17 [RH git: 242e9035f1]
    Commit list:
    a31060e609 selinux: Update policy file.


* Fri Sep 20 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-168
- Merging upstream branch-2.17 [RH git: 683255f9ce]
    Commit list:
    72da322f89 ofproto-dpif-mirror: Always revalidate on mirror update. (FDP-788)


* Mon Sep 16 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-167
- Merging upstream branch-2.17 [RH git: 74a1b04bfd]
    Commit list:
    07889466b9 vconn: Always properly free flow stats reply.
    f0676dbf46 mcast-snooping: Properly check group_get_lru return code.
    c70944c770 ovsdb-idl: Fix IDL memory leak.
    d7cbc67deb ofproto/bond: Preserve active bond member over restarts.
    ce789d991f ofproto-dpif-upcall: Avoid stale ukeys leaks.


* Tue Aug 27 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-166
- Merging upstream branch-2.17 [RH git: 5b1cb9f5a6]
    Commit list:
    fecbba4bc0 Prepare for 2.17.12.
    394ba58edf Set release date for 2.17.11.


* Wed Aug 14 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-165
- Merging upstream branch-2.17 [RH git: b3a4017d60]
    Commit list:
    05bdf2a252 netdev-linux: Fix unaligned access to rpl_rtnl_link_stats64.
    dd91419654 route-table: Fix another UBsan warning about pointer type.


* Thu Aug 08 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-164
- Merging upstream branch-2.17 [RH git: 5ee5dc9357]
    Commit list:
    5fb3bbd361 netdev-dpdk: Fix race condition in mempool information dump.
    46a0eaad43 ovsdb: transaction: Remove incorrect transaction abort in pre-commit.


* Fri Jul 19 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-163
- Merging upstream branch-2.17 [RH git: 3f4a02107e]
    Commit list:
    721273612d netlink-notifier: Silence the UBsan's function pointer mismatch error.


* Fri Jul 19 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-162
- Merging upstream branch-2.17 [RH git: 438cef1ebb]
    Commit list:
    a241f77650 Documentation: Update QEMU documentation URLs.
    7b58b6f93d match: Fix false-positive snprintf size warning.
    d548506ff1 util: Add non-NULL format assertion to xvasprintf.
    49e28efb1e flow: Fix unaligned access to the ND target in miniflow_extract.
    f3d5ce5fad dpif-netlink-rtnl: Fix netdev leak in out-of-tree tunnels probe.


* Wed Jul 17 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-161
- Merging upstream branch-2.17 [RH git: 5a72905640]
    Commit list:
    d7fa3c3ff6 dpctl: Fix netdev reference leak in "show" command.


* Wed Jul 03 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-160
- Merging upstream branch-2.17 [RH git: 742489606c]
    Commit list:
    5c20050300 cirrus: Update to FreeBSD 14.1.


* Wed Jun 19 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-159
- Merging upstream branch-2.17 [RH git: 1f8a72dac2]
    Commit list:
    1bd8526818 dpdk: Check other_config:dpdk-extra for '--lcores'.


* Fri Jun 07 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-158
- Merging upstream branch-2.17 [RH git: ed8dddd40b]
    Commit list:
    1f0344ed01 Prepare for 2.17.11.
    ab673c7a90 Set release date for 2.17.10.


* Fri Jun 07 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-157
- Merging upstream branch-2.17 [RH git: 76a0a4340b]
    Commit list:
    f050ccc006 python: idl: Fix index not being updated on row modification.


* Wed Jun 05 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-156
- Merging upstream branch-2.17 [RH git: 72ac71bb0c]
    Commit list:
    3930bc7446 nsh: Add support to compose-packet and use it in system tests.
    ef39373fd1 tests: Convert ND, MPLS and CT sendpkt tests to compose-packet.
    244f90d559 tests: sendpkt: Allow different input formats.
    171398797b ovs-ofctl: Implement compose-packet --bare.
    526044b56d ipf: Handle common case of ipf defragmentation.
    d9465f907e ipf: Only add fragments to batch of same dl_type.


* Mon Jun 03 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-155
- Merging upstream branch-2.17 [RH git: 277e5df78d]
    Commit list:
    f924527d97 tests: Fix non-portable plus match in python vlog test.


* Thu May 30 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-154
- Merging upstream branch-2.17 [RH git: c63aeab455]
    Commit list:
    628ccf2c67 dpdk: Use DPDK 21.11.7 release for OVS 2.17.


* Tue May 28 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-153
- Merging upstream branch-2.17 [RH git: 563361db7c]
    Commit list:
    9dc9ad38ba socket: Fix uninitialized values in inet_parse_ functions.
    adc851604e dpctl: Fix uninitialized value when deleting flows.


* Fri May 17 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-152
- Merging upstream branch-2.17 [RH git: 9ce5325f9a]
    Commit list:
    9468d54d01 compiler: Fix errors in Clang 17 ubsan checks.
    f23b1e500a table: Fix freeing global variable.
    a6f9175aee vlog: Destroy async_append first then close log_fd.


* Tue May 14 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-151
- Merging upstream branch-2.17 [RH git: b4f6b6d488]
    Commit list:
    c553026ecd conntrack: Fully initialize conn struct before insertion.
    966ed838e3 conntrack: Do not use {0} to initialize unions.


* Tue May 07 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-150
- Merging upstream branch-2.17 [RH git: b910c875a6]
    Commit list:
    d1a2af7c33 ovsdb-client: Add missing arg to help for 'dump'.


* Fri May 03 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-149
- Merging upstream branch-2.17 [RH git: 699bf5d1d9]
    Commit list:
    9d0de176c7 ofproto-dpif-trace: Fix access to an out-of-scope stack memory.
    bd020fba03 hash, jhash: Fix unaligned access to the hash remainder.
    78ea43c71c sparse: Add additional define for sparse on GCC >= 14.


* Tue Apr 30 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-148
- Merging upstream branch-2.17 [RH git: 30aa1c5a97]
    Commit list:
    755b66f68e sparse: Add immintrin.h header.
    c029de2482 tc: Fix -Wgnu-variable-sized-type-not-at-end warning with Clang 18.
    0efdca5d34 tests: Fix build failure with Clang 18 due to -Wformat-truncation.


* Wed Apr 24 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-147
- Merging upstream branch-2.17 [RH git: 82345a570a]
    Commit list:
    b2e1911039 netdev-dpdk: Fix possible memory leak configuring VF MAC address.


* Tue Apr 23 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-146
- Merging upstream branch-2.17 [RH git: 73aa27fc83]
    Commit list:
    091961542a ovsdb: raft: Fix probe intervals after install snapshot request.
    15720a3e24 ovsdb: raft: Fix inability to join a cluster with a large database.
    856cf68bca rhel/systemd: Set ovsdb-server timeout to 5 minutes.


* Thu Apr 11 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-145
- Merging upstream branch-2.17 [RH git: 8bc38e6a6d]
    Commit list:
    1fe98e41f0 github: Update python to 3.12.
    ae67980c00 ovsdb-dot: Fix flake8 issues.
    143fdbaeb5 ovsdb-doc: Fix syntax warning with Python 3.12 and flake8 issues.


* Wed Apr 10 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-144
- Merging upstream branch-2.17 [RH git: 9fd3b72efa]
    Commit list:
    e4d61152f8 python: Remove hacking dependency and use recent flake8.
    69687ac1b2 cirrus: Update to FreeBSD 13.3.
    10588fed09 xenserver: Fix tests with Python 3.12.
    fc2b1ad3d4 tests: Fix compatibility issue with Python 3.13 in vlog.at.


* Fri Apr 05 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-143
- Merging upstream branch-2.17 [RH git: 8705b676b4]
    Commit list:
    74875da782 ofproto-dpif-upcall: Fix ukey installation failure logs and counters.


* Wed Apr 03 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-142
- Merging upstream branch-2.17 [RH git: b241a6e150]
    Commit list:
    915d3c1ae5 conntrack: Do not use icmp reverse helper for icmpv6.
    13678cfab7 conntrack: Fix SNAT with exhaustion system test.


* Wed Mar 27 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-141
- Merging upstream branch-2.17 [RH git: fad2352a11]
    Commit list:
    1d740ed1b8 ovsdb: raft: Fix inability to join after leadership change round trip.
    7065ac8e10 ovsdb: raft: Fix permanent joining state on a cluster member.
    1aa302fb5e ovsdb: raft: Avoid transferring leadership to unavailable servers.


* Wed Mar 27 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-140
- Merging upstream branch-2.17 [RH git: 5afafcd521]
    Commit list:
    30ea1ecc3e ofproto-dpif-xlate: Fix continuations with associated metering.


* Fri Mar 22 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-139
- Merging upstream branch-2.17 [RH git: 59a9b59378]
    Commit list:
    c0f0426195 ovs-monitor-ipsec: LibreSwan autodetect paths. (#1975039)
    f913a4c78b route-table: Avoid routes from non-standard routing tables.


* Tue Mar 19 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-138
- Merging upstream branch-2.17 [RH git: f42943f2f2]
    Commit list:
    2c1b9e9cee ofproto-dpif: Fix tunnel with different name del/add failure.
    019e545ba8 ofpbuf: Prevent undefined behavior in ofpbuf_clone.
    1a5f056303 github: Reduce ASLR entropy to be compatible with asan in llvm 14.
    adcb870d1a bfd: Improve state change log message. (#2258496)
    f9602296a9 tests: Fix "SSL db: Implementation" test with openssl > 3.2.0.
    ee8485227f conntrack: Fix flush not flushing all elements.


* Wed Mar 13 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-137
- Merging dpdk subtree [RH git: 6388f9648e]
    Commit list:
    856b38dbd3 Merge tag 'v21.11.6' into 21.11
    48ac0a964f Reapply "net/iavf: fix abnormal disable HW interrupt"
    181fb849b5 version: 21.11.6
    1aa6eccdc8 Merging upstream branch-2.17
    ef39402104 Merging upstream branch-2.17
    f082ed71cc Merging upstream branch-2.17
    598acceb55 Merging upstream branch-2.17
    bbc9320caf version: 21.11.6-rc1
    fc1c14ba87 Revert "net/iavf: fix abnormal disable HW interrupt"
    b655b64158 Revert "net/iavf: fix abnormal disable HW interrupt"
    770e7c2724 net/af_xdp: make compatible with libbpf 0.8.0
    9bb15a3d0f net/hns3: fix VF reset handler interruption
    90236089a2 net/hns3: fix reset event status
    0dece2892b net/hns3: fix ignored reset event
    f2151f9aa0 ethdev: fix ESP packet type description
    6faf898f55 mempool: clarify enqueue/dequeue ops documentation
    1699794ad5 mempool: fix get function documentation
    69793a2e87 doc: remove number of commands in vDPA guide
    82a6991ac2 doc: fix some ordered lists
    f8a3dcb22d doc: remove restriction on ixgbe vector support
    8633f55ed5 Merging upstream branch-2.17
    88bee6c641 Merging 4e50ad4469 version: 21.11.5
    c83e88b939 Merging upstream branch-2.17
    2b8325631a Merging upstream branch-2.17
    9a6c6fad1b Merging upstream branch-2.17
    fab24e72ab app/pipeline: add sigint handler
    25bb8f090e test/hash: fix creation error log
    83eafb9441 examples/ethtool: fix pause configuration
    952d702879 app/dumpcap: allow multiple invocations
    c9a8aa95de pdump: fix error number on IPC response
    b2d5c193df eal/windows: fix build with recent MinGW
    e39929c868 examples/ipsec-secgw: fix partial overflow
    25bd80cff6 doc: update versions recommendations for i40e and ice
    3840836817 doc: fix RSS flow description in hns3 guide
    326b4f1213 doc: update features in hns3 guide
    dded07195d doc: fix hns3 build option about max queue number
    d549330dfc net/txgbe: fix out of bound access
    45cef8185a vhost: fix missing lock protection in power monitor API
    9b63dd4599 net/virtio: fix descriptor addresses in 32-bit build
    93f0406998 net/hns3: fix crash for NEON and SVE
    662c60a322 net/hns3: fix LRO offload to report
    7d54c473db net/hns3: fix setting DCB capability
    9a8d7ab07f net/hns3: extract common function to obtain revision ID
    082393fa5d net/hns3: fix IMP or global reset
    5544a65fbb net/hns3: fix traffic management thread safety
    88ddc5f559 net/nfp: fix reconfigure logic of set MAC address
    69933a8ef9 net/nfp: fix reconfigure logic in VF initialization
    66e7d1cdb0 net/nfp: fix reconfigure logic in PF initialization
    f3f42b6d5b net/nfp: fix link status interrupt
    d6ca7e03fe net/nfp: fix DMA error after abnormal exit
    09ec0e74aa net/mlx5: fix hairpin queue unbind
    f19325f6eb crypto/qat: fix raw API null algorithm digest
    501c30a45c crypto/qat: fix NULL algorithm digest placement
    1c5191e68c net/nfp: fix Tx descriptor free logic of NFD3
    8d9e1872ea event/dlb2: fix disable PASID
    804ef265cf net/mlx5: zero UDP checksum over IPv4 in encapsulation
    e867b9ff37 net/mlx5: fix shared Rx queue list management
    48f88518d9 net/mlx5: fix multi-segment Tx inline data length
    b4baa4d39e net/mlx5: fix hairpin queue states
    5642cf46de net/mlx5: fix use after free on Rx queue start
    17a2cc95f1 net/mlx5: fix validation of sample encap flow action
    8f6de188ec app/testpmd: fix tunnel TSO configuration
    522d1db23c app/testpmd: add explicit check for tunnel TSO
    7e61e0b122 app/testpmd: fix tunnel TSO capability check
    78727d935b net/hns3: fix mailbox sync
    07e3d1ea4f test/bonding: fix uninitialized RSS configuration
    af6b84f09f ethdev: account for smaller MTU when setting default
    4084334e1d app/testpmd: remove useless check in TSO command
    c105c5081a net/sfc: remove null dereference in log
    7d50298a26 meter: fix RFC4115 trTCM API Doxygen
    e9285c755b event/dlb2: fix missing queue ordering capability flag
    644f1632a6 net/ice: fix crash on closing representor ports
    056e0eac3d test/bbdev: assert failed test for queue configure
    939e119406 test/bbdev: fix Python script subprocess
    38a1842b74 event/dlb2: fix name check in self-test
    68cdf1299e app/dumpcap: fix mbuf pool ring type
    c268e6c466 config/arm: fix aarch32 build with GCC 13
    f4ef2095b0 net/ice: fix Tx preparation
    93bbc6d23d net/iavf: fix Tx preparation
    cfd4195e5c crypto/nitrox: fix panic with high number of segments
    987c28f022 net/ice: fix DCF port statistics
    7fd13314d3 net/iavf: fix Tx offload flags check
    9e228c5690 net/iavf: fix indent in Tx path
    820e8fc770 net/iavf: fix Tx offload mask
    da268d8b4e net/ice: fix L1 check interval
    981460d101 common/mlx5: fix controller index parsing
    986d9d2fbb net/mlx5: fix E-Switch mirror flow rule validation
    9f2c545da6 net/mlx5: fix decap action checking in sample flow
    97cf69ec61 net/tap: fix RSS for fragmented packets
    4c22ff4433 app/procinfo: adjust format of RSS info
    ff10f5d05b app/procinfo: fix RSS info
    774c444b1c net/tap: fix IPv4 checksum offloading
    8b094ad673 net/tap: fix L4 checksum offloading
    c2404cbdfa net/hns3: fix uninitialized hash algo value
    8ca6753041 net/hns3: keep set/get algo key functions local
    5c52c7e6a4 net/hns3: fix some error logs
    6b71d322ad net/hns3: fix some return values
    48ce6323ad net/enic: avoid extra unlock in MTU set
    6d69e09954 ethdev: fix 32-bit build with GCC 13
    d0f7aa36ad net/bonding: fix possible overrun
    fe5d3a4119 test/bonding: add missing check
    1c29c23953 test/bonding: remove unreachable statement
    df93e5cc12 net/hns3: refactor interrupt state query
    0bc0e51d06 net/hns3: fix multiple reset detected log
    b28a338b6b net/hns3: remove reset log in secondary
    efe611f1c8 net/hns3: fix double stats for IMP and global reset
    fc1e7c7b6e net/hns3: fix unchecked Rx free threshold
    79ee20d589 net/hns3: fix typo in function name
    0aaa1f6146 ethdev: fix function name in comment
    4adc748e0e common/cnxk: fix pool buffer size in opaque mode
    587aea0f91 vhost: fix check on virtqueue access in in-flight getter
    201e1f617b vhost: fix check on virtqueue access in async registration
    900cc61cbe vhost: fix missing check on virtqueue access
    e9b6f56c9c vhost: fix missing vring call check on virtqueue access
    98857c5b76 net/virtio: fix link state interrupt vector setting
    0c91efd331 net/virtio: fix missing next flag in Tx packed ring
    c900dccdfe eventdev: fix missing driver names in info struct
    48ecb471d9 eventdev: fix device pointer for vdev-based devices
    6de3135f1e net/mlx5: fix matcher layout size calculation
    104340b4e1 net/mlx5: fix MPRQ stride size to accommodate the headroom
    21554f4ee2 Merging upstream branch-2.17
    7a268dfe93 malloc: remove return from void functions
    997c669059 app/procinfo: remove unnecessary rte_malloc
    6b396dceec net/bonding: fix link status callback stop
    097657f9bc app/testpmd: fix primary process not polling all queues
    91c5c25915 net/vmxnet3: fix Rx and Tx queue state
    a508510366 net/virtio: fix Rx and Tx queue state
    1213bcc826 net/vhost: fix Rx and Tx queue state
    358e6d50e7 net/txgbe: fix Rx and Tx queue state
    4e0e44f7ef net/softnic: fix Rx and Tx queue state
    7a88ec18c1 net/sfc: fix Rx and Tx queue state
    d849664d39 net/ring: fix Rx and Tx queue state
    ec33dc897d net/pfe: fix Rx and Tx queue state
    2e34b54c6e net/octeon_ep: fix Rx and Tx queue state
    b86f8689f9 net/null: fix Rx and Tx queue state
    4cdfd0b407 net/ngbe: fix Rx and Tx queue state
    eb249c2d5f net/mvpp2: fix Rx and Tx queue state
    bd403e9e66 net/mvneta: fix Rx and Tx queue state
    789097d1b9 net/mlx4: fix Rx and Tx queue state
    72786175fb net/memif: fix Rx and Tx queue state
    5c8a283469 net/ipn3ke: fix Rx and Tx queue state
    9323a4e3c7 net/hinic: fix Rx and Tx queue state
    10ccc32cc0 net/enic: fix Rx and Tx queue state
    ee101d1045 net/enetc: fix Rx and Tx queue state
    b69c78275b net/ena: fix Rx and Tx queue state
    180c47a4a4 net/e1000: fix Rx and Tx queue state
    09058bb2bb net/dpaa2: fix Rx and Tx queue state
    87695a10d6 net/dpaa: fix Rx and Tx queue state
    92c7732d11 net/cxgbe: fix Rx and Tx queue state
    b251cfe68f net/bonding: fix Rx and Tx queue state
    af16f64988 net/bnxt: fix Rx and Tx queue state
    8b1f7ca738 net/bnx2x: fix Rx and Tx queue state
    0a4aa9fa9e net/avp: fix Rx and Tx queue state
    36cbe7901c net/af_xdp: fix Rx and Tx queue state
    d59c166780 net/af_packet: fix Rx and Tx queue state
    f3baeaa757 fib6: fix adding default route as first route
    e9cd35de3c fib: fix adding default route overwriting entire table
    70b49bf5ef net/mlx5: fix leak in sysfs port name translation
    1b21ab31ce net/ice: fix TSO with big segments
    d4041c9e05 net/ice: remove log from Tx prepare function
    49e338a2b2 net/iavf: fix TSO with big segments
    296c529c25 net/iavf: remove log from Tx prepare function
    11e3255ee8 net/iavf: fix Tx debug
    1cc6a40c0d net/ice: fix initial link status
    f89cd0418d net/iavf: fix ESN session update
    77aff6a046 net/iavf: unregister interrupt handler before FD close
    1b0d948303 net/iavf: fix port stats clearing
    28ddcaf4a6 net/ice: fix TM configuration clearing
    13662a31d2 net/i40e: fix buffer leak on Rx reconfiguration
    bf23d4ca47 net/iavf: fix checksum offloading
    71663e247f net/iavf: fix VLAN offload strip flag
    e7bd53b384 net/ice: write timestamp to first segment in scattered Rx
    1d231c0c26 net/i40e: fix FDIR queue receives broadcast packets
    cbc624f535 app/bbdev: fix link with NXP LA12XX
    e166b7fd15 baseband/acc: fix ACC100 HARQ input alignment
    8816d35798 common/cnxk: remove dead Meson code
    e50b6544bb common/cnxk: fix aura disable handling
    5bbab97809 mempool/cnxk: fix free from non-EAL threads
    f2a2d57884 dma/cnxk: fix device state
    7c35f7b1c5 common/cnxk: fix DPI memzone name
    a2e1ba51cd net/cnxk: fix uninitialized variable
    723ae321d2 net/cnxk: fix uninitialized variable
    3e087130fc common/cnxk: fix different size bit operations
    981e2093cb common/cnxk: fix xstats for different packet sizes
    b2da49e418 common/cnxk: fix default flow action setting
    77810d067d event/sw: fix ordering corruption with op release
    9ae9b97617 eventdev/eth_rx: fix timestamp field register in mbuf
    2ab27f391f event/sw: remove obsolete comment
    9ff70c4b78 test/event: fix crypto null device creation
    107d68ad4d event/cnxk: fix return values for capability API
    d31f9b208d event/cnxk: fix getwork mode devargs parsing
    2df5816de9 Merging upstream branch-2.17
    13b3789404 bus/pci: fix device ID log
    0882f0ecd2 eventdev: fix symbol export for port maintenance
    27a64dc2dd crypto/ipsec_mb: add dependency check for cross build
    4346110ba4 test/crypto: fix typo in asym tests
    0ad8ae6b18 test/crypto: skip some synchronous tests with CPU crypto
    956aa99fcb test/crypto: fix IV in some vectors
    de8bdca2b3 doc: replace code blocks with includes in security guide
    9ee1a46fe7 cryptodev: add missing doc for security context
    64513c3fd4 app/testpmd: fix help string
    da9e764370 net/tap: use MAC address parse API instead of local parser
    4cdc254d17 net/ngbe: check process type in close operation
    4a97dac668 net/txgbe: check process type in close operation
    5658f2dd84 net/ngbe: keep link down after device close
    a3d1c5eb08 net/txgbe: keep link down after device close
    709992faca net/ngbe: reconfigure MAC Rx when link update
    b817c9e250 net/txgbe: reconfigure MAC Rx when link update
    51451e5516 net/ngbe: fix flow control
    289d492046 net/txgbe: fix GRE tunnel packet checksum
    2a455021e4 net/txgbe: add Tx queue maximum limit
    eb6a3e4952 net/netvsc: increase VSP response timeout to 60 seconds
    25123c091b hash: align SSE lookup to scalar implementation
    171c6bf70d bus/dpaa: fix build with asserts for GCC 13
    81b71fcdab random: initialize state for unregistered non-EAL threads
    03a4383ed7 net/hns3: fix order in NEON Rx
    7690a37723 net/hns3: fix flushing multicast MAC address
    21874e8d89 net/hns3: fix error code for multicast resource
    e5a349762a net/hns3: fix VF default MAC modified when set failed
    2a40eeaf9a net/sfc: add missing error code indication to MAE init path
    0ea692c019 net/sfc: account for data offset on Tx
    c0edca24f2 net/sfc: set max Rx packet length for representors
    41073f2809 net/bonding: fix header for C++
    2e32b7f958 rawdev: fix device class in log message
    c8f024efd8 eal/unix: fix firmware reading with external xz helper
    acafc55e26 mempool: fix default ops for an empty mempool
    fb25ee65c2 Merging upstream branch-2.17
    f5fec488a1 Merging upstream branch-2.17
    5d7fc78c46 Merging upstream branch-2.17
    2d8e91e4cd Merging upstream branch-2.17
    edb655f33c Merging upstream branch-2.17
    fcd29ab280 Merging upstream branch-2.17
    0ab613e72e Merging upstream branch-2.17
    dc3b12d638 Merging upstream branch-2.17
    e89b367b29 Merging upstream branch-2.17
    b960a1e73b Merging upstream branch-2.17
    2323252f10 Merging upstream branch-2.17
    ec3ddd7e91 Revert "net/iavf: fix tunnel TSO path selection"
    bfa72e847e Merging upstream branch-2.17
    4dbf535102 Merging upstream branch-2.17
    33604e6b9e Merging upstream branch-2.17
    1d093172f3 Merging upstream branch-2.17
    c6fe249b71 Merging upstream branch-2.17
    75de7e4692 Merging upstream branch-2.17
    0cabc0aaab Merging upstream branch-2.17
    3906bbc236 Merging upstream branch-2.17
    c54d4024f1 Merging upstream branch-2.17
    ae0cf9c610 Merging upstream branch-2.17
    40bc911f1e Merging upstream branch-2.17
    9f7cd5522e Merging upstream branch-2.17
    6521f134cf Merging upstream branch-2.17
    9f8ccda402 Merging upstream branch-2.17
    cbaaedee10 Merging upstream branch-2.17
    46e64a87e0 Merging upstream branch-2.17
    475deff39c Merging upstream branch-2.17
    31a23281e4 Merging upstream branch-2.17
    5d594abe7a Merging upstream branch-2.17
    76a5db03fd Merging upstream branch-2.17
    f477adf374 Merging upstream branch-2.17
    45d844304e Merging upstream branch-2.17
    2697579fdc Merging upstream branch-2.17
    67f604ebdc Merging upstream branch-2.17
    05fa26a139 Merging upstream branch-2.17
    37c3af3e12 Merging upstream branch-2.17
    0e651f6b54 Merging upstream branch-2.17
    17b95f12c3 Merging upstream branch-2.17
    ae8260a204 Merging upstream branch-2.17
    128581791a net/i40e: revert link status check on device start (#2138116)
    6f8543f511 Merging upstream branch-2.17
    f19938d3a1 Merging upstream branch-2.17
    b525569b0d Merging upstream branch-2.17
    5dfd4e6400 Merging upstream branch-2.17
    1cfa796567 Merging upstream branch-2.17
    71ddd61269 Merging upstream branch-2.17
    a433643e75 Merging upstream branch-2.17
    6169fac929 Merging upstream branch-2.17
    f23d889fb6 Merging upstream branch-2.17
    0ec0df6e20 Merging upstream branch-2.17
    4ba6b95b22 Merging upstream branch-2.17
    71bc61c2bf Merging upstream branch-2.17
    7ff23905b5 Merging upstream branch-2.17
    25e49e5fca Merging upstream branch-2.17
    da8dd9a9b2 net/i40e: fix jumbo frame Rx with X722
    f1c25f8297 Merging upstream branch-2.17
    84413c9788 Merging upstream branch-2.17
    ab44868171 Merging upstream branch-2.17
    d0433c40d3 Merging upstream branch-2.17
    7c403d4410 Merging upstream branch-2.17
    0b5d3b91b4 Merging upstream branch-2.17
    a533d9e5f2 Merging upstream branch-2.17
    3b7766ed9f Merging upstream branch-2.17
    516dbfecd4 Merging upstream branch-2.17
    8ca47ac0d2 Merging upstream branch-2.17
    8fb9f9f63d Merging upstream branch-2.17
    312ab65013 Merging upstream branch-2.17
    11d3f7c41a vhost: fix virtqueue use after free on NUMA reallocation
    e516b3bf5f Merging upstream branch-2.17
    d749cfdaec Merging upstream branch-2.17
    1295f7a5e6 Merging 7bcd45ce82 version: 21.11.2
    6f69b34570 Merging upstream branch-2.17
    89e726bde0 Merging upstream branch-2.17
    a4ef706d85 Merging upstream branch-2.17
    22fee2fe1c Merging upstream branch-2.17
    d5f05599e2 Merging upstream branch-2.17
    9696953ec3 Merging upstream branch-2.17
    4e7aefcf9b Merging upstream branch-2.17
    35eafbd002 Merging upstream branch-2.17
    f20d9896dc Merging upstream branch-2.17
    33619c7858 Merging upstream branch-2.17
    90c3a0cb82 Merging upstream branch-2.17
    99635fe2d6 Merging upstream branch-2.17
    14f43280c9 Merging upstream branch-2.17
    6d503f9671 Merging upstream branch-2.17
    ef89b30abc Merging upstream branch-2.17
    fc7fadc01f Merging upstream branch-2.17
    3048a9f25e Merging upstream branch-2.17
    67ef01bba8 Merging upstream branch-2.17
    5ca18f3ca7 Merging upstream branch-2.17
    97e4e20baf Merging upstream branch-2.17
    05c95aefde Merging upstream branch-2.17
    d5ccc414d3 Merging upstream branch-2.17
    ec6e7994a3 Merging upstream branch-2.17
    47e297811e vhost: fix queue number check when setting inflight FD
    eb67d78dbb vhost: fix FD leak with inflight messages
    4130c8ead3 Merging upstream branch-2.17
    5a4bc1fbfe Merging upstream branch-2.17
    3383d19a17 Merging upstream branch-2.17
    c32cf7621a Merging upstream branch-2.17
    e20f46658c Merging upstream branch-2.17


* Tue Mar 12 2024 Timothy Redaelli <tredaelli@redhat.com> - 2.17.0-136
- redhat: Fix testcase failures due to downstream only backport. [RH git: 9578fef35c]
    The following tests where failing due to the downstream only backport:
    
    793: tunnel_push_pop - local_ip configuration
    797: tunnel_push_pop - use non-local port as tunnel endpoint
    801: tunnel_push_pop_ipv6 - local_ip configuration
    
    This is the downstream backport causing the problem:
    
      684b6e8ad9ff ("ofproto-dpif-xlate: Optimize datapath action set by removing last clone action.")


* Tue Mar 05 2024 Timothy Redaelli <tredaelli@redhat.com> - 2.17.0-135
- redhat: Use Patch0 instead of Patch [RH git: dbed769cab]


* Tue Mar 05 2024 Timothy Redaelli <tredaelli@redhat.com> - 2.17.0-134
- redhat: Fix SyntaxWarnings with Python 3.12 [RH git: f84864b37a]


* Tue Mar 05 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-133
- Merging upstream branch-2.17 [RH git: f017ff4f8e]
    Fix merge conflict as well. The fix goes fully with the Upstream version
    
    Commit list:
    67f834f2b3 bond: Reset stats when deleting post recirc rule.
    567b7f9cf1 ofproto-dpif-trace: Fix infinite recirculation tracing.
    108d5e70a0 ofproto-dpif-xlate: Fix ignoring IPv6 local_ip for native tunnels.
    d4d4e7dec3 netdev-dummy: Add local route entries for IP addresses.
    01e400bf5b tests: Move the non-local port as tunnel endpoint test.
    ff356a2988 netdev-dummy: Support multiple IP addresses.
    e60c121f60 rstp: Fix deadlock with patch ports.


* Wed Feb 14 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-132
- Merging upstream branch-2.17 [RH git: b61e7bc77f]
    Commit list:
    558ec274f6 ofproto-dpif-monitor: Remove unneeded calls to clear packets.
    1b9ee817e0 bfd: Set proper offsets and flags in BFD packets.


* Fri Feb 09 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-131
- Merging upstream branch-2.17 [RH git: 580b9cf435]
    Commit list:
    82ab9d1dcb Prepare for 2.17.10.
    0bea06d995 Set release date for 2.17.9.
    b8657dada9 netdev-offload-tc: Check geneve metadata length.
    e235a421fb odp: ND: Follow Open Flow spec converting from OF to DP.
    002cba9f19 dpdk: Use DPDK 21.11.6 release for OVS 2.17.
    ee889659db github: Update versions of action dependencies (Node.js 20).
    bf717d0f31 ovs-atomic: Fix inclusion of Clang header by GCC 14.


* Thu Jan 11 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-130
- Merging upstream branch-2.17 [RH git: e9660639ae]
    Commit list:
    9bbc2cf8a8 ovsdb-idl.at: Test IDL behavior during database conversion.
    049189584f tests: Use _DAEMONIZE macro's to start tcpdump.
    30099c5d9e tests-ovsdb: Switch OVSDB_START_IDLTEST to macro.
    f4b4d650a1 python: idl: Handle monitor_canceled.


* Tue Jan 09 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-129
- Merging upstream branch-2.17 [RH git: 3661e3d93d]
    Commit list:
    d6caa6ed03 vconn: Count vconn_sent regardless of log level.
    b0eb66a69d backtrace: Fix error in log_backtrace() documentation.
    bb89735b21 ovsdb: trigger: Do not allow conversion in read-only mode.
    a79ee883a7 ovsdb: jsonrpc-server: Fix the DSCP value in default options.
    4f01f2f7de jsonrpc: Sort JSON objects while printing debug messages.
    3cae42bc53 tests: ovsdb: Use diff -up format for replay test.
    a7036f6a1e ovsdb-server.at: Enbale debug logs in active-backup tests.
    c944a30fee ovsdb: transaction: Don't try to diff unchanged columns.
    5c0dc96027 ovsdb: transaction: Avoid diffs for different type references.


* Tue Jan 09 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-128
- Merging upstream branch-2.17 [RH git: 64bf41e65e]
    Commit list:
    eabd4cb2f6 ci: Update the GitHub Ubuntu runner image to Ubuntu 22.04.
    c462aabb36 netdev-afxdp: Disable -Wfree-nonheap-object on receive.


* Thu Jan 04 2024 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-127
- Merging upstream branch-2.17 [RH git: b4b8a09abb]
    Commit list:
    b3f8c32eda ovsdb-idl: Preserve change_seqno when deleting rows.


* Tue Dec 19 2023 Kevin Traynor <ktraynor@redhat.com> - 2.17.0-126
- Revert "net/iavf: fix abnormal disable HW interrupt" [RH git: 4b0cf32296]
    This reverts commit b965aceffdb9dd8d2501314c174716617371d752.
    
    This was reported by QE to be causing a hang in FD-3249.
    
    commit b965aceffdb9dd8d2501314c174716617371d752
    Author: Mingjin Ye <mingjinx.ye@intel.com>
    Date:   Wed Jun 14 09:53:03 2023 +0000
    
        net/iavf: fix abnormal disable HW interrupt
    
        [ upstream commit 675a104e2e940ec476e8b469725e8465d01c0098 ]
    
    Signed-off-by: Kevin Traynor <ktraynor@redhat.com>


* Tue Dec 05 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-125
- Merging upstream branch-2.17 [RH git: e44674c18e]
    Commit list:
    d254aedad7 tunnel: Do not carry source port from a previous tunnel.
    1857c569ee netdev-offload-tc: Fix offload of tunnel key tp_src.
    0a0c500d7c cirrus: Update from FreeBSD 12 to 14.


* Fri Dec 01 2023 Kevin Traynor <ktraynor@redhat.com> - 2.17.0-124
- Merging 4e50ad4469 version: 21.11.5 [RH git: 3d32e2c14a]
    Commit list:
    4e50ad4469 version: 21.11.5
    89133ca5b1 version: 21.11.5-rc1
    cdb53b339b net/mlx5: fix drop action attribute validation
    c6c34e7304 net/hns3: get FEC capability from firmware
    464ba4ae95 net/hns3: fix missing FEC capability
    5a557a0746 test/bonding: fix include of standard header
    894cfad370 net/ngbe: fix RSS offload capability
    155acf8e9d test/mbuf: fix crash in a forked process
    ad2b9b7ef9 net/nfp: fix offloading flows
    9866fb3dae doc: update BIOS settings and supported HW for NTB
    c90d34c66f net/mlx5: fix validation for conntrack indirect action
    88407eb228 net/mlx5: fix LRO TCP checksum
    a83cabaa74 net/mlx5: fix drop action memory leak
    23103032ab net/e1000: fix Rx and Tx queue status
    5df4afe600 net/igc: fix Rx and Tx queue status
    9eceb8933e net/ixgbe: fix Rx and Tx queue status
    7b9fc06893 common/iavf: fix MAC type for 710 NIC
    8ff3aaeba2 net/iavf: fix stop ordering
    f89976b2af net/i40e: fix comments
    775d83159d doc: fix typos and wording in flow API guide
    904c11f81a kni: fix build with Linux 6.5
    4934f0d915 ipsec: fix NAT-T header length
    7d5fa222be examples/ipsec-secgw: fix TAP default MAC address
    0fad3187d7 app/crypto-perf: fix socket ID default value
    629d2a5ac7 examples/fips_validation: fix digest length in AES-GCM
    ea37fdf491 test/crypto: fix PDCP-SDAP test vectors
    80aeb93e1e common/qat: detach crypto from compress build
    2fabcaceff baseband/fpga_5gnr_fec: fix starting unconfigured queue
    2074d7e982 baseband/fpga_5gnr_fec: fix possible division by zero
    03f55be06e net/ice: fix RSS hash key generation
    3eb4ad8ed6 net/iavf: fix tunnel TSO path selection
    336ae4ce52 net/ice: fix 32-bit build
    87a713bbe9 net/iavf: fix VLAN insertion in vector path
    c3d6a7d2e4 net/ice: fix VLAN mode parser
    3f5a206aab net/mlx5: forbid MPRQ restart
    c947d1f3bd net/mlx5: fix flow workspace destruction
    9a1b7013e1 net/mlx5: fix flow dump for modify field
    376ba6a8d7 ethdev: fix potential leak in PCI probing helper
    4045558987 net/hns3: fix index to look up table in NEON Rx
    3a78edd47d net/hns3: fix non-zero weight for disabled TC
    7b603155c1 doc: fix number of leading spaces in hns3 guide
    a6df8f6163 doc: fix syntax in hns3 guide
    8d3993728f doc: fix kernel patch link in hns3 guide
    73aaba67bd net/hns3: delete duplicate macro definition
    8ed9016759 app/testpmd: fix checksum engine with GTP on 32-bit
    3bb1514228 net/netvsc: fix sizeof calculation
    4701569166 hash: fix reading unaligned bits in Toeplitz hash
    8f2d1e294c mem: fix memsegs exhausted message
    aa341b7700 fib: fix adding default route
    0c24fe6db3 ipc: fix file descriptor leakage with unhandled messages
    b687d491a2 net/cnxk: fix flow queue index validation
    fa91d69044 net/cnxk: fix cookies check with security offload
    27da89db96 net/cnxk: flush SQ before configuring MTU
    09ad6cf34e common/mlx5: adjust fork call with new kernel API
    3bb439262b net/mlx5: fix device removal event handling
    04972e0400 net/mlx5: fix risk in NEON Rx descriptor read
    ad874a89de net/ice: fix protocol agnostic offloading with big packets
    87ec3aee94 net/e1000: fix queue number initialization
    0826a11cd2 net/i40e: fix tunnel packet Tx descriptor
    b965aceffd net/iavf: fix abnormal disable HW interrupt
    9dee3615aa net/ixgbe: add proper memory barriers in Rx
    259f2c0780 net/ice: fix tunnel packet Tx descriptor
    fe2fc3df82 net/iavf: fix VLAN offload with AVX512
    c4dc88c937 common/sfc_efx/base: fix Rx queue without RSS hash prefix
    4963f9aba5 net/nfp: fix address always related with PF ID 0
    fcea6b6498 net/ngbe: fix extended statistics
    edf9b54d25 net/txgbe: fix extended statistics
    1077232f46 net/txgbe: fix to set autoneg for 1G speed
    5b72e18f0a net/txgbe: fix interrupt enable mask
    1a7755214b net/txgbe/base: fix Tx with fiber hotplug
    d98f67c3a3 net/bonding: fix destroy dedicated queues flow
    b11127de28 net/bonding: fix startup when NUMA is not supported
    da6cad795b ethdev: update documentation for API to get FEC
    b6557a758d ethdev: check that at least one FEC mode is specified
    d53afe6d0e ethdev: update documentation for API to set FEC
    1cf0bf459c crypto/openssl: skip workaround at compilation time
    ad9d44049a ci: fix libabigail cache in GHA
    88497910a9 mbuf: fix Doxygen comment of distributor metadata
    5d9357c7e2 test: add graph tests
    47a25c8459 examples/l2fwd-cat: fix external build
    648321ab81 doc: remove warning with Doxygen 1.9.7
    eac5508ce6 doc: fix typo in graph guide
    77145940b5 net/virtio-user: fix leak when initialisation fails
    7b8888a456 net/ice: fix outer UDP checksum offload
    1c5b0a02f0 net/ice: initialize parser for double VLAN
    634cd44ea0 net/ice: fix timestamp enabling
    285bc0e2d1 net/ice: adjust timestamp mbuf register
    f420162557 net/ice/base: remove unreachable code
    cdd62beeb2 net/ice: fix DCF control thread crash
    45daf222f8 net/iavf: release large VF when closing device
    9d5f649aa5 net/ice: fix DCF RSS initialization
    4408ee1716 net/ice: fix statistics
    0a060a3c1e net/iavf: fix Rx data buffer size
    54b08280e7 net/ice: fix Rx data buffer size
    d5755af28b net/i40e: fix Rx data buffer size
    1173611e55 doc: fix typo in cnxk platform guide
    a56289503e net/qede: fix RSS indirection table initialization
    498f380f8c common/cnxk: fix inline device VF identification
    6f685b45a6 common/cnxk: fix IPsec IPv6 tunnel address byte swap
    baff3174c6 net/mlx5: fix duplicated tag index matching in SWS
    2681bfff6d net/mlx5: enhance error log for tunnel offloading
    32d51fbf81 net/virtio: fix initialization to return negative errno
    2c2d4e88a8 net/virtio: propagate interrupt configuration error values
    11a426ee6b vhost: fix invalid call FD handling
    f329acb883 crypto/ipsec_mb: optimize allocation in session
    2487cb35ca crypto/ipsec_mb: fix enqueue counter for SNOW3G
    0428cfa189 test/crypto: fix session creation check
    c4583cd33a test/crypto: fix return value for SNOW3G
    792da5fcf7 crypto/scheduler: fix last element for valid args
    54fa9bdcd5 doc: fix auth algos in cryptoperf app
    f68f4b2b8b net/vmxnet3: fix return code in initializing
    1fa656ba3c net/hns3: fix IMP reset trigger
    b99c14584b net/hns3: fix redundant line break in log
    44160c032b net/hns3: fix inaccurate log
    1834797be4 net/hns3: fix uninitialized variable
    f630f709e9 net/hns3: fix device start return value
    51a43c9a86 net/hns3: fix mbuf leakage when RxQ started after reset
    3d26d3f0c2 net/hns3: fix mbuf leakage when RxQ started during reset
    37164c2537 net/hns3: extract PTP to its own header file
    80d032eed5 net/hns3: uninitialize PTP
    d2ec3c302c net/hns3: fix RTC time after reset
    bf28f06d51 net/hns3: fix RTC time on initialization
    57a458ded6 doc: fix format in flow API guide
    65193aced0 net/hns3: fix FEC mode check
    3e8f218194 net/hns3: fix FEC mode for 200G ports
    c11ee881c2 ethdev: fix indirect action conversion
    b374bc7b0e net/hns3: fix Rx multiple firmware reset interrupts
    5c105051b9 net/hns3: fix variable type mismatch
    4077943285 net/hns3: fix never set MAC flow control
    fbfa671cbf net/sfc: invalidate dangling MAE flow action FW resource IDs
    b3741dfb48 ethdev: fix MAC address occupies two entries
    80e17cb702 net/txgbe: fix use-after-free on remove
    6de921b8d6 net/vmxnet3: fix drop of empty segments in Tx
    b23b2580e3 app/testpmd: fix GTP L2 length in checksum engine
    f297d8681d net/dpaa2: fix checksum good flags
    aae992cbfb net/tap: set locally administered bit for fixed MAC address
    ed992acac3 net/sfc: stop misuse of Rx ingress m-port metadata on EF100
    f400487830 net/hns3: fix build warning
    b75ffdb751 eal/linux: fix legacy mem init with many segments
    3ca06320cd eal/linux: fix secondary process crash for mp hotplug requests
    15aac36450 event/cnxk: fix nanoseconds to ticks conversion
    44a0ae7840 eventdev/timer: fix buffer flush
    63daa71622 event/dsw: free rings on close
    87c6203836 doc: fix event timer adapter guide
    84d280e276 eventdev/timer: fix timeout event wait behavior
    e248dac54f pci: fix comment referencing renamed function
    e506470227 eal: avoid calling cleanup twice
    c2f6df57e2 test/malloc: fix statistics checks
    13c7286a69 test/malloc: fix missing free
    e531825d4e pipeline: fix double free for table stats
    4b8a60276b ring: fix dequeue parameter name
    c95d48b0d4 telemetry: fix autotest on Alpine
    16e1d054e4 build: fix case of project language name
    e8393bfd7b kernel/freebsd: fix function parameter list
    ae3de8c27c vfio: fix include with musl runtime
    096ec31efd ring: fix use after free
    27f385ccbd examples/ntb: fix build with GCC 13
    43a3d772b3 examples/ip_pipeline: fix build with GCC 13
    b22ddfe63a kni: fix build with Linux 6.3
    e185150c2a version: 21.11.4
    37b4d55f5e build: detect backtrace availability
    f7dce59377 version: 21.11.4-rc1
    dea6bb1c53 vhost: fix possible FD leaks
    a7843e7a00 net/af_xdp: squash deprecated-declaration warnings
    29d8b0a92a ci: switch to Ubuntu 20.04
    6da61add54 doc: fix pipeline example path in user guide
    03973756cf acl: fix crash on PPC64 with GCC 11
    606474e9d0 pdump: fix build with GCC 12
    143dc1f75c test/crypto: fix statistics error messages
    f428da47bf net/mlx5: fix sysfs port name translation
    4509d71d9e net/mlx5: fix CQE dump for Tx
    c3a4fd09f9 net/mlx5: fix build with GCC 12 and ASan
    b663eda75c examples/qos_sched: fix config entries in wrong sections
    fd79c3462e net/nfp: fix MTU configuration order
    398c55fee9 net/ipn3ke: fix representor name
    b3fbfee3fb net/ipn3ke: fix thread exit
    400ac4f9da bus/ifpga: fix devargs handling
    34934b2b19 doc: fix LPM support in l3forward guide
    7a7e85c4de net/mlx5: fix hairpin Tx queue reference count
    35f911011c net/iavf: fix device stop during reset
    e71d71bc0c net/i40e: fix MAC loopback on X722
    acfff39a6d net/e1000: fix saving of stripped VLAN TCI
    ac111b80fe net/i40e: fix AVX512 fast-free path
    998d70414b net/sfc: invalidate switch port entry on representor unplug
    f5922d3d3d net/virtio: remove address width limit for modern devices
    1585556d2c net/vhost: fix Rx interrupt
    a38b2e5693 net/vhost: fix leak in interrupt handle setup
    14297e3110 net/vhost: add missing newline in logs
    b3225c2215 app/bbdev: check statistics failure
    9daf33a237 app/compress-perf: fix remaining data for ops
    50f94c98a9 test/crypto: fix capability check for ZUC cipher-auth
    0872c1aaad test/crypto: fix ZUC digest length in comparison
    655c88665d test/mbuf: fix test with mbuf debug enabled
    988dc26cab test: fix segment length in packet generator
    b71a128da3 reorder: fix sequence number mbuf field register
    7dd9b2a9fa raw/skeleton: fix selftest
    fe4b05502d net/hns3: add verification of RSS types
    a306316dd2 net/hns3: reimplement hash flow function
    31b6a0d06f net/hns3: separate flow RSS config from RSS conf
    6e7fad71e4 net/hns3: allow adding queue buffer size hash rule
    c1c4bb0af2 net/hns3: remove unused structures
    2e9d4cae1a net/hns3: save hash algo to RSS filter list node
    d624edd0a2 net/hns3: use new RSS rule to configure hardware
    5b805e1ebc net/hns3: separate setting RSS types
    10b331bc5f net/hns3: separate setting hash key
    22b71c0ad7 net/hns3: separate setting hash algorithm
    1f685aab8a net/hns3: use hardware config to report hash types
    abe4818f0e net/hns3: use hardware config to report hash key
    8dac9d9073 net/hns3: extract common functions to set Rx/Tx
    b5f5a77a9f net/hns3: fix burst mode query with dummy function
    6cce9c61f9 net/hns3: fix RSS key size compatibility
    9a20540ca1 net/hns3: make getting Tx function static
    df7d846ead net/hns3: separate Tx prepare from getting Tx function
    8ad4e433e7 common/cnxk: fix auth key length
    7faf9ad3c4 eal: cleanup alarm and hotplug before memory detach
    64407a1385 common/cnxk: fix dual VLAN parsing
    bace3fae4e net/sfc: fix resetting mark in tunnel offload switch rules
    0a3ba8d8bc mailmap: add list of contributors
    27b61d8f7b app/flow-perf: fix division or module by zero
    a9cddaff93 app/crypto-perf: fix test file memory leak
    44bd8ea719 net/mlx5: fix Windows build with MinGW GCC 12
    f8bbcce58a net/hns3: separate setting and clearing RSS rule
    5de7a11e06 net/hns3: separate setting redirection table
    9a7ea28161 net/hns3: use hardware config to report redirection table
    abeba16e38 net/hns3: fix possible truncation of redirection table
    f9e58fd51a net/hns3: fix possible truncation of hash key when config
    43af30f9a5 mem: fix heap ID in telemetry
    01a15c3c5c cmdline: handle EOF as quit
    42339a554e cmdline: make rdline status not private
    c98bda4768 kni: fix possible starvation when mbufs are exhausted
    b7c5365796 common/sfc_efx/base: add MAE mark reset action
    5b765d83bb regex/mlx5: fix doorbell record
    e140c624f6 regex/mlx5: utilize all available queue pairs
    c07485a1c1 table: fix action selector group size log2 setting
    d15e8526b0 raw/skeleton: fix empty devargs parsing
    c6dd06ddb6 dma/skeleton: fix empty devargs parsing
    cbb0399801 net/virtio: fix empty devargs parsing
    1b619068f3 net/hns3: fix empty devargs parsing
    52480ab3ae cryptodev: fix empty devargs parsing
    cb72e89906 compressdev: fix empty devargs parsing
    5d95507d27 kvargs: add API documentation for process callback
    5eeee34bf7 common/cnxk: add memory clobber to steor and ldeor
    c0a24be8f2 net/cnxk: fix LBK BPID usage
    617735f8fb net/ixgbe: fix IPv6 mask in flow director
    66c0e09464 app/testpmd: fix secondary process packet forwarding
    096166c31c ethdev: remove telemetry Rx mbuf alloc failed field
    2d42946f45 net/nfp: fix getting RSS configuration
    36cbdd704b ethdev: fix build with LTO
    4b158390a6 app/testpmd: fix packet transmission in noisy VNF engine
    ce6a8e97ec app/testpmd: fix packet count in IEEE 1588 engine
    0a4ce1a382 app/testpmd: fix Tx preparation in checksum engine
    90c0aaef25 compress/mlx5: fix queue setup for partial transformations
    38c2a798fd compress/mlx5: fix output Adler-32 checksum offset
    cb240b164c compress/mlx5: fix decompress xform validation
    f18e07dad7 examples/ipsec-secgw: fix auth IV length
    c41493361c net/virtio: deduce IP length for TSO checksum
    7a4cda6e20 vhost: fix OOB access for invalid vhost ID
    e29f5be725 test/bbdev: remove check for invalid opaque data
    8a36f3995a test/bbdev: extend HARQ tolerance
    f77e413c91 test/bbdev: fix crash for non supported HARQ length
    349431b3fb event/cnxk: fix SSO cleanup
    6147a8003d doc: fix reference to event timer header
    52cf05533b doc: add gpudev to the Doxygen index
    0bc981bfdf eal/windows: fix pedantic build
    7b20d58e71 build: fix dependencies lookup
    74f84c7558 examples/qos_sched: fix Tx port config when link down
    661f5540c3 examples/cmdline: fix build with GCC 12
    c791a30249 eal: use same atomic intrinsics for GCC and clang
    aff575df46 build: fix toolchain definition
    fa627c973b test/reorder: fix double free of drained buffers
    68bf4f36e9 reorder: invalidate buffer from ready queue in drain
    5f2d6beac4 dma/ioat: fix error reporting on restart
    3d440ae7d3 dma/ioat: fix indexes after restart
    7e8fc5d992 dma/ioat: fix device stop if no copies done
    118edbb634 eal/freebsd: fix lock in alarm callback
    818b598bfd sched: fix alignment of structs in subport
    058262ec6c app/testpmd: fix crash on cleanup
    e6152fdf62 net/bnxt: fix link state change interrupt config
    8b717146ab app/compress-perf: fix testing single operation
    87689a74a4 app/compress-perf: fix some typos
    cc692ab817 net/iavf: fix VLAN offload with AVX2
    312d7c3eb2 net/ixgbe: enable IPv6 mask in flow rules
    7cdea129b8 net/iavf: fix building data desc
    a6aba6b291 net/iavf: protect insertion in flow list
    1ce8e1d4a8 net/ice: fix validation of flow transfer attribute
    cb8f428cfe net/i40e: fix validation of flow transfer attribute
    22ffbcffdf net/iavf: add lock for VF commands
    a13a713ce4 net/ixgbe: fix firmware version consistency
    c8e4a58ca9 net/i40e: reduce interrupt interval in multi-driver mode
    0b4592d347 net/mlx5: check compressed CQE opcode in vectorized Rx
    026450013f net/mlx5: ignore non-critical syndromes for Rx queue
    0167cd8cf1 net/mlx5: fix error CQE dumping for vectorized Rx
    e8b6b06faa net/mlx5: fix flow sample with ConnectX-5
    190d16fb4c net/txgbe: fix Rx buffer size in config register
    08f5c42a98 net/sfc: enforce fate action in transfer flow rules
    ef7d2f34a7 net/sfc: fix MAC address entry leak in transfer flow parsing
    483243b873 net/hns3: remove debug condition for Tx prepare
    c086288760 net/hns3: add debug info for Rx/Tx dummy function
    e0f5e9d162 app/testpmd: fix link check condition on port start
    a3172b1ab9 net/sfc: export pick transfer proxy callback to representors
    f6c50b6c50 net/hns3: fix duplicate RSS rule check
    69d2be50d9 net/hns3: fix config struct used for conversion
    c7c798a8f6 net/hns3: fix warning on flush or destroy rule
    2f00c06957 net/hns3: remove useless code when destroy valid RSS rule
    8ba1441f48 net/hns3: use RSS filter list to check duplicated rule
    eee8b3cd45 net/hns3: fix clearing RSS configuration
    abe093c214 net/hns3: refactor set RSS hash algorithm and key interface
    b6328f7feb net/hns3: extract common function to query device
    81cb3c29c8 net/hns3: fix log about indirection table size
    489a1c2580 net/txgbe: fix interrupt loss
    f8e27fb215 net/ngbe: fix packet type to parse from offload flags
    5d80aae214 net/txgbe: fix packet type to parse from offload flags
    551a0e317c net/txgbe: fix default signal quality value for KX/KX4
    b641ca3033 app/testpmd: fix forwarding stats for Tx dropped
    8746dd7d44 doc: fix description of L2TPV2 flow item
    9c90d1a945 net/hns3: declare flow rule keeping capability
    fd950290d1 net/virtio-user: fix device starting failure handling
    6e302e5ede vhost: fix possible FD leaks on truncation
    f05708ea45 vhost: decrease log level for unimplemented requests
    02397094e9 eventdev/timer: fix overflow
    5f55f9989c test/mbuf: fix mbuf reset test
    26b4d5a198 eal/linux: fix hugetlbfs sub-directories discovery
    bb9295b2f3 telemetry: fix repeat display when callback don't init dict
    13bf4f461a raw/ifpga/base: fix init with multi-process
    8a411e66c3 mem: fix hugepage info mapping
    9b7ac02837 event/cnxk: fix timer operations in secondary process
    45fb6a4f8a event/cnxk: fix burst timer arm
    da4a271c75 event/cnxk: wait for CPT flow control on WQE path
    2b15b1cd4a net/bnxt: fix RSS hash in mbuf
    20189c4886 net/bnxt: fix Rx queue stats after queue stop and start
    aa0ecc4f91 net/bnxt: fix Tx queue stats after queue stop and start
    1ac2732197 compressdev: fix end of driver list
    af78ee860e test/crypto: add missing MAC-I to PDCP vectors
    af7f9481e1 test/crypto: fix typo in AES test
    b2c5b2d8a8 crypto/ccp: fix IOVA handling
    bc5f3c068c crypto/ccp: remove some dead code for UIO
    ba8923c86e crypto/ccp: remove some printf
    df587bef4a baseband/acc: fix acc100 iteration counter in TB
    3664b67985 baseband/acc: fix memory leak on acc100 close
    dd830098ef vhost: fix net header settings in datapath
    e928dfe88c vdpa/ifc: fix reconnection in SW-assisted live migration
    2d551ec8dc vdpa/ifc: fix argument compatibility check
    f8d7e778b5 app/dumpcap: fix storing port identifier
    dce447af75 examples/qos_sched: fix debug mode
    5cac713dff mem: fix telemetry data truncation
    ddb46da599 cryptodev: fix telemetry data truncation
    119d73b152 mempool: fix telemetry data truncation
    86d2c8b77c ethdev: fix telemetry data truncation
    005b23b18f telemetry: move include after guard
    f6a5384a93 app/testpmd: fix interactive mode with no ports
    f43191608a net/hns3: fix inaccurate RTC time to read
    d13acd65cc net/nfp: fix firmware name derived from PCI name
    e4609ddf51 graph: fix node shrink
    868b1b71df gpudev: fix deadlocks when registering callback
    9a43ba896c fbarray: fix metadata dump
    e8f2aab768 crypto/qat: fix stream cipher direction
    98f5f64240 eventdev/eth_tx: fix devices loop
    a668035217 app/crypto-perf: fix IPsec direction
    b2d5a49ce6 app/crypto-perf: fix SPI zero
    d734fcf15c app/crypto-perf: fix number of segments
    17817f916b devtools: fix escaped space in grep pattern
    71d0f78adf doc: fix dependency setup in l2fwd-cat example guide
    47951ef1dc hash: fix GFNI implementation build with GCC 12
    84d43ac12f kni: fix build on RHEL 9.1
    31608e4db5 version: 21.11.3
    e1d728588d ring: squash gcc 12.2.1 warnings
    adeaf361f0 vhost: fix doxygen warnings
    3b02ad76a3 lib: remove empty return types from doxygen comments
    7a21adb82b Revert "net/iavf: add thread for event callbacks"
    558ff33739 Revert "net/i40e: enable maximum frame size at port level"
    494050958c Revert "net/i40e: fix max frame size config at port level"
    528361cfa8 Revert "net/i40e: fix jumbo frame Rx with X722"
    0c553ce527 net/bonding: set initial value of descriptor count alignment
    9524c48bcd devtools: fix checkpatch header retrieval from stdin
    d5f1d8130b examples/ipsec-secgw: fix Tx checksum offload flag
    0bb6905a88 version: 21.11.3-rc1
    46abe3043e net/i40e: fix jumbo frame Rx with X722
    655f0ed4a7 net/hns3: fix restore filter function input
    eee943e2f2 net/hns3: fix lock protection of RSS flow rule
    14687654a0 net/hns3: fix RSS rule restore
    800390b260 net/hns3: extract functions to create RSS and FDIR flow rule
    2d10a3a9ba doc: add Rx buffer split capability for mlx5
    0b176394b7 net/mlx5: fix assert when creating meter policy
    7cd66fc297 net/mlx5: fix mirror flow validation with ASO action
    666d1e75a2 net/mlx5: fix source port checking in sample flow rule
    bd9e9d22ef trace: fix metadata dump
    fcf8e69afb net/iavf: add thread for event callbacks
    9345c7264d net/mlx5: fix port event cleaning order
    db856c5fb6 net/mlx5: fix race condition in counter pool resizing
    3e852fd9fe ci: enable ABI check in GHA
    66bfbc5b37 Revert "cryptodev: fix missing SHA3 algorithm strings"
    9a3294eb17 doc: avoid meson deprecation in setup
    23f263e7bd doc: fix maximum packet size of virtio driver
    776c777a61 drivers: remove unused build variable
    631e68c186 net/nfp: fix Rx descriptor DMA address
    24d76003e1 doc: fix colons in testpmd aged flow rules
    9f54b0a4f9 doc: fix underlines in testpmd guide
    d42406e77e doc: add LRO size limitation in mlx5 guide
    8e04bc3773 net/mlx5: fix maximum LRO message size
    4b50df7128 net/ixgbevf: fix promiscuous and allmulti
    1961dbbdbd test/event: fix build with clang 15
    ca0952588a test/member: fix build with clang 15
    4cacbe5682 test/efd: fix build with clang 15
    1cd61dc7fb app/testpmd: fix build with clang 15 in flow code
    e5d36910cf app/testpmd: fix build with clang 15
    c5f336041e net/dpaa2: fix build with clang 15
    c44d10cae9 net/atlantic: fix build with clang 15
    c6ece01586 bus/dpaa: fix build with clang 15
    d116a5e632 vhost: fix build with clang 15
    2d03c4e3ef service: fix build with clang 15
    3930398baa vdpa/ifc: handle data path update failure
    29a2eb7cee ring: remove leftover comment about watermark
    ecfdc8089d ring: fix description
    674f2e762d drivers: fix typos found by Lintian
    b16910eabc doc: fix typo depreciated instead of deprecated
    4726dffdd2 test/crypto: fix bitwise operator in a SNOW3G case
    5ffd9e4baf doc: document device dump in procinfo guide
    1c94187eec doc: fix application name in procinfo guide
    08a6a565e7 mempool/cnxk: fix destroying empty pool
    aaf49e83ab examples/fips_validation: fix typo in error log
    c8812bd8ec event/cnxk: fix missing mempool cookie marking
    7773bb2b9a app/eventdev: fix limits in error message
    80dfbebe4f event/cnxk: fix mbuf offset calculation
    40f8ea78a9 doc: fix event timer adapter guide
    fd7eb800f4 ci: update to new API for step outputs in GHA
    852ba6cf84 ci: bump versions of actions in GHA
    b0df64d8a2 net/ice: fix interrupt handler unregister
    1f7763504a net/ice: fix scalar Tx path segment
    da678c3542 net/ice: fix scalar Rx path segment
    43acbdad22 net/i40e: fix pctype configuration for X722
    12164b4b18 net/iavf: fix VLAN offload
    59f67d1041 net/ice/base: fix duplicate flow rules
    3e76df459a net/mlx5: fix drop action validation
    4f1a129761 net/mlx5: fix port initialization with small LRO
    815d59452a net/mlx5: fix indexed pool local cache crash
    4cce54a549 net/mlx5: fix first segment inline length
    b4524bef61 net/mlx5: fix hairpin split with set VLAN VID action
    6f9e7bd908 net/mlx5: fix shared Rx queue config reuse
    bbddde24b2 common/mlx5: fix shared mempool subscription
    97b4706f1e net/mlx5: fix action flag data type
    4468cce76b bus/auxiliary: prevent device from being probed again
    e2413f6427 test/hash: fix bulk lookup check
    1e81619d17 test/hash: remove dead code in extendable bucket test
    84848bab5c hash: fix RCU configuration memory leak
    5a4f6d16e8 power: fix some doxygen comments
    3ff124101d eal: fix doxygen comments for UUID
    89f4c06b0f net/bonding: fix mbuf fast free handling
    a0521c13c1 app/testpmd: make quit flag volatile
    194dea76b1 net/bonding: fix dropping valid MAC packets
    185674ed26 app/testpmd: fix MAC header in checksum forward engine
    8bdb61a66f net/bonding: fix slave device Rx/Tx offload configuration
    ffdfd9c1f2 baseband/acc100: fix double MSI intr in TB mode
    43f2133add baseband/acc100: fix ring/queue allocation
    61623044a0 baseband/acc100: fix null HARQ input case
    1c83304c34 baseband/acc100: enforce additional check on FCW
    478d7fa578 baseband/acc100: fix ring availability calculation
    fd2001af83 baseband/acc100: check AQ availability
    9e244f70bc baseband/acc100: add LDPC encoder padding function
    49be94c1a2 examples/vhost: fix use after free
    4733d1363d net/bonding: fix flow flush order on close
    dec305584e net/mlx5: fix build with recent compilers
    673e72e4dd crypto/qat: fix null hash algorithm digest size
    0c19d3c807 examples/ipsec-secgw: fix Tx checksum offload flag
    91f397092e test/crypto: fix PDCP vectors
    1d95544ee5 baseband/acc100: fix close cleanup
    29ee0dd15a baseband/acc100: fix device minimum alignment
    bc46d5e411 baseband/acc100: fix clearing PF IR outside handler
    c0e09362ca baseband/acc100: fix input length for CRC24B
    e20054a0ca baseband/acc100: add null checks
    f0f952b3a4 baseband/acc100: check turbo dec/enc input
    a52ef88f24 baseband/acc100: fix memory leak
    dfe0ec3699 test/crypto: fix wireless auth digest segment
    230df8806a examples/l2fwd-crypto: fix typo in error message
    b4d5a4880f net/mlx5: fix thread termination check on Windows
    5f6b7cdb26 common/cnxk: fix schedule weight update
    adc3d8f0be net/cnxk: fix later skip to include mbuf private data
    9e011e6018 net/ice: support VXLAN-GPE tunnel offload
    80b45cf627 net/iavf: fix queue stop for large VF
    7a87e29707 net/iavf: fix SPI check
    d8f6f9c217 net/iavf: fix IPsec flow create error check
    8d69eff7e5 net/ice: fix null function pointer call
    a7ae3ec58b net/ixgbe: fix unexpected VLAN Rx in promisc mode on VF
    7fc86024c5 net/ixgbe: fix broadcast Rx on VF after promisc removal
    c422bc8590 examples/qos_sched: fix number of subport profiles
    71f3070f3b sched: fix subport profile configuration
    8c0059933d net/mlx5: fix null check in devargs parsing
    3a37707b3f net/mlx5: fix tunnel header with IPIP offload
    5dd7f99419 net/mlx5: fix RSS expansion buffer size
    695bdd0252 net/mlx5: fix thread workspace memory leak
    ce31e6798d vhost: add non-blocking API for posting interrupt
    8c4cb627f2 net/nfp: fix internal buffer size and MTU check
    a2e076069c app/testpmd: remove jumbo offload
    1df0906a71 net/ionic: fix reported error stats
    1865648551 net/ionic: fix Rx filter save
    b91f3a9676 net/ionic: fix adapter name for logging
    9c5b13e3d6 net/ionic: fix endianness for RSS
    2e91cfe2d1 net/ionic: fix endianness for Rx and Tx
    69d5f8cbdb net/bonding: fix descriptor limit reporting
    765b6db1e1 app/testpmd: skip port reset in secondary process
    74a6d9b865 net/iavf: revert VLAN insertion fix
    9f735dd4ae doc: fix support table for Ethernet/VLAN flow items
    5123b23465 gro: check payload length after trim
    ff54781530 eventdev/eth_tx: fix queue delete
    11b702acfa eventdev/crypto: fix multi-process
    050edd6df0 event/sw: fix log in self test
    14a1303083 event/sw: fix flow ID init in self test
    24687124e2 net/dpaa2: fix buffer freeing on SG Tx
    e0c63efff0 net/dpaa2: use internal mempool for SG table
    a71b12bced net/dpaa: fix buffer freeing on SG Tx
    a7bcea2f9c net/dpaa: use internal mempool for SG table
    161eb5bcfc event/dlb2: handle enqueuing more than maximum depth
    5da67ffc34 service: fix early move to inactive status
    5c3b10f936 doc: fix reference to dma application example
    f0f63a2a3c app/dumpcap: fix pathname for output file
    9fe212c5b1 app/dumpcap: fix crash on cleanup
    3c5fb1c3aa pdump: do not allow enable/disable in primary process
    b7926cae59 trace: fix race in debug dump
    8f22713b3f trace: fix dynamically enabling trace points
    f6c054fa69 trace: fix leak with regexp
    6f27e2f1a7 trace: fix mode change
    f620019ec3 trace: fix mode for new trace point
    f2a63213a4 buildtools: fix NUMA nodes count
    3fedf9fcf4 examples/l3fwd: fix MTU configuration with event mode
    0f52767b30 dma/idxd: check DSA device allocation
    19ab7dbdeb node: check Rx element allocation
    dd0ea76557 graph: fix node objects allocation
    6976f45b64 common/mlx5: fix multi-process mempool registration
    fd3f52c7d7 mempool: make event callbacks process-private
    b252ecfe35 pcapng: fix write more packets than IOV_MAX limit
    226d2f8fd8 doc: fix dumpcap interface parameter option
    7e0fbf6e4b eal: fix data race in multi-process support
    f9544dfb1e net/bonding: fix Tx hash for TCP
    ef528a1c38 gro: trim tail padding bytes
    f4696c801d net/dpaa: fix buffer freeing in slow path
    7ac138d29b net/dpaa: fix jumbo packet Rx in case of VSP
    82b3b682b2 net/dpaa2: fix DPDMUX error behaviour
    c1098f3797 net/enetfec: fix buffer leak
    5747e5d217 net/enetfec: fix restart
    8582b5b558 net/nfp: fix memory leak in Rx
    dd0c2c45fe net/hns3: fix minimum Tx frame length
    d08a9e5bf5 net/hns3: fix VF mailbox message handling
    dea739ceb8 net/hns3: revert fix mailbox communication with HW
    cb4be0a694 net/hns3: add L3 and L4 RSS types
    b3596aa547 net/hns3: fix IPv4 RSS
    6b31e0bea1 net/hns3: fix typos in IPv6 SCTP fields
    4a628c7185 net/hns3: fix IPv4 and IPv6 RSS
    0ee1261c33 net/hns3: fix packet type for GENEVE
    61bd1be0ee net/hns3: move flow direction rule recovery
    d86c6f3dbb net/hns3: fix RSS flow rule restore
    ceefe8e42c net/hns3: fix RSS filter restore
    69155ec3fb net/hns3: revert Tx performance optimization
    3990392648 net/hns3: fix clearing hardware MAC statistics
    d9d6252870 net/hns3: delete unused markup
    afa520b633 net/hns3: fix crash when secondary process access FW
    daf6edc317 net/hns3: fix next-to-use overflow in simple Tx
    540c8608d6 net/hns3: fix next-to-use overflow in SVE Tx
    2197709643 net/hns3: fix crash in SVE Tx
    5210f643fe net/hns3: fix Rx with PTP
    84cc72849a common/sfc_efx/base: remove VQ index check during VQ start
    ee7decc2c9 net/memif: fix crash with different number of Rx/Tx queues
    37560c8deb net/tap: fix overflow of network interface index
    4d4b866a15 net/qede/base: fix 32-bit build with GCC 12
    9ba87edbe6 net/i40e: fix build with MinGW GCC 12
    54a98eecdb vhost: fix build with GCC 12
    84e55d681a timer: fix stopping all timers
    e7ad87f034 examples/vm_power_manager: use safe list iterator
    e3b8a0894a mem: fix API doc about allocation on secondary processes
    1b93855eb5 net/bnxt: fix build with GCC 13
    b673b37b9a net/bnxt: fix representor info freeing
    50e07634fe net/bnxt: remove unnecessary check
    a12a1fcc0c net/bnxt: fix error code during MTU change
    d477471727 net/bnxt: fix null pointer dereference in LED config
    6638450e4b cryptodev: fix unduly newlines in logs
    86727609c5 event/cnxk: fix missing xstats operations
    67f3304980 common/sfc_efx/base: fix maximum Tx data count
    fb442d0c0f net/axgbe: save segment data in scattered Rx
    9683271240 net/axgbe: clear buffer on scattered Rx chaining failure
    18895ee575 net/axgbe: reset end of packet in scattered Rx
    1747e299c2 net/cnxk: fix DF bit in vector mode
    d141aba6a0 net/ice: check illegal packet sizes
    60f243aee8 net/iavf: check illegal packet sizes
    6a68e9ad38 net/mlx5: fix meter profile delete after disable
    9412d614c2 net/mlx5: fix modify action with tunnel decapsulation
    ccdfdbafa4 net/mlx5: fix Tx check for hardware descriptor length
    6986b5af9c net/mlx5: fix inline length exceeding descriptor limit
    517c25053b net/mlx5: fix single not inline packet storing
    b5e5d926b2 net/mlx5: fix check for orphan wait descriptor
    879ebb7dce net/mlx5: fix Verbs FD leak in secondary process
    43ebf47ac3 net/mlx4: fix Verbs FD leak in secondary process
    21c7ed77f1 net/virtio: fix crash when configured twice
    5150a5b753 net/iavf: fix outer checksum flags
    5f0b3890df net/iavf: fix processing VLAN TCI in SSE path
    bf097fbecf net/ice/base: fix input set of GTPoGRE
    65e2ff5b1e net/ice/base: ignore promiscuous already exist
    da3be8cd7e net/ice/base: fix double VLAN in promiscuous mode
    b1f7933ce6 net/ice/base: fix add MAC rule
    f1ac3e7090 net/ice/base: fix bit finding range over ptype bitmap
    e075b36c5f net/ice/base: fix array overflow in add switch recipe
    26b64ce3a2 net/ice/base: fix endian format
    13824e6da2 net/ice/base: fix function descriptions for parser
    d2c68e7c09 net/ice/base: fix media type of PHY 10G SFI C2C
    0255526a1b net/ice/base: fix DSCP PFC TLV creation
    fdbf7b4da3 net/ice/base: fix 100M speed capability
    14ed431e08 net/ice/base: fix division during E822 PTP init
    85de6911de common/iavf: avoid copy in async mode
    fc56f980c8 net/iavf: update IPsec ESN values when updating session
    30fc18b4dc net/iavf: fix Tx done descriptors cleanup
    246026e0b8 net/iavf: fix pattern check for flow director parser
    fe9ea36901 net/iavf: fix VLAN insertion
    301e4cc87b net/iavf: fix L3 checksum Tx offload flag
    a50e008983 net/ice/base: fix inner symmetric RSS hash in raw flow
    a991f641f3 net/ice: fix RSS hash update
    85821d6d95 net/i40e: fix VF representor release
    278054776c eventdev: fix name of Rx conf type in documentation
    afa77bc4df cryptodev: fix missing SHA3 algorithm strings
    29b6bd6014 crypto/qat: fix build with GCC 12
    db9f8c23a4 ipsec: fix build with GCC 12
    fdebff6b5a test/ipsec: fix build with GCC 12
    656b357968 common/qat: fix VF to PF answer
    1af7871cdd test/crypto: fix debug messages
    783a1099f2 examples/ipsec-secgw: use Tx checksum offload conditionally
    6a5ed8de57 test/ipsec: skip if no compatible device
    a003adfe32 eventdev/eth_tx: fix adapter stop
    24f4f4450f eventdev/eth_tx: add spinlock for adapter start/stop
    0fc2e4cd21 event/sw: fix device name in dump
    6dc1d114cd event/dsw: fix flow migration
    5f22fcf619 malloc: fix storage size for some allocations
    8b3ce30416 common/cnxk: fix printing disabled MKEX registers
    97083f144c common/cnxk: fix missing flow counter reset
    6d030554f1 net/mvneta: fix build with GCC 12
    a2439f58c0 common/cnxk: fix log level during MCAM allocation
    82fa3908c0 net/ngbe: fix maximum frame size
    60df2778b9 net/ngbe: remove semaphore between SW/FW
    9f6bab86f3 net/ngbe: rename some extended statistics
    8bdb992cea net/txgbe: rename some extended statistics
    982225e1bb net/txgbe: remove semaphore between SW/FW
    d47522ba5c net/txgbe: fix IPv6 flow rule
    f1810ceebb net/nfp: improve HW info header log readability
    88eb5f06dd net/axgbe: remove freeing buffer in scattered Rx
    c57a09f16a net/axgbe: optimise scattered Rx
    7c52801e6c net/axgbe: fix checksum and RSS in scattered Rx
    edf988aa48 net/axgbe: fix length of each segment in scattered Rx
    fca744c60f net/axgbe: fix mbuf lengths in scattered Rx
    77c3e4194b net/axgbe: fix scattered Rx
    45ae1b821d net/nfp: compose firmware file name with new hwinfo
    f88bb5a08a net/failsafe: fix interrupt handle leak
    e9c74a0c19 net/bonding: fix double slave link status query
    371746d80f net/bonding: fix array overflow in Rx burst
    40e0b6e827 app/testpmd: restore ixgbe bypass commands
    48240d704e eal: fix side effect in some pointer arithmetic macros
    ac8fea2279 net: accept unaligned data in checksum routines
    155a98e864 build: enable developer mode for all working trees
    8010a15523 vhost: fix virtqueue use after free on NUMA reallocation


* Thu Nov 30 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-123
- Merging upstream branch-2.17 [RH git: 48a6c66bb5]
    Commit list:
    74633888d2 dpdk: Use DPDK 21.11.5 release for OVS 2.17.


* Wed Nov 29 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-122
- Merging upstream branch-2.17 [RH git: 285a69ef1f]
    Commit list:
    b5e54aa161 ovs-ofctl: Correctly mark the CT flush commands.


* Mon Nov 27 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-121
- Merging upstream branch-2.17 [RH git: cebd92a373]
    Commit list:
    1d3609a489 mcast-snooping: Flush flood and report ports when deleting interfaces.
    df101fe1ea mcast-snooping: Test per port explicit flooding.


* Wed Nov 01 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-120
- Merging upstream branch-2.17 [RH git: dd53abab6d]
    Commit list:
    8313ebbb33 flake8: Fix E721 check failures.
    f73208151a build-aux: Enable flake8 checks for python extraction scripts.
    8b6a8fcb0a build-aux/extract-ofp-msgs: Fix flake8 and syntax errors.
    80e922644f build-aux/extract-ofp-fields: Fix flake8 and syntax errors.
    1508e7abce build-aux/extract-ofp-errors: Fix flake8 and syntax errors.
    98fc48e4dc build-aux/extract-ofp-actions: Fix flake8 and syntax errors.
    d52231171e automake: Move build-aux EXTRA_DIST updates to their own file.


* Tue Oct 31 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-119
- Merging upstream branch-2.17 [RH git: bde74ad3b0]
    Commit list:
    8868756b8c netdev-offload: Fix Clang's static analyzer 'Division by zero' warnings.
    46e9cacaae ofp-table: Fix count_common_prefix_run() function.
    8e6d1cd042 vswitch.xml: Add entry for dpdkvhostuser userspace-tso.
    7838778ade vswitch.xml: Add dpdkvhostuser group status.


* Thu Oct 26 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-118
- Merging upstream branch-2.17 [RH git: 7961c8a931]
    Commit list:
    a3a0395071 tests: Use ping timeout instead of deadline.


* Wed Oct 25 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-117
- Merging upstream branch-2.17 [RH git: 462f701bdc]
    Commit list:
    3351b149c8 tests/system-traffic: Ensure no name resolution for tcpdump.


* Fri Oct 20 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-116
- Merging upstream branch-2.17 [RH git: 258fc7a88a]
    Commit list:
    bce17b0bb5 tc: Improve logging of mismatched actions.
    af934924f8 ofproto-dpif-upcall: Pause revalidators when purging.


* Wed Oct 18 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-115
- Merging upstream branch-2.17 [RH git: 0717965172]
    Commit list:
    48fa547473 db-ctl-base: Fix memory leak of db commands.


* Tue Oct 17 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-114
- Merging upstream branch-2.17 [RH git: 6d06e4d3dc]
    Commit list:
    7fb2197e1e Prepare for 2.17.9.
    275be1eb95 Set release date for 2.17.8.


* Fri Oct 13 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-113
- Merging upstream branch-2.17 [RH git: aa85ffacfd]
    Commit list:
    be1a8f7ecb conntrack: Remove nat_conn introducing key directionality.
    f179c7c07f conntrack: simplify cleanup path


* Thu Oct 12 2023 Timothy Redaelli <tredaelli@redhat.com> - 2.17.0-112
- redhat: use rhpkg push instead of git push [RH git: 7b22bbc0dd]


* Tue Oct 10 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-111
- Merging upstream branch-2.17 [RH git: f747af68b3]
    Commit list:
    fac770a0a7 netdev-dpdk: Document status options for VF MAC address.
    79ab2eeb16 netdev-offload-dpdk: Fix flushing of a physdev.


* Thu Oct 05 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-110
- Merging upstream branch-2.17 [RH git: 051758b3e3]
    Commit list:
    4ced485f8d connmgr: Fix ofconn configuration on vswitchd startup.


* Mon Sep 18 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-109
- Merging upstream branch-2.17 [RH git: 03e330a147]
    Commit list:
    3c39cfe031 python: idl: Fix last-id update from a monitor reply.


* Thu Sep 07 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-108
- Merging upstream branch-2.17 [RH git: 2636d56cb6]
    Commit list:
    a6207b2bce ofproto-dpif-xlate: Fix recirculation with patch port and controller. (#2170920)


* Wed Sep 06 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-107
- Merging upstream branch-2.17 [RH git: 9ed4710854]
    Commit list:
    a141b62c2f ofproto-dpif-xlate: Don't reinstall removed XC_LEARN rule. (#2213892)


* Wed Aug 30 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-106
- Merging upstream branch-2.17 [RH git: 8da11aaa9d]
    Commit list:
    586e73dacf configure: Avoid deprecated AC_PROG_CC_C99 if possible.


* Mon Aug 28 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-105
- Merging upstream branch-2.17 [RH git: ca98be26e7]
    Commit list:
    bd95fe3d7b tests: Fix time dependency in overlapping flows modification test.


* Fri Aug 25 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-104
- Merging upstream branch-2.17 [RH git: 46e94d6a61]
    Commit list:
    123b7aaa7c python: Use build to generate PEP517 compatible archives.
    41d2e7e9a8 python: Use twine to upload sdist package to pypi.org.
    66d5562e30 python: Rename build related code to ovs_build_helpers.
    c880faea8e dpif-netdev: Fix length calculation of netdet_flow_key.
    8c7aa5f589 doc: Fix description of max_len for controller action.
    34ff03c3cb docs: Fix rendering of VLAN Comparison Chart.
    93412e00e7 docs: Run tbl preprocessor in manpage-check rule.
    6929485d31 docs: Add `nowarn` region option to tables.
    08b6b83a36 tests: Add clang-analyzer-results to gitignore.
    c252b1f8a7 ci: Add jobs to test -std=c99 builds.
    242bb2624c tests: Fix order of includes in barrier/id-fpool/mpsc-queue tests.
    292eca58c6 sflow: Always enable _BSD_SOURCE.
    82aa3fb019 compiler.h: Don't use asm and typeof with non-GNU compilers.


* Thu Aug 17 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-103
- Merging upstream branch-2.17 [RH git: 04750e9ad1]
    Commit list:
    a45b3afbf8 ovs.tmac: Fix troff warning in versions above groff-1.23.


* Tue Aug 15 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-102
- Merging upstream branch-2.17 [RH git: 76a39dc7fa]
    Commit list:
    a336ef7121 connmgr: Count unsent async messages.


* Mon Aug 14 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-101
- Merging upstream branch-2.17 [RH git: 163447f9d5]
    Commit list:
    a74b7dfb96 dpif-netdev: Fix dpif_netdev_flow_put.


* Wed Aug 09 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-100
- Merging upstream branch-2.17 [RH git: 23753e82f9]
    Commit list:
    f04bfd5e47 ofproto-dpif-xlate: Reduce stack usage in recursive xlate functions. (#2104779)


* Wed Aug 09 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-99
- Merging upstream branch-2.17 [RH git: e11afe5dde]
    Commit list:
    29990edbc0 cirrus: Update to FreeBSD 13.2.


* Fri Aug 04 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-98
- Merging upstream branch-2.17 [RH git: 88c2d2ea83]
    Commit list:
    65bb823690 ci: Fix OPTS not being passed to OSX builds.


* Thu Aug 03 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-97
- Merging upstream branch-2.17 [RH git: 22854be7fc]
    Commit list:
    fe98b0c1f9 ovsdb-tool: Fix json leak while showing clustered log.
    44722bbda3 ovsdb-server: Fix excessive memory usage on DB open. (#2228464)
    9db221fcd8 tests: Add ovsdb execution cases for set size constraints.
    3cfe388cb8 ovsdb: relay: Fix handling of XOR updates with size constraints.
    f4d15497f8 ovsdb: file: Fix diff application to a default column value.
    7864ed557e ovsdb: file: Fix inability to read diffs that violate type size.
    97d91ad2d6 ovs-tcpdump: Clear auto-assigned ipv6 address of mirror port.


* Wed Aug 02 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-96
- Merging upstream branch-2.17 [RH git: 507c546250]
    Commit list:
    dba7482e02 ofproto-dpif: Fix removal of renamed datapath ports.


* Fri Jul 21 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-95
- Merging upstream branch-2.17 [RH git: 99709cc365]
    Commit list:
    a1ca9e589f ofproto-dpif-upcall: Mirror packets that are modified. (#2155579)


* Tue Jul 18 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-94
- Merging upstream branch-2.17 [RH git: f484b9ed30]
    Commit list:
    5d976536b3 vswitchd: Wait for a bridge exit before replying to exit unixctl.


* Tue Jun 27 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-93
- Merging upstream branch-2.17 [RH git: bfc17b1bd2]
    Commit list:
    e206df08d2 Prepare for 2.17.8.
    f15de6508c Set release date for 2.17.7.


* Fri Jun 16 2023 Timothy Redaelli <tredaelli@redhat.com> - 2.17.0-92
- redhat: Use sysusers instead of useradd/groupadd directly [RH git: aeeb5c020a] (#2193168)
    Reported-at: https://bugzilla.redhat.com/2193168
    Reported-by: Dan Williams <dcbw@redhat.com>
    Signed-off-by: Timothy Redaelli <tredaelli@redhat.com>


* Fri Jun 09 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-91
- Merging upstream branch-2.17 [RH git: 0e0cb5d889]
    Commit list:
    4b10b0b87f fatal-signal: Don't share signal fds/handles with forked process.


* Wed Jun 07 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-90
- Merging upstream branch-2.17 [RH git: 2fbcbf32f8]
    Commit list:
    e01ea8e7ef cpu: Fix cpuid check for some AMD processors. (#2211747)
    111c7be319 tc: Fix crash on malformed reply from kernel.


* Fri Jun 02 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-89
- Merging upstream branch-2.17 [RH git: febaa37b14]
    Commit list:
    75152d3d62 netdev-dpdk: Fix warning with gcc 13.


* Mon May 29 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-88
- Merging upstream branch-2.17 [RH git: c24e4da8ec]
    Commit list:
    5285dad182 utilities/bashcomp: Fix PS1 generation on new bash. (#2170344)
    ebe7bd7b68 netdev-offload-dpdk: Fix crash in debug log.
    4937a53410 stream-ssl: Disable alerts on unexpected EOF.
    fe99e6b971 tests: layer3-tunnels: Skip bareudp tests if not supported by kernel.
    a375055f2e ovs-fields: Modify the width of tpa and spa.
    749769be30 netdev-vport: RCU-fy tunnel config.
    c423fa5f6e smap: Make argument of smap_add_ipv6 constant.
    2db06ee6f5 netdev-vport: Fix unsafe handling of GRE sequence number.


* Thu May 11 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-87
- Merging upstream branch-2.17 [RH git: 5ff67cbb44]
    Commit list:
    51d804aa4f dpctl: Fix dereferencing null pointer in parse_ct_limit_zones().


* Wed May 10 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-86
- Merging upstream branch-2.17 [RH git: 976d80d1af]
    Commit list:
    80b15d1428 netdev-offload: Fix deadlock/recursive use of the netdev_hmap_rwlock rwlock. (#2182541)
    0d3c27e909 ofproto-dpif-xlate: Fix use-after-free when xlate_actions().


* Fri Apr 28 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-85
- Merging upstream branch-2.17 [RH git: 0365e5389c]
    Commit list:
    8eb24943cf tc: Fix cleaning chains.


* Wed Apr 26 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-84
- Merging upstream branch-2.17 [RH git: e60083b517]
    Commit list:
    cbe5852d76 python-stream: Handle SSL error in do_handshake.


* Tue Apr 25 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-83
- Merging upstream branch-2.17 [RH git: 43fc90b55a]
    Commit list:
    be3caf4553 dpif-netlink: Fix memory leak dpif_netlink_open().
    b7e1593f4c ofp-parse: Check ranges on string to uint32_t conversion.
    70cb45c665 learning-switch: Fix coredump of OpenFlow15 learning-switch.


* Mon Apr 24 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-82
- Merging upstream branch-2.17 [RH git: 34bbf561db]
    Commit list:
    b082241945 ovsdb: Allow conversion records with no data in a clustered storage.
    efcdf6c0de ovsdb: Check for ephemeral columns before writing a new schema.
    bf39ea3c79 ovsdb-tool: Fix cluster-to-standalone for DB conversion records.


* Fri Apr 07 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-81
- Merging upstream branch-2.17 [RH git: a1438ec598]
    Commit list:
    4f82f89039 ovs-tcpdump: Stdout is shutdown before ovs-tcpdump exit.


* Thu Apr 06 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-80
- Merging upstream branch-2.17 [RH git: a34e49c430]
    Commit list:
    77116d9903 Prepare for 2.17.7.
    a08bb41e3c Set release date for 2.17.6.


* Thu Apr 06 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-79
- Merging upstream branch-2.17 [RH git: 6a73129db8]
    Commit list:
    27fb5db7f7 ofproto-dpif-xlate: Always mask ip proto field. (#2134873)


* Tue Apr 04 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-78
- Merging upstream branch-2.17 [RH git: dd004f4cf6]
    Commit list:
    c3684a0604 conntrack-tp: Fix clang warning.
    be19308aaf netdev-offload-tc: Del ufid mapping if device not exist.


* Tue Apr 04 2023 Timothy Redaelli <tredaelli@redhat.com> - 2.17.0-77
- ofproto-dpif-xlate: Always mask ip proto field. [RH git: cfd5c61966] (#2134873)
    The ofproto layer currently treats nw_proto field as overloaded to mean
    both that a proper nw layer exists, as well as the value contained in
    the header for the nw proto.  However, this is incorrect behavior as
    relevant standards permit that any value, including '0' should be treated
    as a valid value.
    
    Because of this overload, when the ofproto layer builds action list for
    a packet with nw_proto of 0, it won't build the complete action list that
    we expect to be built for the packet.  That will cause a bad behavior
    where all packets passing the datapath will fall into an incomplete
    action set.
    
    The fix here is to unwildcard nw_proto, allowing us to preserve setting
    actions for protocols which we know have support for the actions we
    program.  This means that a traffic which contains nw_proto == 0 cannot
    cause connectivity breakage with other traffic on the link.
    
    Reported-by: David Marchand <dmarchand@redhat.com>
    Reported-at: https://bugzilla.redhat.com/show_bug.cgi?id=2134873
    Acked-by: Ilya Maximets <i.maximets@ovn.org>
    Signed-off-by: Aaron Conole <aconole@redhat.com>


* Wed Mar 29 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-76
- Merging upstream branch-2.17 [RH git: d63f1374ab]
    Commit list:
    4f41e58bc6 netdev-tc-offloads: Fix misaligned 8 byte read.


* Tue Mar 28 2023 David Marchand <david.marchand@redhat.com> - 2.17.0-75
- net/i40e: revert link status check on device start [RH git: 79a3a95a21] (#2138116)
    [ upstream commit a8ca8edf8c076c765c6d142ab4664a1f61414233 ]
    
    The mentioned changes broke existing applications when the link status
    of i40e ports is down at the time the port is started.
    Revert those changes, the original issue will need a different fix.
    
    Fixes: a4ba77367923 ("net/i40e: enable maximum frame size at port level")
    Fixes: 2184f7cdeeaa ("net/i40e: fix max frame size config at port level")
    Fixes: 719469f13b11 ("net/i40e: fix jumbo frame Rx with X722")
    
    Reported-at: https://bugzilla.redhat.com/show_bug.cgi?id=2138116
    Signed-off-by: David Marchand <david.marchand@redhat.com>
    Acked-by: Simei Su <simei.su@intel.com>


* Mon Mar 27 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-74
- Merging upstream branch-2.17 [RH git: a86c3f2963]
    Commit list:
    d6d1cad6a7 dpif-netlink: Always create at least 1 handler.


* Mon Mar 20 2023 Timothy Redaelli <tredaelli@redhat.com> - 2.17.0-73
- Install shared linked binaries (all, but ovs-vswitchd) [RH git: 590d558943] (#2159631)
    Resolves: #2159631


* Wed Mar 15 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-72
- Merging upstream branch-2.17 [RH git: aa069916b4]
    Commit list:
    09e6e1de7a ofproto-dpif-upcall: Wait for valid hw flow stats before applying min-revalidate-pps.


* Tue Mar 14 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-71
- Merging upstream branch-2.17 [RH git: 0144f0fed7]
    Commit list:
    691b9e5148 system-traffic: Fix conntrack test cases which are failing with af_xdp.


* Tue Mar 07 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-70
- Merging upstream branch-2.17 [RH git: 0b8ab7fa79]
    Commit list:
    7aa314c9c2 netdev-windows: Add checking when creating netdev with system type on Windows
    215278bded ofproto-dpif-upcall: Include hardware offloaded flows in total flows.
    4a3f8845e9 ofproto-dpif-upcall: Reset ukey's last stats value if the datapath changed.


* Thu Mar 02 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-69
- Merging upstream branch-2.17 [RH git: 887978485c]
    Commit list:
    132fa24b65 classifier: Fix missing masks on a final stage with ports trie.


* Mon Feb 27 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-68
- Merging upstream branch-2.17 [RH git: 33a871473f]
    Commit list:
    8661abd4c4 ofproto: Fix re-creation of tunnel backing interfaces on restart.


* Tue Feb 21 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-67
- Merging upstream branch-2.17 [RH git: 54dfe953e9]
    Commit list:
    638441e981 ovs-actions: Correct typo in ovs-actions man page.


* Tue Feb 21 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-66
- Merging upstream branch-2.17 [RH git: 05aa9c16ae]
    Commit list:
    3c4bd63bca ofproto-ipfix: Use per-domain template timeouts.
    d2583ccb74 ofproto-dpif-upcall: Use last known stats ukey stats on revalidate missed dp flows.
    705190d88e conntrack: Properly unNAT inner header of related traffic. (#2137754)
    d87b6180ec dpctl: Fix memory leak in flush conntrack.


* Mon Feb 13 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-65
- Merging upstream branch-2.17 [RH git: 2011158f64]
    Commit list:
    6626562c53 sparse: Fix build with DPDK and GCC 12.
    82dc71f808 ovsdb-server: Fix handling of DNS name for listener configuration.
    9b341844e7 netdev-offload-tc: If the flow has not been used, report it as such.
    adac28dcdf netdev-offload-tc: Conntrack ALGs are not supported with tc.
    a1c2abba78 netdev-offload-tc: Fix tc conntrack force commit support.
    68a2818b09 ofproto-dpif-upcall: New ukey needs to take the old ukey's dump seq.
    2eb7a60668 netdev-offload-tc: Preserve tc statistics when flow gets modified.
    4f51407698 sparse: Fix numa.h for libnuma >= 2.0.13.


* Tue Feb 07 2023 Eelco Chaudron <echaudro@redhat.com> - 2.17.0-64
- ofproto-dpif-xlate: Optimize datapath action set by removing last clone action. [RH git: 684b6e8ad9]
    Manual backport of the below commit. In addition to the upstream fix,
    we also had to bring in the nl_msg_reset_size() function. We also had
    to fix-up nine test cases as they where showing incorrect results.
    
    Bugzilla       : https://bugzilla.redhat.com/2110018
    Upstream commit: 4f5decf4ab3f ("ofproto-dpif-xlate: Optimize datapath action set by removing last clone action.")
    
      When OFPROTO non-reversible actions are translated to data plane
      actions, the only thing looked at is if there are more actions
      pending. If this is the case, the action is encapsulated in a
      clone().
    
      This could lead to unnecessary clones if no meaningful data
      plane actions are added. For example, the register pop in the
      included test case.
    
      The best solution would probably be to build the full action
      path and determine if the clone is needed. However, this would
      be a huge change in the existing design, so for now, we just try
      to optimize the generated datapath flow. We can revisit this
      later, as some of the pending CT issues might need this rework.
    
      Fixes: feee58b9587f ("ofproto-dpif-xlate: Keep track of the last action")
      Fixes: dadd8357f224 ("ofproto-dpif: Fix issue with non-reversible actions on a patch ports.")
      Acked-by: Ales Musil <amusil@redhat.com>
      Signed-off-by: Eelco Chaudron <echaudro@redhat.com>
      Signed-off-by: Ilya Maximets <i.maximets@ovn.org>
    
    Signed-off-by: Eelco Chaudron <echaudro@redhat.com>


* Mon Jan 30 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-63
- Merging upstream branch-2.17 [RH git: 64bd43b450]
    Commit list:
    32853c0844 tc: Add TCA_KIND flower to delete and get operation to avoid rtnl_lock().
    037131229b netdev-offload-tc: Fix misaligned access to ct label.
    206409bb79 ovsdb: Fix database statistics during the database replacement.


* Mon Jan 09 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-62
- Merging upstream branch-2.17 [RH git: 19293654b8]
    Commit list:
    0f55eced1e cirrus: Update to use FreeBSD 12.4.


* Mon Jan 09 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-61
- Merging upstream branch-2.17 [RH git: 66e0311ad1]
    Commit list:
    e9336a91f6 tc: Add support for TCA_STATS_PKT64. (#1776816)


* Fri Jan 06 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-60
- Merging upstream branch-2.17 [RH git: 2f7e5ad3ed]
    Commit list:
    ba62a1eae6 Documentation: Fix links in maintainers.rst.
    1b76faf8d1 Documentation: Fix links in the DPDK guide on physical ports.
    e1ee9c32a4 treewide: Don't use non-portable '==' with test command.
    a7d7c30c48 dpif: Fix tunnel key set for IPv6 tunnels with SLOW_ACTION.


* Wed Jan 04 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-59
- Merging upstream branch-2.17 [RH git: 7151f74734]
    Commit list:
    8d055809b8 ci: Fix overriding OPTS provided from the yml.
    0eb2aa46be Prepare for 2.17.6.
    08971e4b93 Set release date for 2.17.5.
    ecaacb01a9 lldp: Fix bugs when parsing malformed AutoAttach.
    ee002b3514 dpif-netdev: Use unmasked key when adding datapath flows.
    18dcfda673 ovsdb-cs: Consider default conditions implicitly acked.
    793709a856 rculist: Use rculist_back_protected to access prev.
    abb9d3482e Prepare for 2.17.5.
    b6c3788fe2 Set release date for 2.17.4.
    b50f4e3d21 odp-util: Fix reporting unknown keys as keys with bad length.
    44012fccdc ovs-dpctl-top: Fix ovs-dpctl-top via pipe.


* Tue Dec 06 2022 Timothy Redaelli <tredaelli@redhat.com> - 2.17.0-58
- net/i40e: fix jumbo frame Rx with X722 [RH git: 768e70d2a5]
    [ upstream commit 719469f13b11dbdc921b74258f2d10bd1c5328d4 ]
    
    For NIC I40E_10G-10G_BASE_T_X722, when the port is configured with
    link speed, it cannot receive jumbo frame packets.
    
    Because it set maximum frame size failed when starts the port that
    the port link status is still down.
    
    This patch fix the error that starts the port will force set maximum
    frame size.
    
    Fixes: 2184f7cdeeaa ("net/i40e: fix max frame size config at port level")
    
    Signed-off-by: Jie Wang <jie1x.wang@intel.com>
    Tested-by: Dukai Yuan <dukaix.yuan@intel.com>


* Thu Nov 24 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-57
- Merging upstream branch-2.17 [RH git: 73470e2571]
    Commit list:
    118e4349db rculist: Fix iteration macros.
    c9f10ae334 vswitchd: Publish per iface received multicast packets.
    4e3f9951fb learn: Fix parsing immediate value for a field match.
    282ba24d99 datapath-windows: Check the condition to reset pseudo header checksum on Rx side


* Tue Nov 22 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-56
- Merging upstream branch-2.17 [RH git: b01d0d7482]
    Commit list:
    ee0e1d0a51 netdev-offload-dpdk: Enhance the support of tunnel pop action


* Sat Nov 05 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-55
- Merging upstream branch-2.17 [RH git: 91cc3eb3bf]
    Commit list:
    4e3d762f05 ci: Update meson requirement for DPDK.


* Fri Nov 04 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-54
- Merging upstream branch-2.17 [RH git: 28e77c1573]
    Commit list:
    0d1e425c7c ovsdb: transaction: Fix weak reference leak.
    ceab1ca1ec ovsdb: transaction: Refactor assess_weak_refs.


* Wed Nov 02 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-53
- Merging upstream branch-2.17 [RH git: 5c721e65a7]
    Commit list:
    fa95bf9621 ovs-tcpdump: Cleanup mirror port on SIGHUP/SIGTERM.
    7ebef81f91 netdev-linux: Fix inability to apply QoS on ports with custom qdiscs. (#2138339)
    037ef6301b tc: Fix misaligned writes while parsing pedit.
    869e2e1ba0 odp-util: Add missing separator in format_odp_conntrack_action().
    0aa55709fc vswitch.xml: Fix the name of rstp-path-cost option.
    af459fa370 mac-learning: Fix learned fdb entries not age out issue.
    c4336a1f12 ofproto-dpif-xlate: Update tunnel neighbor when receive gratuitous ARP.
    683508cd4e bond: Fix crash while logging not yet enabled member.
    41b178d525 netdev-dpdk: Fix tx_dropped counters value.


* Wed Oct 26 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-52
- Merging upstream branch-2.17 [RH git: 2e56cd8bfd]
    Commit list:
    d0276481a1 unaligned: Correct the stats of packet_count and byte_count on Windows.
    71401199ff tests: Fix filtering of whole-second durations.
    3c1c034e58 netdev-offload: Set 'miss_api_supported' to be under netdev.


* Tue Oct 18 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-51
- Merging upstream branch-2.17 [RH git: 8ffcf35d65]
    Commit list:
    35615cd37a cmap: Add thread fence for slot update.
    5f8ba216a4 ofproto-dpif-xlate: Do not use zero-weight buckets in select groups.


* Thu Oct 13 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-50
- Merging upstream branch-2.17 [RH git: de74ee2fd8]
    Commit list:
    5e26f88b4f github: Update versions of action dependencies.


* Tue Oct 11 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-49
- Merging upstream branch-2.17 [RH git: b62483b493]
    Commit list:
    afce3662f7 ovs-tcpdump: Fix bond port unable to capture jumbo frames.
    602a41bb3b json: Fix deep copy of objects and arrays.


* Fri Oct 07 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-48
- Merging upstream branch-2.17 [RH git: bf1601978f]
    Commit list:
    5dde4d748e Prepare for 2.17.4.
    2b4b4b8689 Set release date for 2.17.3.


* Fri Oct 07 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-47
- Merging upstream branch-2.17 [RH git: abaac3dca6]
    Commit list:
    fbc3b10e9f Add support for OpenSSL 3.0 functions.
    5a77d53b8e dhparams: Fix .c file generation with OpenSSL >= 3.0.


* Fri Oct 07 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-46
- Merging upstream branch-2.17 [RH git: b2b4334db0]
    Commit list:
    09e22fec45 daemon-unix: Fix file descriptor leak when monitor restarts child.
    53df50db26 vconn: Allow ECONNREFUSED in refuse connection test.
    26a11ca610 dpdk: Use DPDK 21.11.2 release.
    edf699ec64 m4: Test avx512 for x86 only.
    1989caf9ea ovsdb-idl: Preserve references for rows deleted in same IDL run as their insertion. (#2126450)
    db6a612cd7 python: idl: Fix idl.Row.__str__ method.
    73d7bf64a7 bond: Avoid deadlock while updating post recirculation rules.
    70a63391cb ofproto-dpif-upcall: Add debug commands to pause/resume revalidators.
    cf0e12f8ae test-list: Fix false-positive build failure with GCC 12.


* Tue Oct 04 2022 Timothy Redaelli <tredaelli@redhat.com> - 2.17.0-45
- redhat: get the NVR from spec file directly [RH git: f3b0501deb]
    Fixes: 339efe77c4c7 ("pkgtool: keep %{?dist} before added bz string")


* Wed Sep 21 2022 Timothy Redaelli <tredaelli@redhat.com> - 2.17.0-44
- vhost: fix virtqueue use after free on NUMA reallocation [RH git: 68652b2a12]
    [ upstream commit 0b2a2ca35037d6a5168f0832c11d9858b8ae946a ]
    
    translate_ring_addresses (via numa_realloc) may change a virtio device and
    virtio queue.
    The virtqueue object must be refreshed before accessing the lock.
    
    Fixes: 04c27cb673b9 ("vhost: fix unsafe vring addresses modifications")
    
    Signed-off-by: David Marchand <david.marchand@redhat.com>
    Reviewed-by: Maxime Coquelin <maxime.coquelin@redhat.com>


* Wed Sep 14 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-43
- Merging upstream branch-2.17 [RH git: e91381d8a7]
    Commit list:
    5cbed27c87 tests: Fix tests with GNU grep 3.8.


* Mon Sep 12 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-42
- Merging upstream branch-2.17 [RH git: 72e5d18fde]
    Commit list:
    a5cd60db0f cirrus: Upgrade to FreeBSD 13.1 image.
    43ece36f31 netdev-linux: Skip some internal kernel stats gathering.
    846d6a0c51 ofproto-dpif-xlate: Fix error messages for nonexistent ports/recirc_ids.
    e8814c9b88 ofproto-dpif-xlate: Clear tunnel wc bits if original packet is non-tunnel.


* Tue Sep 06 2022 Timothy Redaelli <tredaelli@redhat.com> - 2.17.0-41
- Merging 7bcd45ce82 version: 21.11.2 [RH git: c132ae122f]
    Commit list:
    7bcd45ce82 version: 21.11.2
    e12d415556 vhost: fix header spanned across more than two descriptors
    f167022606 vhost: discard too small descriptor chains
    25c01bd323 net/mlx5: fix Rx queue recovery mechanism
    125a65cb03 examples/performance-thread: fix build with GCC 12
    2a55c38e27 test/crypto: skip oop test for raw api
    a561d44985 net/vhost: fix null pointer dereference
    0f80c13b4d version: 21.11.2-rc1
    84b2018842 app/testpmd: fix GTP PSC raw processing
    9e7d93ae2f net/iavf: fix GTP-U extension flow
    b11e955370 vdpa/sfc: resolve race between vhost lib and device conf
    06b246ead6 vdpa/ifc/base: fix null pointer dereference
    dbe68f0958 vdpa/mlx5: fix leak on event thread creation
    9224015451 examples/link_status_interrupt: fix stats refresh rate
    b941165a00 examples/vhost: fix retry logic on Rx path
    f169902058 avoid AltiVec keyword vector
    20ee5fbe91 app/regex: fix mbuf size for multi-segment buffer
    81a0919f6a app/regex: avoid division by zero
    e1c3685b21 dma/idxd: fix null dereference in PCI remove
    5b7a2b5672 dma/idxd: fix partial freeing in PCI close
    1fd4a985e4 dma/idxd: fix memory leak in PCI close
    008e1abc82 net/mlx5: reject negative integrity item configuration
    fa1d93b8c4 common/mlx5: fix non-expandable global MR cache
    03a6a9f751 common/cnxk: allow changing PTP mode on CN10K
    8fb51606a7 gro: fix identifying fragmented packets
    e46eb5a8dc service: fix lingering active status
    399cbc736c net/igc: support multi-process
    97e75c37b0 net/iavf: fix VF reset
    bbc9dcaefa common/cnxk: fix GRE tunnel parsing
    36f4c8e67f net/virtio-user: fix Rx interrupts with multi-queue
    c353b1de9f vhost: restore device information in log messages
    1f963ee7a3 vhost: add some trailing newline in log messages
    4ef6a79d4a vdpa/sfc: fix sync between QEMU and vhost-user
    5991d25b74 net/vhost: fix deadlock on vring state change
    a3ff1d7e9c doc: fix readability in vhost guide
    19457a68ea net/virtio-user: fix socket non-blocking mode
    3287afa5e8 net/netvsc: fix vmbus device reference in multi-process
    b6e4963255 app/testpmd: fix supported RSS offload display
    49cc0b73a0 eventdev/eth_tx: fix queue delete
    a1564274cd doc: fix grammar and parameters in l2fwd-crypto guide
    a8b87a7063 doc: fix grammar and formatting in compressdev guide
    8017591016 crypto/qat: fix DOCSIS crash
    f2a62f854e examples/fips_validation: handle empty payload
    390e956b6d test/crypto: fix SNOW3G vector IV format
    35b1acf851 test/crypto: fix ZUC vector IV format
    6706a66aaa test/crypto: fix authentication IV for ZUC SGL
    f95b184d1e doc: add more instructions for running as non-root
    a74fd43471 net/bnxt: fix check for autoneg enablement in the PHY FW
    7a91bb4238 net/bnxt: cleanup MTU setting
    1ab0afa450 net/bnxt: disallow MTU change when device is started
    8185654d05 net/bnxt: fix setting forced speed
    e798345849 net/bnxt: allow Tx only or Rx only
    cce3a4048e net/bnxt: fix switch domain allocation
    17d26c7fa0 examples/distributor: fix distributor on Rx core
    8bbab0b5a5 net/hns3: delete unused code
    32535f69cd net/hns3: fix descriptors check with SVE
    5a05333308 net/hns3: fix statistics locking
    6420d2f828 net/hns3: fix PTP interrupt logging
    bdabb55ddc net/hns3: support backplane media type
    a650bf5cfe net/hns3: fix link status capability query from VF
    44dad33c76 app/testpmd: fix GTP PSC raw processing
    5dee226e46 net: fix GTP PSC headers
    95b87a5314 app/testpmd: fix flex parser destroy command
    2a4ad9bb84 app/testpmd: cleanup port resources after implicit close
    bbf31ae0fc test: check memory allocation for CRC
    ed8a477487 app/procinfo: show all non-owned ports
    6fce2b8067 test/hash: fix out of bound access
    7181c621fb rib: fix references for IPv6 implementation
    1b31f49983 dma/idxd: fix non-AVX builds with old compilers
    d6e109f8aa dma/idxd: fix AVX2 in non-datapath functions
    b72fa6fd7a raw/ioat: fix build when ioat dmadev enabled
    d028271a0a raw/ioat: fix build missing errno include
    a3d0dbcf03 config: fix C++ cross compiler for Arm and PPC
    3a9c3000f4 vdpa/mlx5: fix maximum number of virtqs
    45150fc78b vdpa/mlx5: workaround var offset within page
    0de69e279d doc: fix flow integrity hardware support in mlx5 guide
    02017fcad3 net/mlx5: fix stack buffer overflow in drop action
    f8b370bbb4 net/mlx5: fix metering on E-Switch Manager
    aa8fb4afda net/mlx5: add limitation for E-Switch Manager match
    fac54fde60 net/mlx5: fix RSS expansion for patterns with ICMP item
    de9fa7b453 net/mlx5: fix build with clang 14
    e4939398df net/qede: fix build with GCC 12
    cca0819d48 net/ice/base: fix build with GCC 12
    f361d278e7 net/ice: fix race condition in Rx timestamp
    f294a3dbb0 net/qede: fix build with GCC 13
    760f94b15a common/cnxk: handle ROC model init failure
    3a66cbb695 common/cnxk: fix decrypt packet count register update
    614cd42ac0 net/octeontx: fix port close
    bee8c21938 malloc: fix allocation of almost hugepage size
    7b610e0a8d net/virtio: unmap PCI device in secondary process
    d6e4e0f46e vhost/crypto: fix descriptor processing
    f69a61bde0 vhost/crypto: fix build with GCC 12
    361723acef vhost: fix missing enqueue pseudo-header calculation
    76556a3128 app/testpmd: revert MAC update in checksum forwarding
    1901dc5492 net/ngbe: add more packet statistics
    a92e31d35d net/txgbe: fix register polling
    f48795dea1 app/testpmd: fix bonding slave devices not released
    b3cfb3db85 app/testpmd: add help messages for multi-process
    bfaaf994a5 net/hns3: fix TM capability
    35582af08c net/hns3: fix crash from secondary process
    ba4aa140b3 net/hns3: fix return value for unsupported tuple
    332e5fca03 net/hns3: fix code check warning
    fc61bd5d37 net/hns3: remove duplicate definition
    e885f508d9 net/hns3: fix an unreasonable memset
    8854374c9e test/bonding: fix RSS test when disable RSS
    2b71d44b80 net/bonding: fix RSS inconsistency between ports
    bd9ffc1961 eventdev/eth_tx: fix adapter creation
    19591ad643 event/dlb2: fix advertized capabilities
    f7b34f357c event/cnxk: fix Tx adapter enqueue return for CN10K
    93b1138ccd event/cnxk: fix QoS parameter handling
    e6f569043c event/dlb2: fix check of QID in-flight
    7c0439f319 event/dlb2: rework queue drain handling
    d2c3d326d0 event/octeontx: fix SSO fast path
    bf7aa26ddd net/nfp: fix initialization
    1c770fda6f net/nfp: make sure MTU is never larger than mbuf size
    fe2cddeb08 net/nfp: update how max MTU is read
    095d2af061 crypto/cnxk: swap zuc-256 iv
    38eabfdd0d common/cnxk: swap zuc-256 key
    d1e2bd80a6 test/ipsec: fix performance test
    387d7f2a33 test/crypto: fix cipher offset for ZUC
    bf03e0341c crypto/scheduler: fix queue pair in scheduler failover
    9445fcf138 test/ipsec: fix build with GCC 12
    e0bff8480f crypto/cnxk: fix build with GCC 12
    978835ed87 common/cpt: fix build with GCC 12
    a9485fd00b examples/ipsec-secgw: fix ESN setting
    362a219f40 net/iavf: fix NAT-T payload length
    be3beb946e examples/ipsec-secgw: fix NAT-T header fields
    d6a5fb4092 ipsec: fix NAT-T ports and length
    fd2d725ae5 baseband/acc100: add protection for some negative scenario
    4184a99adb baseband/acc100: update companion PF configure function
    4fb5429816 eal/x86: drop export of internal alignment macro
    bba01c7ab8 sched: remove unnecessary floating point
    03b38f5281 test: drop reference to removed tests
    b55b2820d2 trace: fix init with long file prefix
    17615c81fe trace: fix crash when exiting
    64fdce75b6 net/mlx5: fix RSS hash types adjustment
    1fb92a1f45 net/bnxt: fix tunnel stateless offloads
    e10c862914 net/iavf: fix segfaults when calling API after VF reset failed
    8e8886a0e9 dma/hisilicon: fix includes in header file
    e027f40cd2 dma/skeleton: fix index returned when no memcpy completed
    675b5bdf2c app/flow-perf: fix build with GCC 12
    f85d0fc397 vdpa/ifc: fix build with GCC 12
    ec6a2fa05c net/ice: fix build with GCC 12
    ac8e3a7546 net/enetfec: fix build with GCC 12
    9c1822f59f net/ena: fix build with GCC 12
    c86456efc9 crypto/ipsec_mb: fix build with GCC 12
    4cfe560401 kni: use dedicated function to set MAC address
    9b7982b986 kni: use dedicated function to set random MAC address
    e731132bca net/tap: fix device freeing
    63bb35c3f3 net/failsafe: fix device freeing
    a9062fa2fc app/testpmd: fix multicast address pool leak
    c18ad5cc3e app/testpmd: fix packet segment allocation
    8bb9213bbc dma/idxd: fix error code for PCI device commands
    5215fd05ab doc: fix formatting and link in BPF library guide
    7133eadc9c bus/fslmc: fix VFIO setup
    d2d91f50f7 raw/ifpga: unregister interrupt on close
    56e6acc152 raw/ifpga: remove virtual devices on close
    e06a55362a eal/ppc: fix compilation for musl
    c3a48df3d5 dma/hisilicon: enhance CQ scan robustness
    543121b53e dma/hisilicon: fix index returned when no DMA completed
    d1461844a6 examples/dma: fix Tx drop statistics
    6564af3d39 examples/dma: fix MTU configuration
    5d71b3d9fa common/mlx5: remove unused lcore check
    94b9525189 net/iavf: remove dead code
    f0c897ea5a net/iavf: increase reset complete wait count
    341d13b08b net/iavf: fix device stop
    eab5e035ce net/iavf: fix device initialization without inline crypto
    78cf4cbe62 doc: update matching versions in i40e guide
    d124639aee net/iavf: fix Rx queue interrupt setting
    4a42ee9346 net/iavf: fix mbuf release in multi-process
    e1a84de6a9 net/iavf: fix queue start exception handling
    6730951205 net/i40e: fix max frame size config at port level
    cfa67fc84b net/ice: fix MTU info for DCF
    356142f8a2 net/ice/base: fix direction of flow that matches any
    745563ca3c net/ice/base: fix getting sched node from ID type
    97f8a95696 net/ixgbe: add option for link up check on pin SDP3
    111417a49b net/iavf: fix data path selection
    c8868b3c5c kni: fix build
    3aeeea257f kni: fix build with Linux 5.18
    301300a86e net/mlx5: fix statistics read on Linux
    83abe945a6 net/mlx5: fix Tx recovery
    f06feb0822 examples/vhost: fix crash when no VMDq
    a7c72e3e6c vhost: fix deadlock when message handling failed
    e156da31dd doc: fix vhost multi-queue reconnection
    17a0ef7be3 vhost: fix async access
    c8c6eeda37 net/bnxt: fix ULP parser to ignore segment offset
    ca961550e9 net/bnxt: fix compatibility with some old firmwares
    ee3b68b408 ethdev: fix port close in secondary process
    da7caee013 common/sfc_efx/base: convert EFX PCIe INTF to MCDI value
    959cd86178 net/vmxnet3: fix Rx data ring initialization
    8c381b1157 app/testpmd: fix help of create meter command
    237d93b36c net/nfp: fix disabling VLAN stripping
    b3ef192fec net/txgbe: fix max number of queues for SR-IOV
    7b5339d563 net/txgbe: fix SGMII mode to link up
    8bf4f37ede net/ngbe: fix PCIe related operations with bus API
    512f325928 net/ngbe: fix reading PHY ID
    ba78db53ee net/ngbe: fix link speed check
    8e23b06316 ethdev: fix port state when stop
    54cb103e7b net/memif: fix overwriting of head segment
    fde361696c net/bonding: fix mbuf fast free usage
    ce5917f846 app/testpmd: do not poll stopped queues
    8b28d584d8 app/testpmd: fix use of indirect action after port close
    28e88ef39e ethdev: prohibit polling stopped queue
    011122b9e0 app/testpmd: fix metering and policing command for RFC4115
    e154ece049 app/testpmd: replace hardcoded min mbuf number with macro
    f7638851b4 net/cnxk: fix possible null dereference in telemetry
    c05dd44f52 ethdev: fix possible null pointer access
    e5177f3853 ethdev: fix memory leak in xstats telemetry
    2104014dbd net/axgbe: fix xstats get return if xstats is null
    3422f4b58c net/mvpp2: fix xstats get return if xstats is null
    7a1086a9d5 net/ipn3ke: fix xstats get return if xstats is null
    bae6c70cd3 net/hns3: fix xstats get return if xstats is null
    0c48dafbdf app/testpmd: remove useless pointer checks
    8378498b96 app/testpmd: perform SW IP checksum for GRO/GSO packets
    65bff89f9a app/testpmd: fix port status of bonding slave device
    4f9c7fb5af doc: add missing auth algo for IPsec example
    2d0ec22be8 test/crypto: fix driver name for DPAA raw API test
    082148b6a5 drivers/crypto: fix warnings for OpenSSL version
    48dda925a7 test/crypto: fix null check for ZUC authentication
    c195ec01df examples/ipsec-secgw: fix promiscuous mode option
    9c33903649 examples/ipsec-secgw: fix uninitialized memory access
    ea0ab8e686 pcapng: fix timestamp wrapping in output files
    412da85334 pipeline: fix emit instruction for invalid headers
    ce7b8e673a devtools: fix null test for NUMA systems
    84eb565954 doc: fix API index Markdown syntax
    d55a70f874 mbuf: dump outer VLAN
    2fcd1cc163 rib: fix traversal with /32 route
    8c5ab722fb acl: fix rules with 8-byte field size
    5ffee1e906 test: avoid hang if queues are full and Tx fails
    c1f49d47a9 eal/freebsd: fix use of newer cpuset macros
    214462a05b devargs: fix leak on hotplug failure
    29fa5a6eaf eal/x86: fix unaligned access for small memcpy
    eeaeb58d56 event/cnxk: fix out of bounds access in test
    09d859555f eventdev/eth_rx: fix telemetry Rx stats reset
    ec08dcaf4b doc: fix build with sphinx 4.5
    671e8fa0c8 net/mlx5: fix no-green metering with RSS
    6857653625 net/bnxt: fix freeing VNIC filters
    fa1a893ff7 net/bnxt: recheck FW readiness if in reset process
    2ff3768d20 net/bnxt: fix link status when port is stopped
    71ab79d3a7 net/bnxt: force PHY update on certain configurations
    db239d7290 net/bnxt: fix speed autonegotiation
    ce36a5d910 net/bnxt: avoid unnecessary endianness conversion
    8c464cf618 net/bnxt: handle queue stop during RSS flow create
    c25b1d545e net/bnxt: check duplicate queue IDs
    3f9914a7b3 net/bnxt: fix ring group on Rx restart
    821dd9cd43 net/bnxt: fix RSS action
    3774986bdd net/bnxt: fix Rx configuration
    d620238a97 net/bnxt: remove unused macro
    2f66d10615 net/bnxt: fix device capability reporting
    b174adfcae net/bnxt: fix reordering in NEON Rx
    7d9f5b3b33 net/cnxk: add barrier after meta batch free in scalar
    8790891a6d common/cnxk: fix SQ flush sequence
    08d2d8868e net/cnxk: fix uninitialized variables
    a10e2ec8ee common/cnxk: fix null pointer dereference
    d13786763a common/cnxk: fix unaligned access to device memory
    b117088323 net/cnxk: add message on flow parsing failure
    caf428f0a0 app/testpmd: fix MTU verification
    5e1545b730 app/testpmd: check statistics query before printing
    66b7e330d6 net/hns3: remove unnecessary RSS switch
    15b794b152 ethdev: fix RSS update when RSS is disabled
    0cec1c9477 net/hns3: remove redundant RSS tuple field
    5a6fb3a977 net/hns3: fix rollback on RSS hash update
    8c193c0b4c net/hns3: fix RSS disable
    8b00917c08 net/hns3: fix mbuf free on Tx done cleanup
    74089f471a net/hns3: fix pseudo-sharing between threads
    827f72e8ce net/hns3: fix MAC and queues HW statistics overflow
    d96ee7bac0 net/hns3: fix order of clearing imissed register in PF
    aa2c6d3f69 ethdev: fix build with vtune option
    b839853e83 net/tap: fix interrupt handler freeing
    41c0ba64de net/bonding: fix slave stop and remove on port close
    5a8afc69af net/bonding: fix stopping non-active slaves
    e856fe9aa6 doc: update matching versions in ice guide
    82ccc27de5 net/dpaa: fix event queue detach
    d24d6395d6 vdpa/mlx5: fix dead loop when process interrupted
    879fb64517 vdpa/mlx5: fix interrupt trash that leads to crash
    78414da84e vhost: fix missing virtqueue lock protection
    e3036fbd0a net/vhost: fix TSO feature default disablement
    4852da727c net/virtio: restore some optimisations with AVX512
    58d1b856be net/vhost: fix access to freed memory
    24dabb9d25 net/cxgbe: fix Tx queue stuck with mbuf chain coalescing
    6627ee48b5 net/cxgbe: fix port ID in Rx mbuf
    8cf194f699 net/bonding: fix RSS key config with extended key length
    3192737d10 net/nfp: remove unneeded header inclusion
    8ab93b06bc net/netvsc: fix hot adding multiple VF PCI devices
    03e1864411 test/mem: disable ASan when accessing unallocated memory
    e9b46ab763 net/mlx5: fix LRO configuration in drop Rx queue
    d5fdf0a2ba net/mlx5: fix LRO validation in Rx setup
    28ecf49a60 examples/l2fwd-crypto: fix stats refresh rate
    aeca5959dd common/dpaax: fix short MAC-I IV calculation for ZUC
    5a9af71a6d crypto/dpaa2_sec: fix operation status for simple FD
    5e3a3f48d1 crypto/dpaa2_sec: fix crypto operation pointer
    4644779034 crypto/dpaa_sec: fix secondary process probing
    15a3ae1a5f crypto/dpaa2_sec: fix chained FD length in raw datapath
    bee2c296c8 crypto/dpaa_sec: fix chained FD length in raw datapath
    86ba4e206e crypto/dpaa2_sec: fix buffer pool ID check
    f72e482fec crypto/dpaa2_sec: fix fle buffer leak
    8bad3a05f1 crypto/mlx5: fix login cleanup
    be6637f158 security: fix SA lifetime comments
    bb386a9f91 crypto/dpaa_sec: fix digest size
    f343d3b4ed eal: fix C++ include for device event and DMA
    de48c79f3b malloc: fix ASan handling for unmapped memory
    804b2e64eb mem: skip attaching external memory in secondary process
    65855b2d37 test/table: fix buffer overflow on lpm entry
    c7e0471948 net/mlx5: fix Rx/Tx stats concurrency
    b0e6a9c183 net/mlx5: fix GTP handling in header modify action
    b3896dba13 net/mlx5: restrict Rx queue array access to boundary
    c08c6247f2 net/mlx5: fix counter in non-termination meter
    99ba358268 net/mlx5: fix probing with secondary bonding member
    1430ccb1db net/mlx5: fix Tx when inlining is impossible
    72691359fa common/mlx5: fix memory region range calculation
    550f0d8288 net/netvsc: fix calculation of checksums based on mbuf flag
    21edf23c6d net/ice: fix raw flow input pattern parsing
    aedf24edbb net/ice: refactor parser usage
    bb6683a89f net/ice: add missing Tx burst mode name
    91355ad5b2 net/i40e: populate error in flow director parser
    8ae457cbf5 net/ice: improve performance of Rx timestamp offload
    a25197930d test/bpf: skip test if libpcap is unavailable
    6da5f268db examples/bond: fix invalid use of trylock
    9c267cbd10 net/dpaa2: fix dpdmux default interface
    d8898f0763 eal/windows: add missing C++ include guards
    fad1dbc0c5 eal/windows: fix data race when creating threads
    95e04d4866 doc: fix release note typo
    592c7bf714 net/af_xdp: make compatible with libbpf >= 0.7.0
    6721fb14eb net/af_xdp: use libxdp if available
    fcd039e466 version: 21.11.1
    2130012318 net/cnxk: fix build with optimization
    9518bcf700 net/mlx5: fix flex item availability
    05aa560efc version: 21.11.1-rc1
    b68dbab7c8 Revert "net/mlx5: fix flex item availability"
    bb5ce0625c crypto/ipsec_mb: fix GMAC parameters setting
    cef6bb00ce crypto/ipsec_mb: fix length and offset settings
    be2edca509 Revert "crypto/ipsec_mb: fix length and offset settings"
    dec4b1b89e raw/ifpga: fix build with optimization
    4586b6b8c2 doc: fix telemetry example in cryptodev guide
    2740b29e48 doc: fix missing note on UIO module in Linux guide
    713a4bc48c doc: replace characters for (R) symbol in Linux guide
    a50b228d2d net/mlx5: fix CPU socket ID for Rx queue creation
    8db2867c79 net/mlx5: fix port matching in sample flow rule
    7c12be128c eventdev: fix clang C++ include
    4f263532d0 cryptodev: fix clang C++ include
    ec8a6dc2e6 compressdev: fix missing space in log macro
    37232971b0 eal/freebsd: add missing C++ include guards
    8320df4804 examples/l3fwd: fix buffer overflow in Tx
    3313fe0301 app/testpmd: fix flow rule with flex input link
    39d09d7155 app/testpmd: fix GTP header parsing in checksum engine
    514668e230 app/testpmd: fix show RSS RETA on Windows
    3a3d4d3332 app/regex: fix number of matches
    f2a457c605 bpf: fix build with some libpcap version on FreeBSD
    e84b43b5eb crypto/ipsec_mb: fix GCM requested digest length
    8c7bebaa38 net/af_xdp: fix custom program loading with multiple queues
    88dbe7c555 net/qede: fix maximum Rx packet length
    09891782a4 net/qede: fix Rx bulk
    506f3198ab net/qede: fix Tx completion
    268985d32e doc: fix modify field action description for mlx5
    59a419a416 net/mlx5: fix implicit tag insertion with sample action
    42cf1850e2 net/mlx5: forbid multiple ASO actions in a single rule
    dd859e1797 net/mlx5: fix sample flow action on trusted device
    7680d1d321 net/mlx5: fix VLAN push action validation
    691ff0b6db net/mlx5: fix NIC egress flow mismatch in switchdev mode
    6cb68162e4 vhost: fix FD leak with inflight messages
    4c40d30d2b vhost: fix queue number check when setting inflight FD
    6ae8ba6b7a build: suppress rte_crypto_asym_op abi check
    efd091d541 devtools: fix symbols check
    026470bafa build: hide local symbols in shared libraries
    89f14be564 common/mlx5: consider local functions as internal
    6e7f8939f2 regexdev: fix section attribute of symbols
    6472c2d476 net/iavf: fix potential out-of-bounds access
    67191a9cb3 net/sfc: reduce log level of tunnel restore info error
    ee836190a1 net/mlx5: fix meter creation default state
    a17cea76b7 net/mlx5: fix configuration without Rx queue
    d31463e0b2 net/mlx5: fix MPLS/GRE Verbs spec ordering
    48fe9efaf2 net/mlx5: fix flex item availability
    3bd5cf393d net/mlx5: fix meter policy creation assert
    c77572d2a1 net/mlx5: remove unused reference counter
    0036f3941e net/mlx5: fix modify port action validation
    eebfb74c51 net/mlx5: fix shared RSS destroy
    5d3ade99bd net/mlx5: fix next protocol RSS expansion
    4500ec704f net/mlx5: fix inet IPIP protocol type
    9bdcba122b net/bnxt: fix null dereference in session cleanup
    4aadf56c66 ethdev: fix doxygen comments for device info struct
    0c7cbe52f7 build: fix build on FreeBSD with Meson 0.61.1
    dab4a96be2 devtools: remove event/dlb exception in ABI check
    4fa43b7bff vhost: fix physical address mapping
    f03f4b98c9 net/cnxk: fix Rx/Tx function update
    3a5e1aaee4 net/mlx5: fix initial link status detection
    295f5022f6 net/mlx5: fix link status change detection
    be828a8eaf common/mlx5: add Netlink event helpers
    7214354c52 examples/kni: add missing trailing newline in log
    f5ba75eb9a examples/l3fwd: make Rx and Tx queue size configurable
    ef48f23bfd examples/l3fwd: share queue size variables
    6bf720d7d7 examples/flow_classify: fix failure message
    2719708908 examples/distributor: reduce Tx queue number to 1
    7aa3bbafd6 app/dumpcap: check for failure to set promiscuous
    955a6afc6f test/bpf: skip dump if conversion fails
    e71f3dc931 pcapng: handle failure of link status query
    b8222349eb app/pdump: abort on multi-core capture limit
    8adbf6df92 raw/ifpga: fix monitor thread
    69da51b405 raw/ifpga: fix interrupt handle allocation
    d4536cf86a raw/ifpga: fix variable initialization in probing
    186250df3d gpu/cuda: fix dependency loading path
    af8ffbba79 sched: remove useless malloc in PIE data init
    8ebcaf23cb eal/linux: fix device monitor stop return
    89d84883b0 examples/vhost: fix launch with physical port
    7a5659dd94 vhost: fix linker script syntax
    b7f396be62 net/ice: fix Tx offload path choice
    28acfe550d common/cnxk: fix mbuf data offset for VF
    51af57d005 common/cnxk: fix bitmap usage for TM
    43dec151be net/iavf: fix AES-GMAC IV size
    f314e6acfb net/mlx5: fix flex item header length translation
    1926a8d8c5 net/mlx5: fix matcher priority with ICMP or ICMPv6
    1f5aede9bd net/mlx5: reduce flex item flow handle size
    279cc42d3b net/mlx5: fix GRE item translation in Verbs
    39cba36e63 doc: fix typos and punctuation in flow API guide
    41510092eb net/kni: fix config initialization
    6090ee620d net/txgbe: fix queue statistics mapping
    8a301f166c net/mlx5: fix check in count action validation
    c46eaf6f4c net/mlx5: fix shared counter flag in flow validation
    de3ad851ca net/mlx5: fix destroying empty matchers list
    6468addfe3 net/mlx5: fix indexed pool fetch overlap
    ae071e1851 net/iavf: fix function pointer in multi-process
    b82b6ed613 net/iavf: support NAT-T / UDP encapsulation
    5f275a0312 net/ixgbe: fix FSP check for X550EM devices
    aa6f865e7e net/hns3: increase time waiting for PF reset completion
    94420985c7 net/hns3: fix VF RSS TC mode entry
    dc3cb423f5 net/hns3: fix RSS TC mode entry
    772292049b net/hns3: remove duplicate macro definition
    24939fcc13 compressdev: fix socket ID type
    30fea0f0a6 app/compress-perf: fix number of queue pairs to setup
    b2b15ab556 app/compress-perf: fix socket ID type during init
    8ace98122a compress/mlx5: support out-of-space status
    d386e37612 app/compress-perf: optimize operations pool allocation
    c65e648405 app/compress-perf: fix cycle count operations allocation
    9bb7a3f9df event/dlb2: add shift value check in sparse dequeue
    d2b19d6346 event/cnxk: fix Rx adapter config check
    dd8c73295c event/cnxk: fix sub-event clearing mask length
    170c124998 kni: fix freeing order in device release
    0617d94900 bus/pci: assign driver pointer before mapping
    099aba7265 devargs: fix crash with uninitialized parsing
    dcf545fce1 eal/linux: fix illegal memory access in uevent handler
    38c59b06b0 distributor: fix potential overflow
    77b6873f73 efd: fix uninitialized structure
    b017e1159f test/efd: fix sockets mask size
    e9100a0196 doc: add CUDA driver features
    9703132099 app/testpmd: fix build without drivers
    158012beee app/testpmd: fix raw encap of GENEVE option
    8c4ce4d7ff net/i40e: fix unintentional integer overflow
    3334722c21 net/cnxk: fix RSS RETA table update
    b8bfbcd1a0 net/cnxk: fix build with GCC 12
    c957e1063b net/cnxk: fix inline IPsec security error handling
    ee97d867e7 net/cnxk: register callback early to handle initial packets
    c5124d0ea8 net/cnxk: fix inline device RQ tag mask
    283f54ba9d mempool/cnxk: fix batch allocation failure path
    ba9d00afac doc: correct name of BlueField-2 in mlx5 guide
    9385e97741 doc: replace broken links in mlx guides
    239796f3dd doc: remove obsolete vector Tx explanations from mlx5 guide
    2007577b29 net/mlx5: fix E-Switch manager vport ID
    a600672d1a net/mlx5: fix entry in shared Rx queues list
    7f982e1320 net/mlx5: fix meter sub-policy creation
    7b5ea7efc3 net/mlx5: remove unused function
    aff5b2ee60 net/mlx5: set flow error for hash list create
    d2e99680f9 common/mlx5: fix queue pair ack timeout configuration
    233c5aa3e7 net/ena: fix checksum flag for L4
    f5eff853e4 net/ena: check memory BAR before initializing LLQ
    70c3e891d0 net/ena: fix meta descriptor DF flag setup
    867dd857f4 net/ena: fix reset reason being overwritten
    c443512e3d net/ena: skip timer if reset is triggered
    4e9e9e29c4 net/ena: remove unused offload variables
    e63e5c79ce net/ena: remove unused enumeration
    399b489328 net/txgbe: fix debug logs
    a8be311dd1 net/ngbe: fix debug logs
    c1cf1a9735 app/testpmd: fix GENEVE parsing in checksum mode
    036993974f net/mlx5: fix errno update in shared context creation
    b6b1c3ad5d net/mlx5: fix ASO CT object release
    49257a9394 net/mlx5: fix ineffective metadata argument adjustment
    50f3a03f75 net/mlx5: fix sibling device config check
    e68285796c net/i40e: enable maximum frame size at port level
    15ff989ca8 net/iavf: fix segmentation offload buffer size
    dbb1c53725 net/iavf: fix segmentation offload condition
    d75be6c28d net/ice: fix overwriting of LSE bit by DCF
    a628e2bf19 net/af_xdp: ensure socket is deleted on Rx queue setup error
    ae2f030ad1 net/sfc: fix memory allocation size for cache
    ea21c6bf4e net/sfc: fix flow tunnel support detection
    a58ae9af98 common/sfc_efx/base: add missing handler for 1-byte fields
    4874f1d005 common/sfc_efx/base: fix recirculation ID set in outer rules
    e4b43ee28c net/cnxk: fix uninitialized local variable
    f0cfb0e3d1 common/cnxk: fix uninitialized pointer read
    2f61027cda common/cnxk fix unintended sign extension
    7eeb8d37ed common/cnxk: add missing checks of return values
    dd1851c1de net/af_xdp: add missing trailing newline in logs
    6a9b64907e common/cnxk: fix NPC key extraction validation
    87b639b4ed vhost: fix unsafe vring addresses modifications
    01e3dee29c vhost: fix field naming in guest page struct
    e09a0094a6 common/cnxk: fix base rule merge
    1751e87f51 common/cnxk: fix log level during MCAM allocation
    d91869302f common/cnxk: fix flow deletion
    450ee57e5f app/testpmd: check starting port is not in bonding
    387187932f net/bonding: fix slaves initializing on MTU setting
    c93302dd4f net/cnxk: fix mbuf data length
    116bfaa14e ethdev: fix MAC address in telemetry device info
    a42a874599 net/iavf: reset security context pointer on stop
    496747d389 net/txgbe: reset security context pointer on close
    223010f1da net/ixgbe: reset security context pointer on close
    967cb49748 net/nfb: fix multicast/promiscuous mode switching
    afe8e58fed net/nfb: fix array indexes in deinit functions
    daf06c45e8 crypto/ipsec_mb: fix length and offset settings
    cfa7703c8e crypto/ipsec_mb: fix ZUC operation overwrite
    1170e24b20 crypto/ipsec_mb: fix ZUC authentication verify
    bbc596578a crypto/ipsec_mb: check missing operation types
    9c67637c8c crypto/virtio: fix out-of-bounds access
    301ee2f378 baseband/acc100: avoid out-of-bounds access
    79247ddc0d examples/l2fwd-crypto: fix port mask overflow
    5772c7b32e doc: fix FIPS guide
    ad76dc4e91 examples/ipsec-secgw: fix buffer freeing in vector mode
    f092922c36 cryptodev: fix RSA key type name
    c8bcbe8b68 crypto/ipsec_mb: remove useless check
    fec66e64e5 event/cnxk: fix uninitialized local variables
    52d824d106 event/cnxk: fix variables casting
    9a552423fd event/dlb2: poll HW CQ inflights before mapping queue
    720fb431b4 event/dlb2: update rolling mask used for dequeue
    7d7a9f161d eventdev/eth_rx: fix queue config query
    529f3a735e eventdev/eth_rx: fix parameters parsing memory leak
    d33bb6bd28 examples/qos_sched: fix core mask overflow
    9970eab8c4 doc: improve configuration examples in idxd guide
    b254386fad dma/idxd: configure maximum batch size to high value
    ebc0188ccb test/dma: fix missing checks for device capacity
    c6aea57d99 dma/hisilicon: use common PCI device naming
    56d6e5b091 ethdev: fix cast for C++ compatibility
    5d75eb0924 cryptodev: add missing C++ guards
    c02f5bcfe9 bpf: add missing C++ guards
    362921a8e3 vhost: add missing C++ guards
    fb37e2b3ae kni: add missing C++ guards
    e4dbb6873a eventdev: add missing C++ guards
    3d1746c9ac compressdev: add missing C++ guards
    6fca954338 acl: add missing C++ guards
    447210e07c metrics: add missing C++ guards
    b99a45df05 ethdev: add missing C++ guards
    e7291176c2 telemetry: add missing C++ guards
    b2f85a808a eal: add missing C++ guards
    81c40b01d0 dmadev: add missing header include
    692ae335d6 eventdev/eth_tx: fix queue add error code
    adfebc59b5 pipeline: fix table state memory allocation
    1e8aa23aba pipeline: fix annotation checks
    13ddcf9dee raw/ntb: clear all valid doorbell bits on init
    0627e93c26 crypto/dpaax_sec: fix auth/cipher xform chain checks
    0fd24703c6 crypto/cnxk: fix update of number of descriptors
    2630bff5a4 compress/octeontx: fix null pointer dereference
    6f9d8df3d1 crypto/qat: fix GEN4 AEAD job in raw data path
    98ec92641b crypto/ipsec_mb: fix buffer overrun
    13aab9f493 crypto/ipsec_mb: fix premature dereference
    98ece68514 test/crypto: fix out-of-place SGL in raw datapath
    4d5d4d7abc examples/ipsec-secgw: fix offload flag used for TSO IPv6
    abfad6b59c net/txgbe: fix KR auto-negotiation
    42960ce408 net/txgbe: fix link up and down
    59691181a3 net/ngbe: fix packet statistics
    b9c20ea8f0 net/ngbe: fix Tx hang on queue disable
    3698c17f42 net/ngbe: fix missed link interrupt
    cacbd7e4f7 net/ngbe: fix Rx by initializing packet buffer early
    863d787942 net/bnxt: fix ring calculation for representors
    e53da2ffbe net/bnxt: set HW coalescing parameters
    6c8ff52958 net/mlx5: fix inline length for multi-segment TSO
    3831da6c7b net/mlx5: fix meter capabilities reporting
    6022babd1d net/mlx5: fix committed bucket size
    c9a140e15b net/mlx5: fix metadata endianness in modify field action
    8f821b1135 vdpa/sfc: fix null dereference during removal
    5dfd488d82 vdpa/sfc: fix null dereference during config
    7537c99618 net/ice: fix build with 16-byte Rx descriptor
    607d564355 net/ice: fix pattern check in flow director
    d422a9cdae net/ice/base: add profile validation on switch filter
    5dc74f1348 net/iavf: count continuous DD bits for Arm in flex Rx
    68522027e3 net/iavf: count continuous DD bits for Arm
    f746bb72ba net/iavf: fix null pointer dereference
    b832a197fa net/sfc: demand Tx fast free offload on EF10 simple datapath
    915b0b0b9f net/sfc: do not push fast free offload to default TxQ config
    6fdd1953b0 ethdev: remove unnecessary null check
    851b597291 net: fix L2TPv2 common header
    d594afc792 net/memif: remove pointer deference before null check
    273bacf2a8 config: align mempool elements to 128 bytes on CN10K
    e183e43e2b vfio: cleanup the multiprocess sync handle
    c32322e508 ipc: end multiprocess thread during cleanup
    6e1bc26cde test/mbuf: fix mbuf data content check
    472f790f95 app/fib: fix division by zero
    1058b2c369 mem: check allocation in dynamic hugepage init
    c59904ed03 vhost: fix C++ include
    6afaa0f3d7 table: fix C++ include
    91b9d6cd34 ipsec: fix C++ include
    4f328f8e2b graph: fix C++ include
    3668e54828 eventdev: fix C++ include
    1fdfd87f14 eal: fix C++ include
    72334ceaf1 config/arm: add values for native armv7
    02a96ad251 stack: fix stubs header export
    6b06137c98 regex/mlx5: fix memory allocation check
    72487940d1 net/virtio: fix slots number when indirect feature on
    160769f648 vhost: fix guest to host physical address mapping
    eaf935f63c net/sfc: fix lock releases
    ce413e1922 app/testpmd: fix stack overflow for EEPROM display
    ac180f4d26 net/tap: fix to populate FDs in secondary process
    721d0bbd16 ethdev: add internal function to device struct from name
    605d1de0d3 app/testpmd: fix bonding mode set
    7b71bc2d00 net/bonding: fix reference count on mbufs
    26f2cc6490 net/bonding: fix promiscuous and allmulticast state
    30dcde8467 net/ixgbe: check filter init failure
    e72696baa4 net/hns3: delete duplicated RSS type
    2ae91ac660 net/hns3: fix operating queue when TCAM table is invalid
    2b7587ea99 net/hns3: fix double decrement of secondary count
    10342b22ae net/hns3: fix insecure way to query MAC statistics
    9b1f69f906 net/hns3: fix RSS key with null
    d7033074e0 net/hns3: fix max packet size rollback in PF
    2c27da1e51 net/bonding: fix MTU set for slaves
    9ac1343c4d net/dpaa2: fix null pointer dereference
    90386f428c net/enic: fix dereference before null check
    57b2aa0265 test/mem: fix error check
    32cb4f09ff eal/windows: fix error code for not supported API
    5a9f8c2ba4 ring: fix overflow in memory size calculation
    8b45a1dea3 ring: fix error code when creating ring
    63cb4ae54f doc: fix KNI PMD name typo
    4f140c9a9a build: remove deprecated Meson functions
    aa8ad3e48c build: fix warnings when running external commands
    1e770ae599 pflock: fix header file installation
    86f7ed09ae doc: update matching versions in ice guide
    37d27abc59 net/mlx5: reject jump to root table
    bc3452d45d common/mlx5: fix probing failure code
    99f5cd0dc3 net/mlx5: fix mark enabling for Rx
    d157628041 common/mlx5: fix MR lookup for non-contiguous mempool
    4c4c0cf459 net/virtio: fix uninitialized RSS key
    0d2ddde419 net/virtio-user: check FD flags getting failure
    4210bb89d8 net/virtio-user: fix resource leak on probing failure
    efc7ea9dd7 vdpa/ifc: fix log info mismatch
    7c58dbf159 net/virtio: fix Tx queue 0 overriden by queue 128
    f05bbce185 vdpa/mlx5: workaround queue stop with traffic
    ad51b31a30 net/hns3: fix using enum as boolean
    9d6db3c3ad net/nfp: free HW ring memzone on queue release
    961922eb71 net/bonding: fix RSS with early configure
    6492c9875d net/hns3: fix vector Rx/Tx when PTP enabled
    9c10b251a1 net/hns3: fix mailbox wait time
    e073f410fb net/hns3: fix Rx/Tx functions update
    581e547a6f net/memif: remove unnecessary Rx interrupt stub
    5de680a494 raw/ifpga/base: fix port feature ID
    0f8f337740 net/bnxt: fix VF resource allocation strategy
    f70203b5c0 net/bnxt: fix memzone allocation per VNIC
    e44c18821c net/bnxt: handle ring cleanup in case of error
    a04034b131 net/bnxt: fix check for autoneg enablement
    72db0cca69 raw/ifpga: fix thread closing
    7c682d5c05 net/ice: fix link up when starting device
    b38f8855d6 net/ice: fix mbuf offload flag for Rx timestamp
    81597d6e20 raw/ifpga/base: fix SPI transaction
    4599a6179a net/sfc: validate queue span when parsing flow action RSS
    c935f2719d ethdev: fix Rx queue telemetry memory leak on failure
    3fd3c3b3b0 common/cnxk: fix error checking
    2253ed93c3 common/cnxk: fix uninitialized variables
    38f3a00894 common/cnxk: fix null pointer dereferences
    1349f9e568 common/cnxk: always use single interrupt ID with NIX
    cfcdf00068 common/cnxk: reset stale values on error debug registers
    285183e606 common/cnxk: fix byte order of frag sizes and infos
    5deff57b9d common/cnxk: fix shift offset for TL3 length disable
    41569f9deb net/nfp: remove useless range checks
    23c2f68598 net/nfp: remove duplicated check when setting MAC address
    85d9e45c32 net/mlx5: fix MPRQ WQE size assertion
    a9bc2a46c2 net/mlx5: fix maximum packet headers size for TSO
    70211750cc net/bnxt: restore dependency on kernel modules
    279f0d75c0 net/dpaa2: fix timestamping for IEEE1588
    c96ea2bf1c net/dpaa2: fix unregistering interrupt handler
    699c30f853 net/cxgbe: fix dangling pointer by mailbox access rework
    ef94549efe app/testpmd: fix external buffer allocation
    6d5f3984dc app/testpmd: fix dereference before null check
    83774f8a67 net/bonding: fix mode type mismatch
    40a4d0544b net/af_xdp: fix build with -Wunused-function
    181ddedb1a net/axgbe: use PCI root complex device to distinguish device
    bb1854bc69 app/testpmd: fix Tx scheduling interval
    96b92d045f net/bonding: fix offloading configuration
    661587eaae net/cnxk: fix promiscuous mode in multicast enable flow
    26a3e3e7d3 net/bnxt: check VF representor pointer before access
    2f9df1413c net/bnxt: fix xstats query
    b74a60df81 net/bnxt: fix crash by validating pointer
    2e31b779e8 net/bnxt: fix PAM4 mask setting
    6c57090c01 net/bnxt: fix ring teardown
    f2c08d53a1 net/bnxt: fix handling of VF configuration change
    377a9a8197 net/bnxt: get maximum supported multicast filters count
    b0fe5e2fa9 net/bnxt: fix flow create when RSS is disabled
    6b722d7b37 net/bnxt: add null check for mark table
    a31a8b6a97 net/bnxt: set fast-path pointers only if recovery succeeds
    6b7c0ce0ce net/bnxt: cap maximum number of unicast MAC addresses
    a9ea24c80c net/bnxt: fix restoring VLAN filtering after recovery
    56f92b77e7 net/bnxt: restore RSS configuration after reset recovery
    880ed79159 net/bnxt: fix queue stop operation
    f4d1e64dec net/bnxt: fix multicast MAC restore during reset recovery
    5e35fae222 net/bnxt: fix multicast address set
    c59f883c24 net/bnxt: fix xstats names query overrun
    9d1da3652a net/mlx5: relax headroom assertion
    ab06c7bf9b net/mlx5: fix GCC uninitialized variable warning
    379079d6cc net/mlx5: fix GRE protocol type translation for Verbs
    d8d54171bd net/mlx5: fix RSS expansion with explicit next protocol
    032e27c0b2 net/mlx5: fix assertion on flags set in packet mbuf
    59f8d27b5f common/mlx5: fix missing validation in devargs parsing
    407b3ae746 net/mlx5: fix memory socket selection in ASO management
    751bca90b1 common/mlx5: fix error handling in multi-class probe
    0832935bf5 net/ixgbe: add vector Rx parameter check
    1eef1cf7d3 net/ice: fix Tx checksum offload
    76a729e7ed net/ice: track DCF state of PF
    85e84c5930 net/iavf: remove git residue symbol
    3380c428a5 net/ice: fix Tx checksum offload capability
    a9ff22fc59 net/ice: fix pattern check for flow director parser
    f1339fd8ec net/qede: fix redundant condition in debug code
    9ff875ecff common/cnxk: fix nibble parsing order when dumping MCAM
    23b8e0a337 net/mlx5: fix MPRQ stride devargs adjustment
    c58aaabede net/mlx5: improve stride parameter names
    f873364dfe common/mlx5: add minimum WQE size for striding RQ
    0422d79548 net/mlx5: fix modify field MAC address offset
    d021a2f9b7 dma/cnxk: fix installing internal headers
    bb6b3ec4e9 devtools: fix comment detection in forbidden token check
    19aefaf2cb examples/ipsec-secgw: fix default flow rule creation
    8c4f0e9e73 examples/ipsec-secgw: fix eventdev start sequence
    5831db3bab crypto/ipsec_mb: fix tainted data for session
    4b8475c98e crypto/ipsec_mb: fix queue cleanup null pointer dereference
    07ee507051 crypto/ipsec_mb: fix queue setup null pointer dereference
    7823f35581 crypto/cnxk: fix extend tail calculation
    5977020bc3 crypto/cnxk: fix inflight count calculation
    99d6741b64 crypto/cnxk: enable allocated queues only
    de6b483f38 common/cnxk: fix reset of fields
    7ee503d33f common/cnxk: add workaround for vWQE flush
    e3b9a8c32f event/cnxk: fix QoS devargs parsing
    87646d04a1 examples/l3fwd: fix Rx burst size for event mode
    8d0ffec0cf eventdev/eth_rx: fix missing internal port checks
    393d0580db doc: fix dlb2 guide
    19c6e95cd6 eal/linux: log hugepage create errors with filename
    24e496918b config: add arch define for Arm
    a8dd54379d gpu/cuda: fix memory list cleanup
    8e8fe373c0 dma/idxd: fix wrap-around in burst capacity calculation
    e0f7faeba1 dma/idxd: fix paths to driver sysfs directory
    cb7d9a39cb dma/idxd: fix burst capacity calculation
    572305874a bus/ifpga: remove useless check while browsing devices
    c30f1ec97d doc: remove dependency on findutils on FreeBSD
    cb2e09a4da buildtools: fix AVX512 check for Python 3.5
    3b511fdf21 maintainers: update for stable branches
    b3122779a5 doc: replace deprecated distutils version parsing
    2be1e5158e fix spelling in comments and strings


* Thu Sep 01 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-40
- Merging upstream branch-2.17 [RH git: 696a65df68]
    Commit list:
    dfc3e65c81 raft: Fix unnecessary periodic compactions.
    6f322ccf8a netdev-offload-tc: Parse tunnel options only for geneve ports.


* Tue Aug 30 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-39
- Merging upstream branch-2.17 [RH git: 18a8544580]
    Commit list:
    a9f10a2bdc netdev-offload-tc: Add missing handling of the tunnel source port.
    ec2e967c1d netdev-offload-tc: Fix ignoring unknown tunnel keys.
    686984d9a0 netdev-offload-tc: Use masks instead of keys while parsing tunnel attributes.
    92c072d944 netdev-offload-tc: Explicitly handle mask for the tunnel destination port.
    87f191a3a3 netdev-offload-tc: Fix the mask for tunnel metadata length.
    cadcea6fea releases: Mark 2.17 as a new LTS release.
    8a1b734480 handlers: Fix handlers mapping.
    713072fdac handlers: Create additional handler threads when using CPU isolation.
    84a8910ffe packets: Fix misaligned access to ip6_hdr.
    fe27e0c884 python: Do not send non-zero flag for a SSL socket. (#2115035)


* Wed Aug 10 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-38
- Merging upstream branch-2.17 [RH git: 3803095f76]
    Commit list:
    729a872f19 dpif-netdev: Simplify AVX512 build time checks to enhance readability.


* Wed Aug 10 2022 Timothy Redaelli <tredaelli@redhat.com> - 2.17.0-37
- pkgtool: keep %{?dist} before added bz string [RH git: b129ea83d9]
    Signed-off-by: Timothy Redaelli <tredaelli@redhat.com>


* Tue Aug 09 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-36
- Merging upstream branch-2.17 [RH git: 66778aea49]
    Commit list:
    1b566f8b80 github: Move CI to ubuntu 20.04 base image.


* Mon Aug 08 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-35
- Merging upstream branch-2.17 [RH git: 2b96d7c354]
    Commit list:
    86725abe10 netdev-offload-tc: Disable offload of IPv6 fragments.
    2276daf889 ovs-save: Use right OpenFlow version for add-tlv-map.


* Mon Aug 08 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-34
- Merging upstream branch-2.17 [RH git: b2f86a115d]
    Commit list:
    c353e757d7 system-traffic: Fix IPv4 fragmentation test sequence for check-kernel.
    6f54dc134a system-traffic: Fix incorrect neigh entry in ipv6 header modification test.
    7848ae6ffb system-traffic: Don't run IPv6 header modification test on kernels < 5.19.
    399185865e netdev-linux: set correct action for packets that passed policer


* Thu Aug 04 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-33
- Merging upstream branch-2.17 [RH git: 3e07847983]
    Commit list:
    cda60c8558 python: Fix E275 missing whitespace after keyword.
    3678fb544d tc: Use sparse hex dump while printing inconsistencies.
    03a0ec82b7 netdev-offload-tc: Print unused mask bits on failure.
    5b8453a44e dynamic-string: Add function for a sparse hex dump.
    8d7cb1daf4 dpif-netlink: Fix incorrect bit shift in compat mode.
    d1cec26869 python: Use setuptools instead of distutils.
    8d6ecb2592 packets: Re-calculate IPv6 checksum only for first frag upon modify.
    26dbc822d3 test-ovsdb: Fix false-positive leaks from LeakSanitizer.
    6eab10cf2c m4: Update ax_func_posix_memalign to the latest version.
    2f51bfd23b m4: Replace obsolete AC_HELP_STRING with AS_HELP_STRING.
    8ad325aab5 libopenvswitch.pc: Add missing libs for a static build.
    b64ff3f480 rhel: Stop installing internal headers.
    b63bbf2dba python-c-ext: Handle initialization failures.
    4ad02ad047 netdev-linux: Do not touch LAG members if master is not attached to OVS.
    e6dcd07bc2 netdev: Clear auto_classified if netdev reopened with the type specified.


* Mon Jul 25 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-32
- Merging upstream branch-2.17 [RH git: 04dbaa3629]
    Commit list:
    1eedf45e81 system-traffic: Properly stop dangling ping after geneve test.
    fb8e34bdba conntrack: Fix conntrack multiple new state.
    af37f41188 python-c-ext: Fix a couple of build warnings.
    b7d9f76100 python-c-ext: Remove Python 2 support.
    02fb4bfb87 netdev-offload-dpdk: Setting RSS hash types in RSS action.
    8e8fcf7bda lib: Print nw_frag in flow key.
    29d8ce1adc ovsdb: Remove extra make target dependency for local-config.5.


* Thu Jul 14 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-31
- Merging upstream branch-2.17 [RH git: bdc6c6696c]
    Commit list:
    13ac0bc7c6 tc: Fix misaligned access while creating pedit actions.
    2c85d737a4 utilities/bashcomp: Fix incorrect file mode.


* Wed Jul 06 2022 Timothy Redaelli <tredaelli@redhat.com> - 2.17.0-30
- rhel: libarchive-devel is needed for DPDK to load compressed firmwares [RH git: 95331d366d]
    Reported-by: David Marchand (david.marchand@redhat.com)


* Fri Jul 01 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-29
- Merging upstream branch-2.17 [RH git: d3c723a17e]
    Commit list:
    05e9d2b7a9 Pmd.at: fix dpcls and dpif configuration test cases.


* Thu Jun 30 2022 Ilya Maximets <i.maximets@redhat.com> - 2.17.0-28
- Merging upstream branch-2.17 [RH git: 9738f7f756]
    Commit list:
    45ecaa9e57 ovsdb: Add Local_Config schema.
    
    Merge:
     redhat/template.spec.in updated with new files.
    
    Signed-off-by: Ilya Maximets <i.maximets@redhat.com>


* Wed Jun 29 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-27
- Merging upstream branch-2.17 [RH git: 62ee0c2ec8]
    Commit list:
    61d64d3899 dpif-netdev: Fix leak of AVX512 DPIF scratch pad.


* Wed Jun 29 2022 Timothy Redaelli <tredaelli@redhat.com> - 2.17.0-26
- Fix REPO_URL [RH git: cf6a18b2bd]


* Wed Jun 29 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-25
- Merging upstream branch-2.17 [RH git: 27d62d7d3f]
    Commit list:
    a77ad9693c dpif-netdev: Refactor AVX512 runtime checks. (#2100393)


* Tue Jun 28 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-24
- Merging upstream branch-2.17 [RH git: f0e25fe3e6]
    Commit list:
    ccea7df578 dpif-netdev-extract-avx512: Protect GCC builtin usage.
    807f7f994a ovs-tcpdump: Default to OVS_RUNDIR if present.
    ec13b03ca3 ovsdb: Fix memory leak on error path in ovsdb_file_read__().
    8b2dff2e34 odp-util: Ignore unknown attributes in parse_key_and_mask_to_match(). (#2089331)
    13d97f6637 ofproto-dpif: Avoid unneccesary backer revalidation.
    9b4035d699 lldp: Fix lldp memory leak.
    d9351febc2 ipfix: Trigger revalidation if ipfix options changes.
    5419b1de93 conntrack: Fix incorrect bit shift while hashing nat range.
    1ab5f94a11 packets: Fix misaligned write to MPLS lse.
    8e00be03c7 tc: Fix misaligned access to stats and time values.
    3a1f5341ca odp-util: Fix unaligned access to tunnel id.
    0c54c43b89 ofpbuf: Fix offsetting a NULL pointer in ofpbuf_reserve.
    98edacb40c drop-stats.at: Fix frequent failures of the recursion too deep test.
    cbc13ce4f7 odp_util: Fix parse_key_and_mask_to_match() vlan parsing.


* Tue Jun 21 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-23
- Merging upstream branch-2.17 [RH git: e2e0aac349]
    Commit list:
    73e6ce4925 Prepare for 2.17.3.
    95979b0f0d Set release date for 2.17.2.


* Tue Jun 07 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-22
- Merging upstream branch-2.17 [RH git: ce91947e61]
    Commit list:
    250e1a6dd2 ofproto-dpif-xlate: Fix internal CT state for non-recirc traffic.
    fe870ee072 classifier: Adjust segment boundary to execute prerequisite processing. (#2081773)
    ec0ec464ba ovs-tcpdump: Fix error when stopping ovs-tcpdump.


* Tue May 31 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-21
- Merging upstream branch-2.17 [RH git: 6ff800a303]
    Commit list:
    420823e2af ofproto-dpif: Fix meter use-after-free.
    c762da2623 ovs-rcu: Add ovsrcu_barrier.
    cd9b6b64f4 dpif-netdev: Fix ALB 'rebalance_intvl' max hard limit.
    64f6c49d25 dpif-netdev: Fix ALB parameters type mismatch.
    b11b84ea7f dpdk: Use DPDK 21.11.1 release.
    d3bf48e9a9 raft: Don't use HMAP_FOR_EACH_SAFE when logging commands.


* Thu May 26 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-20
- Merging upstream branch-2.17 [RH git: 77f2886b02]
    Commit list:
    e07377bb49 ovsdb: raft: Fix transaction double commit due to lost leadership. (#2046340)
    5da86cb360 dynamic-string: Fix undefined behavior due to offsetting null pointer.
    369e688908 Revert "odp-util: Always report ODP_FIT_TOO_LITTLE for IGMP."
    18341166ed ofproto-dpif-xlate: Fix netdev native tunnel neigh discovery spa.
    748e4b2b5b ovs-router: Expose the ovs_router_get_netdev_source_address function.
    34390bb35c ofproto-dpif: Trigger revalidation if ct tp changes.


* Wed May 25 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-19
- Merging upstream branch-2.17 [RH git: 993b9ca4b4]
    Commit list:
    1adb07e206 Carefully release NBL in Windows


* Thu May 19 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-18
- Merging upstream branch-2.17 [RH git: 868b675dfd]
    Commit list:
    1ccaba4484 tests: Properly kill ovsdb test processes.
    260b091c2a ovs-save: Get highest ofp version error.
    7606bb1210 netdev-linux: Properly access 32-bit aligned rtnl_link_stats64 structs.
    0688b9f27d treewide: Avoid offsetting NULL pointers.
    92bcf0a823 treewide: Fix invalid bit shift operations.


* Wed May 04 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-17
- Merging upstream branch-2.17 [RH git: e16db3efbf]
    Commit list:
    7fa76371de utilities: Handle dumping packets in GDB TUI.
    8cac8baa8f ofproto-dpif-xlate: Remove mirror assert.
    e0e8f0c546 netdev-dpdk: Fix tx drops statistic for a down netdev.
    f9b5f8a781 netdev-dpdk: Remove a leftover lock annotation.
    4c3976ff2a netdev-dpdk: Refactor the DPDK transmit path.


* Wed May 04 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-16
- Merging upstream branch-2.17 [RH git: ca8c5adb3e]
    Commit list:
    410b97c839 netdev-offload-dpdk: Fix ethernet type for VLANs.
    7948312feb netdev-offload-dpdk: Use has_vlan match attribute.


* Mon May 02 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-15
- Merging upstream branch-2.17 [RH git: e706ea8148]
    Commit list:
    522c46884d python: idl: Raise AttributeError from uuid_to_row.
    cb24c524e4 ofproto-dpif-xlate: Clear out vlan flow fields while processing native tunnel. (#2060552)
    a665b75dec dpif-netdev-avx512: Fix overflow of UINT32_C(1).


* Thu Apr 28 2022 Timothy Redaelli <tredaelli@redhat.com> - 2.17.0-14
- vhost: fix queue number check when setting inflight FD [RH git: 2ac21853a2]
    [ upstream commit 6442c329b9d2ded0f44b27d2016aaba8ba5844c5 ]
    
    In function vhost_user_set_inflight_fd, queue number in inflight
    message is used to access virtqueue. However, queue number could
    be larger than VHOST_MAX_VRING and cause write OOB as this number
    will be used to write inflight info in virtqueue structure. This
    patch checks the queue number to avoid the issue and also make
    sure virtqueues are allocated before setting inflight information.
    
    Fixes: ad0a4ae491fe ("vhost: checkout resubmit inflight information")
    
    Reported-by: Wenxiang Qian <leonwxqian@gmail.com>
    Signed-off-by: Chenbo Xia <chenbo.xia@intel.com>
    Reviewed-by: Maxime Coquelin <maxime.coquelin@redhat.com>


* Thu Apr 28 2022 Timothy Redaelli <tredaelli@redhat.com> - 2.17.0-13
- vhost: fix FD leak with inflight messages [RH git: bff69b098f]
    [ upstream commit af74f7db384ed149fe42b21dbd7975f8a54ef227 ]
    
    Even if unlikely, a buggy vhost-user master might attach fds to inflight
    messages. Add checks like for other types of vhost-user messages.
    
    Fixes: d87f1a1cb7b6 ("vhost: support inflight info sharing")
    
    Signed-off-by: David Marchand <david.marchand@redhat.com>
    Reviewed-by: Maxime Coquelin <maxime.coquelin@redhat.com>


* Wed Apr 27 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-12
- Merging upstream branch-2.17 [RH git: 7a9f21a896]
    Commit list:
    60e7badd6e dpif-netdev-avx512: Fix ubsan shift error in bitmasks.
    9cc329ec5b python: Politely handle misuse of table.condition.
    0631be2b5a ofproto-xlate: Fix crash when forwarding packet between legacy_l3 tunnels.
    df97903099 system-traffic: Fix fragment reassembly with L3 L4 protocol information.
    ba159ee0f9 cirrus: Update FreeBSD versions.


* Thu Apr 21 2022 Timothy Redaelli <tredaelli@redhat.com> - 2.17.0-11
- Set RTE_ETH_MAXPORTS to 1024 [RH git: c02e6bcdc4] (#2077451)
    Resolves: #2077451


* Wed Apr 13 2022 Timothy Redaelli <tredaelli@redhat.com> - 2.17.0-10
- redhat: network-scripts are gone in RHEL9 [RH git: 613e0e5190]


* Fri Apr 08 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-9
- Merging upstream branch-2.17 [RH git: 4b4333522a]
    Commit list:
    bd1a3b6b49 Prepare for 2.17.2.
    41bb202fb3 Set release date for 2.17.1.
    8f42d4f597 NEWS: Highlight libopenvswitch API change caused by UB fixes.


* Fri Apr 08 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-8
- Merging upstream branch-2.17 [RH git: 11b19654f7]
    Commit list:
    14301b3a3c netdev-offload-tc: Check for ct_state flag combinations that are not offloadable.


* Mon Apr 04 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-7
- Merging upstream branch-2.17 [RH git: 6cd8201ead]
    Commit list:
    3a2eef7927 python: idl: Set cond_changed to true if condition change requested.
    d05ccf288d dpif-netdev: Fix dp_netdev_get_pmd() function getting correct core_id.
    79e291f983 alb.at: Add tests for cross-numa polling.
    9c3b74fb24 dpif-netdev: Fix PMD auto load balance with pmd-rxq-isolate.
    8580ff9ddd pmd.at: Add tests for multi non-local numa pmds.
    6bf4eeddbb dpif-netdev: Fix non-local numa selection for more than two numas.
    c41434b3b7 dpif-netdev: Fix typo in function name.
    e0aa5e1329 python: idl: Set cond_changed to false if last id is zero.
    8da40d31c7 ofproto-dpif-xlate: Fix NULL pointer dereference in xlate_normal().
    63a903ab42 ofproto/ofproto-dpif: Fix dpif_type for userspace tunnels.


* Mon Apr 04 2022 Timothy Redaelli <tredaelli@redhat.com> - 2.17.0-6
- downstream: Enable usdt probes in build [RH git: b366bbed8f]
    Fixes: BZ1840877


* Thu Mar 31 2022 Michael Santana <msantana@redhat.com> - 2.17.0-5
- redhat/makefile: fix support for more rhel versions [RH git: 7c8bb3babb]
    Signed-off-by: Michael Santana <msantana@redhat.com>


* Thu Mar 31 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-4
- Merging upstream branch-2.17 [RH git: 95e1c005d2]
    Commit list:
    14d54eb8b6 sset: add SHORT version of SAFE loop macros.
    f0e63b115f sparse: bump recommended version and include headers.
    70b87cf722 idlc: support short version of SAFE macros.
    3777ed90c9 rculist: use multi-variable helpers for loop macros.
    bb52e9bebf hindex: remove the next variable in safe loops.
    7d6cbfa24b hindex: use multi-variable iterators.
    97ad96b63a cmap: use multi-variable iterators.
    cd62fda22d hmap: use short version of safe loops if possible.
    d56bfd7521 hmap: implement UB-safe hmap pop iterator.
    e2c8354861 hmap: use multi-variable helpers for hmap loops.
    897d6647e6 list: use short version of safe loops if possible.
    979a9eb5b5 list: use multi-variable helpers for list loops.
    6bacf802c6 util: add helpers to overload SAFE macro.
    f127123d66 util: add safe multi-variable iterators.
    38e73f0b68 util: add multi-variable loop iterator macros.
    e91edf4568 ovsdb: raft: Fix inability to read the database with DNS host names. (#2055097)
    2404d45367 system-traffic.at: Fix flaky DNAT load balancing test.
    6b8adfdd8d dpif-netdev: Keep orig_in_port as a field of the flow.
    6098b7f250 tests: Fix incorrect usage of OVS_WAIT_UNTIL.
    cf9018d373 odp-util: Fix output for tc to be equal to kernel.
    992de24063 netdev-offload-tc: Fix IP and port ranges in flower returns.
    7e26796c03 netdev-offload-tc: Fix use of ICMP values instead of masks defines.
    e319e27064 netdev-offload-tc: Always include conntrack information to tc.
    51ef81ad78 netdev-offload-tc: Check for valid netdev ifindex in flow_put.
    974253dc2e netdev-offload-tc: Set the correct VLAN_VID and VLAN_PCP masks.
    c43c159aea netdev-offload-tc: Add debug logs on tc rule verify failures.
    d34622a03b tc: Keep header rewrite actions order.
    5255713d1f faq: Update OVS/DPDK version table for OVS 2.15/2.16
    05cf36a620 system-dpdk: Fix mfex autovalidator tests.
    87540e3b9f ofp-prop: Silence the 'may be uninitialized' warning.
    812164adef tests: Ignore log about failing to set NETLINK_EXT_ACK.
    ae51ccc12c ovsdb-cluster.at: Avoid test failures due to different hashing.
    f33cde23c7 ofproto: Use xlate map for uuid lookups.
    6ac255496c ofproto: Add refcount to ofproto to fix ofproto use-after-free.
    db0cc8be38 ofproto-dpif: Trigger revalidation when ipfix config set.
    31b86e5c98 conntrack: Prefer dst port range during unique tuple search.
    b761b532c3 conntrack: Select correct sport range for well-known origin sport.
    78bd058c36 ipsec: StrongSwan report connection update failures to ovs logs.
    aa05596dfb ipsec: Libreswan report connection failures to ovs logs.
    427776ceae system-tso: Skip encap tests when userspace TSO is enabled.
    66d16e2883 tc: Fix stats byte count on fragmented packets.
    b63c41f31f compat: Add gen_stats include to define tc hw stats.
    c531b3828f ovsdb: raft: Fix inability to join the cluster after interrupted attempt. (#2033514)
    498cedc483 reconnect: Fix broken inactivity probe if there is no other reason to wake up.
    5dc1423d80 datapath-windows: Fix NXM_OF_IP_TOS issue
    91c0f0068d Prepare for 2.17.1.


* Wed Mar 30 2022 Timothy Redaelli <tredaelli@redhat.com> - 2.17.0-3
- redhat: fix setup on RHEL8 [RH git: 769c7d89ac]


* Wed Mar 30 2022 Timothy Redaelli <tredaelli@redhat.com> - 2.17.0-2
- rhel: avoid including sortedcontainers [RH git: 3c5b820d14]


* Mon Feb 21 2022 Timothy Redaelli <tredaelli@redhat.com> - 2.17.0-1
- redhat: Imported Red Hat build files. [RH git: 00b5f7b51b]


